## User

This is the beginning of an individual meeting with Machine Learning Specialist to discuss your research project.

Here is the agenda for the meeting:

You are working on a research project to use machine learning to develop antibodies or nanobodies for the newest variant of the SARS-CoV-2 spike protein that also, ideally, have activity against other circulating minor variants and past variants. Your team previous decided to modify existing nanobodies to improve their binding to the newest variant of the SARS-CoV-2 spike protein. You are responsible for understanding the topic "ESM" in the context of designing nanobody binders for SARS-CoV-2. You need to fine-tune yourself on the relevant literature on ESM to improve your ability to design SARS-CoV-2 nanobody binders. Please use PubMed Central and search for relevant papers on ESM using the query "ESM applications in viral protein interactions" and request 100 articles with abstracts only. Read all of the abstracts and based on each abstract individually, decide whether you want to fine-tune yourself on the full text of that paper. Include as many papers as possible, but only include papers that are directly relevant to ESM. Please provide the PMCIDs and titles of all the papers that you wish to fine-tune yourself on as a Python dictionary mapping PMCID as a double-quoted string to title as a double-quoted string.

Here are the agenda questions that must be answered:

1. What are the PMCIDs and titles of the papers you wish to fine-tune yourself on (as a Python dictionary mapping PMCID as a double-quoted string to title as double-quoted string)?

Machine Learning Specialist, please provide your response to the agenda.

## Machine Learning Specialist

Based on the abstracts provided, here are the papers that are directly relevant to ESM (Evolutionary Scale Modeling) and its applications in viral protein interactions, which I would like to fine-tune myself on:

```python
{
    "11466415": "Exploring the potential of structure-based deep learning approaches for T cell receptor design",
    "11326577": "DepoScope: Accurate phage depolymerase annotation and domain delineation using large language models",
    "11601519": "Scaling down for efficiency: Medium-sized protein language models perform well at transfer learning on realistic datasets",
    "11701548": "BFVD—a large repository of predicted viral protein structures",
    "11751364": "GOPhage: protein function annotation for bacteriophages by integrating the genomic context",
    "11753890": "TargetCLP: clathrin proteins prediction combining transformed and evolutionary scale modeling-based multi-view features via weighted feature integration approach",
    "11477718": "Revolutionizing Molecular Design for Innovative Therapeutic Applications through Artificial Intelligence",
    "11750110": "Connectome-based biophysical models of pathological protein spreading in neurodegenerative diseases",
    "11507661": "SeqDance: A Protein Language Model for Representing Protein Dynamic Properties",
    "11783440": "RNA sequence analysis landscape: A comprehensive review of task types, databases, datasets, word embedding methods, and language models",
    "11751191": "Paying attention to the SARS-CoV-2 dialect : a deep neural network approach to predicting novel protein mutations",
    "10869273": "Efficient evolution of human antibodies from general protein language models",
    "11745544": "Twenty years of advances in prediction of nucleic acid-binding residues in protein sequences",
    "11796103": "Transitioning from wet lab to artificial intelligence: a systematic review of AI predictors in CRISPR",
    "11794456": "DeepPFP: a multi-task-aware architecture for protein function prediction",
    "11745815": "Recent Advances in Mass Spectrometry-Based Protein Interactome Studies",
    "11747409": "Recent advances in deep learning and language models for studying the microbiome",
    "11783280": "PHIStruct: improving phage–host interaction prediction at low sequence similarity settings using structure-aware protein embeddings",
    "11796362": "The protein structurome of Orthornavirae and its dark matter"
}
```

These papers are selected based on their relevance to ESM and its applications in protein interactions, which are crucial for designing nanobody binders for SARS-CoV-2.

## User

Tool Output:

Here are the top 100 articles on PubMed Central for the query "ESM applications in viral protein interactions":

[begin paper 1]

PMCID = 11796362

Title = The protein structurome of Orthornavirae and its dark matter

Metatranscriptomics is uncovering more and more diverse families of viruses with RNA genomes comprising the viral kingdom Orthornavirae in the realm Riboviria. Thorough protein annotation and comparison are essential to get insights into the functions of viral proteins and virus evolution. In addition to sequence- and hmm profile‑based methods, protein structure comparison adds a powerful tool to uncover protein functions and relationships. We constructed an Orthornavirae “structurome” consisting of already annotated as well as unannotated (“dark matter”) proteins and domains encoded in viral genomes. We used protein structure modeling and similarity searches to illuminate the remaining dark matter in hundreds of thousands of orthornavirus genomes. The vast majority of the dark matter domains showed either “generic” folds, such as single α-helices, or no high confidence structure predictions. Nevertheless, a variety of lineage-specific globular domains that were new either to orthornaviruses in general or to particular virus families were identified within the proteomic dark matter of orthornaviruses, including several predicted nucleic acid-binding domains and nucleases. In addition, we identified a case of exaptation of a cellular nucleoside monophosphate kinase as an RNA-binding protein in several virus families. Notwithstanding the continuing discovery of numerous orthornaviruses, it appears that all the protein domains conserved in large groups of viruses have already been identified. The rest of the viral proteome seems to be dominated by poorly structured domains including intrinsically disordered ones that likely mediate specific virus-host interactions.

Advanced methods for protein structure prediction, such as AlphaFold2, greatly expand our capability to identify protein domains and infer their likely functions and evolutionary relationships. This is particularly pertinent for proteins encoded by viruses that are known to evolve rapidly and as a result often cannot be adequately characterized by analysis of the protein sequences. We performed an exhaustive structure prediction and comparative analysis for uncharacterized proteins and domains (“dark matter”) encoded by viruses with RNA genomes. The results show the dark matter of RNA virus proteome consists mostly of disordered and all-α-helical domains that cannot be readily assigned a specific function and that likely mediate various interactions between viral proteins and between viral and host proteins. The great majority of globular proteins and domains of RNA viruses are already known although we identified several unexpected domains represented in individual viral families.

[end paper 1]

[begin paper 2]

PMCID = 11648999

Title = HBFormer: a single-stream framework based on hybrid attention mechanism for identification of human-virus protein–protein interactions

Exploring human-virus protein–protein interactions (PPIs) is crucial for unraveling the underlying pathogenic mechanisms of viruses. Limitations in the coverage and scalability of high-throughput approaches have impeded the identification of certain key interactions. Current popular computational methods adopt a two-stream pipeline to identify PPIs, which can only achieve relation modeling of protein pairs at the classification phase. However, the fitting capacity of the classifier is insufficient to comprehensively mine the complex interaction patterns between protein pairs.

In this study, we propose a pioneering single-stream framework HBFormer that combines hybrid attention mechanism and multimodal feature fusion strategy for identifying human-virus PPIs. The Transformer architecture based on hybrid attention can bridge the bidirectional information flows between human protein and viral protein, thus unifying joint feature learning and relation modeling of protein pairs. The experimental results demonstrate that HBFormer not only achieves superior performance on multiple human-virus PPI datasets but also outperforms 5 other state-of-the-art human-virus PPI identification methods. Moreover, ablation studies and scalability experiments further validate the effectiveness of our single-stream framework.

Codes and datasets are available at https://github.com/RmQ5v/HBFormer.

[end paper 2]

[begin paper 3]

PMCID = 11481560

Title = Improving viral annotation with artificial intelligence

Viruses of bacteria, “phages,” are fundamental, poorly understood components of microbial community structure and function. Additionally, their dependence on hosts for replication positions phages as unique sensors of ecosystem features and environmental pressures. High-throughput sequencing approaches have begun to give us access to the diversity and range of phage populations in complex microbial community samples, and metagenomics is currently the primary tool with which we study phage populations. The study of phages by metagenomic sequencing, however, is fundamentally limited by viral diversity, which results in the vast majority of viral genomes and metagenome-annotated genomes lacking annotation. To harness bacteriophages for applications in human and environmental health and disease, we need new methods to organize and annotate viral sequence diversity. We recently demonstrated that methods that leverage self-supervised representation learning can supplement statistical sequence representations for remote viral protein homology detection in the ocean virome and propose that consideration of the functional content of viral sequences allows for the identification of similarity in otherwise sequence-diverse viruses and viral-like elements for biological discovery. In this review, we describe the potential and pitfalls of large language models for viral annotation. We describe the need for new approaches to annotate viral sequences in metagenomes, the fundamentals of what protein language models are and how one can use them for sequence annotation, the strengths and weaknesses of these models, and future directions toward developing better models for viral annotation more broadly.

[end paper 3]

[begin paper 4]

PMCID = 11312453

Title = Protein Set Transformer: A protein-based genome language model to power high diversity viromics

Exponential increases in microbial and viral genomic data demand transformational advances in scalable, generalizable frameworks for their interpretation. Standard homology-based functional analyses are hindered by the rapid divergence of microbial and especially viral genomes and proteins that significantly decreases the volume of usable data. Here, we present Protein Set Transformer (PST), a protein-based genome language model that models genomes as sets of proteins without considering sparsely available functional labels. Trained on >100k viruses, PST outperformed other homology- and language model-based approaches for relating viral genomes based on shared protein content. Further, PST demonstrated protein structural and functional awareness by clustering capsid-fold-containing proteins with known capsid proteins and uniquely clustering late gene proteins within related viruses. Our data establish PST as a valuable method for diverse viral genomics, ecology, and evolutionary applications. We posit that the PST framework can be a foundation model for microbial genomics when trained on suitable data.

[end paper 4]

[begin paper 5]

PMCID = 11469463

Title = Protein Set Transformer: A protein-based genome language model to power high diversity viromics

Exponential increases in microbial and viral genomic data demand transformational advances in scalable, generalizable frameworks for their interpretation. Standard homology-based functional analyses are hindered by the rapid divergence of microbial and especially viral genomes and proteins that significantly decreases the volume of usable data. Here, we present Protein Set Transformer (PST), a protein-based genome language model that models genomes as sets of proteins without considering sparsely available functional labels. Trained on >100k viruses, PST outperformed other homology- and language model-based approaches for relating viral genomes based on shared protein content. Further, PST demonstrated protein structural and functional awareness by clustering capsid-fold-containing proteins with known capsid proteins and uniquely clustering late gene proteins within related viruses. Our data establish PST as a valuable method for diverse viral genomics, ecology, and evolutionary applications. We posit that the PST framework can be a foundation model for microbial genomics when trained on suitable data.

[end paper 5]

[begin paper 6]

PMCID = 11466415

Title = Exploring the potential of structure-based deep learning approaches for T cell receptor design

Deep learning methods, trained on the increasing set of available protein 3D structures and sequences, have substantially impacted the protein modeling and design field. These advancements have facilitated the creation of novel proteins, or the optimization of existing ones designed for specific functions, such as binding a target protein. Despite the demonstrated potential of such approaches in designing general protein binders, their application in designing immunotherapeutics remains relatively underexplored. A relevant application is the design of T cell receptors (TCRs). Given the crucial role of T cells in mediating immune responses, redirecting these cells to tumor or infected target cells through the engineering of TCRs has shown promising results in treating diseases, especially cancer. However, the computational design of TCR interactions presents challenges for current physics-based methods, particularly due to the unique natural characteristics of these interfaces, such as low affinity and cross-reactivity. For this reason, in this study, we explored the potential of two structure-based deep learning protein design methods, ProteinMPNN and ESM-IF1, in designing fixed-backbone TCRs for binding target antigenic peptides presented by the MHC through different design scenarios. To evaluate TCR designs, we employed a comprehensive set of sequence- and structure-based metrics, highlighting the benefits of these methods in comparison to classical physics-based design methods and identifying deficiencies for improvement.

Redirecting T cells to recognize and combat infected or altered cells through the engineering of T cell receptors (TCR) has shown promising results, particularly in immunotherapy against cancer. Leveraging breakthroughs in deep learning within the biosciences, this study explores whether deep learning architectures for general protein design, such as ProteinMPNN and ESM-IF1, can design TCRs to bind target antigenic peptides presented by the MHC (pMHC) based on fixed-backbone structures of the complexes. We utilized a comprehensive set of sequence-based and structure-based metrics, derived from deep learning or classical physics-based principles, to evaluate the generated TCR designs. Our findings highlight the benefits of these methods compared to traditional physics-based design approaches and pinpoint deficiencies for improvement. The results contribute to advancements in the field of TCR design, serving as a guiding framework for the structure-based design of TCRs using deep learning, thereby providing the basis for computational engineering of specific TCRs for T cell-based immunotherapy.

[end paper 6]

[begin paper 7]

PMCID = 8402008

Title = The Anti-Viral Applications of Marine Resources for COVID-19 Treatment: An Overview

The ongoing pandemic has led to an urgent need for novel drug discovery and potential therapeutics for Sars-CoV-2 infected patients. Although Remdesivir and the anti-inflammatory agent dexamethasone are currently on the market for treatment, Remdesivir lacks full efficacy and thus, more drugs are needed. This review was conducted through literature search of PubMed, MDPI, Google Scholar and Scopus. Upon review of existing literature, it is evident that marine organisms harbor numerous active metabolites with anti-viral properties that serve as potential leads for COVID-19 therapy. Inorganic polyphosphates (polyP) naturally found in marine bacteria and sponges have been shown to prevent viral entry, induce the innate immune response, and downregulate human ACE-2. Furthermore, several marine metabolites isolated from diverse sponges and algae have been shown to inhibit main protease (Mpro), a crucial protein required for the viral life cycle. Sulfated polysaccharides have also been shown to have potent anti-viral effects due to their anionic properties and high molecular weight. Likewise, select marine sponges produce bromotyrosines which have been shown to prevent viral entry, replication and protein synthesis. The numerous compounds isolated from marine resources demonstrate significant potential against COVID-19. The present review for the first time highlights marine bioactive compounds, their sources, and their anti-viral mechanisms of action, with a focus on potential COVID-19 treatment. 

[end paper 7]

[begin paper 8]

PMCID = 11326577

Title = DepoScope: Accurate phage depolymerase annotation and domain delineation using large language models

Bacteriophages (phages) are viruses that infect bacteria. Many of them produce specific enzymes called depolymerases to break down external polysaccharide structures. Accurate annotation and domain identification of these depolymerases are challenging due to their inherent sequence diversity. Hence, we present DepoScope, a machine learning tool that combines a fine-tuned ESM-2 model with a convolutional neural network to identify depolymerase sequences and their enzymatic domains precisely. To accomplish this, we curated a dataset from the INPHARED phage genome database, created a polysaccharide-degrading domain database, and applied sequential filters to construct a high-quality dataset, which is subsequently used to train DepoScope. Our work is the first approach that combines sequence-level predictions with amino-acid-level predictions for accurate depolymerase detection and functional domain identification. In that way, we believe that DepoScope can greatly enhance our understanding of phage-host interactions at the level of depolymerases.

[end paper 8]

[begin paper 9]

PMCID = 11346362

Title = SegVir: Reconstruction of Complete Segmented RNA Viral Genomes from Metatranscriptomes

Segmented RNA viruses are a complex group of RNA viruses with multisegment genomes. Reconstructing complete segmented viruses is crucial for advancing our understanding of viral diversity, evolution, and public health impact. Using metatranscriptomic data to identify known and novel segmented viruses has sped up the survey of segmented viruses in various ecosystems. However, the high genetic diversity and the difficulty in binning complete segmented genomes present significant challenges in segmented virus reconstruction. Current virus detection tools are primarily used to identify nonsegmented viral genomes. This study presents SegVir, a novel tool designed to identify segmented RNA viruses and reconstruct their complete genomes from complex metatranscriptomes. SegVir leverages both close and remote homology searches to accurately detect conserved and divergent viral segments. Additionally, we introduce a new method that can evaluate the genome completeness and conservation based on gene content. Our evaluations on simulated datasets demonstrate SegVir’s superior sensitivity and precision compared to existing tools. Moreover, in experiments using real data, we identified some virus segments missing in the NCBI database, underscoring SegVir’s potential to enhance viral metagenome analysis. The source code and supporting data of SegVir are available via https://github.com/HubertTang/SegVir.

[end paper 9]

[begin paper 10]

PMCID = 11751364

Title = GOPhage: protein function annotation for bacteriophages by integrating the genomic context

Bacteriophages are viruses that target bacteria, playing a crucial role in microbial ecology. Phage proteins are important in understanding phage biology, such as virus infection, replication, and evolution. Although a large number of new phages have been identified via metagenomic sequencing, many of them have limited protein function annotation. Accurate function annotation of phage proteins presents several challenges, including their inherent diversity and the scarcity of annotated ones. Existing tools have yet to fully leverage the unique properties of phages in annotating protein functions. In this work, we propose a new protein function annotation tool for phages by leveraging the modular genomic structure of phage genomes. By employing embeddings from the latest protein foundation models and Transformer to capture contextual information between proteins in phage genomes, GOPhage surpasses state-of-the-art methods in annotating diverged proteins and proteins with uncommon functions by 6.78% and 13.05% improvement, respectively. GOPhage can annotate proteins lacking homology search results, which is critical for characterizing the rapidly accumulating phage genomes. We demonstrate the utility of GOPhage by identifying 688 potential holins in phages, which exhibit high structural conservation with known holins. The results show the potential of GOPhage to extend our understanding of newly discovered phages.

[end paper 10]

[begin paper 11]

PMCID = 11601519

Title = Scaling down for efficiency: Medium-sized protein language models perform well at transfer learning on realistic datasets

Protein language models (pLMs) can offer deep insights into evolutionary and structural properties of proteins. While larger models, such as the 15 billion parameter model ESM-2, promise to capture more complex patterns in sequence space, they also present practical challenges due to their high dimensionality and high computational cost. We systematically evaluated the performance of various pLMs across multiple biological datasets to assess the impact of model size on transfer learning. Surprisingly, we found that larger models not necessarily outperform smaller ones, in particular when data is limited. Medium-sized models, such as ESM-2 650M and ESM C 600M, demonstrated consistently good performance, falling only slightly behind their larger counterparts—ESM-2 15B and ESM C 6B—despite being many times smaller. Additionally, we compared various methods of compressing embeddings prior to transfer learning, and we found that mean embeddings consistently outperformed other compression methods. In summary, ESM C 600M with mean embeddings offers an optimal balance between performance and efficiency, making it a practical and scalable choice for transfer learning in realistic biological applications.

[end paper 11]

[begin paper 12]

PMCID = 8800849

Title = Inhibitory efficacy of 2, 4-diacetylphloroglucinol against SARS-COV-2 proteins: in silico study

The pandemic of Severe Acute Respiratory Syndrome Coronavirus-2 has affected millions of people worldwide with common symptoms of fever, cough, and respiratory complications. The pandemic has posed a huge challenge to emergency health services due to unavailability of potent therapeutic drugs. The proteins associated with the viral pathogenesis has been identified as suitable targets for drug design and warrants effective drug discovery to abate COVID-19. The papain-like protease (PLpro), nucleocapsid (N), main protease (Mpro) and non-structural protein (nsp12) of SARS-CoV-2, key component of processing of viral polyproteins, transcription, assembly and replication. On this streak, present study evaluated the interaction of ligand 2,4-diacetylphloroglucinol (DAPG) with viral proteins using molecular docking with (i) AutoDock 4.2.6 and (ii) AutoDock Vina followed by molecular dynamic simulation studies of protein-ligand complex configuration. The analysis revealed that PLpro (3E9S) and N (4J3K) protein corresponds to the highest docking score and therefore, selected for molecular dynamics simulation study (100 ns). The study comprised analysis of parameters: (i) RMSD and RMSF, (ii) radius of gyration- which indicated interaction of protein entities with ligand supported steadiness of the complex, (iii) Coulombic and Lennard–Jones interactions, which played a significant role in complex stability. DAPG showed a good number of H-bonds with PLpro and MM-PBSA binding energy when compared to the N protein. This study showed DAPG as a potential bioactive molecule to act as an inhibitor for the PLpro thereby, DAPG can be used as potential inhibitor against SARS-CoV-2 and is potential drug candidate against COVID-19.

The online version contains supplementary material available at 10.1007/s11756-021-00979-4.

[end paper 12]

[begin paper 13]

PMCID = 9424195

Title = High-efficiency decomposition of eggshell membrane by a keratinase from Meiothermus taiwanensis

Eggshell membrane (ESM), a plentiful biological waste, consists of collagen-like proteins and glycosaminoglycans (GAGs) such as hyaluronic acid (HA). Here we used a keratinase (oeMtaker)-mediated system to decompose ESM. The best reaction condition was established by incubating the solution containing oeMtaker, sodium sulfite, and ESM with a weight ratio of 1:120:600. ESM enzymatic hydrolysate (ESM-EH) showed a high proportion of essential amino acids and type X collagen peptides with 963–2259 Da molecular weights. The amounts of GAGs and sulfated GAGs in ESM-EH were quantified as 6.4% and 0.7%, respectively. The precipitated polysaccharides with an average molecular weight of 1300–1700 kDa showed an immunomodulatory activity by stimulating pro-inflammatory cytokines (IL-6 and TNF-α) production. In addition, a microorganism-based system was established to hydrolyze ESM by Meiothermus taiwanensis WR-220. The amounts of GAGs and sulfated GAGs in the system were quantified as 0.9% and 0.1%, respectively. Based on our pre-pilot tests, the system shows great promise in developing into a low-cost and high-performance process. These results indicate that the keratinase-mediated system could hydrolyze ESM more efficiently and produce more bioactive substances than ever for therapeutical applications and dietary supplements.

[end paper 13]

[begin paper 14]

PMCID = 11701548

Title = BFVD—a large repository of predicted viral protein structures

The AlphaFold Protein Structure Database (AFDB) is the largest repository of accurately predicted structures with taxonomic labels. Despite providing predictions for over 214 million UniProt entries, the AFDB does not cover viral sequences, severely limiting their study. To address this, we created the Big Fantastic Virus Database (BFVD), a repository of 351 242 protein structures predicted by applying ColabFold to the viral sequence representatives of the UniRef30 clusters. By utilizing homology searches across two petabases of assembled sequencing data, we improved 36% of these structure predictions beyond ColabFold’s initial results. BFVD holds a unique repertoire of protein structures as over 62% of its entries show no or low structural similarity to existing repositories. We demonstrate how a substantial fraction of bacteriophage proteins, which remained unannotated based on their sequences, can be matched with similar structures from BFVD. In that, BFVD is on par with the AFDB, while holding nearly three orders of magnitude fewer structures. BFVD is an important virus-specific expansion to protein structure repositories, offering new opportunities to advance viral research. BFVD can be freely downloaded at bfvd.steineggerlab.workers.dev and queried using Foldseek and UniProt labels at bfvd.foldseek.com.

[end paper 14]

[begin paper 15]

PMCID = 11783280

Title = PHIStruct: improving phage–host interaction prediction at low sequence similarity settings using structure-aware protein embeddings

Recent computational approaches for predicting phage–host interaction have explored the use of sequence-only protein language models to produce embeddings of phage proteins without manual feature engineering. However, these embeddings do not directly capture protein structure information and structure-informed signals related to host specificity.

We present PHIStruct, a multilayer perceptron that takes in structure-aware embeddings of receptor-binding proteins, generated via the structure-aware protein language model SaProt, and then predicts the host from among the ESKAPEE genera. Compared against recent tools, PHIStruct exhibits the best balance of precision and recall, with the highest and most stable F1 score across a wide range of confidence thresholds and sequence similarity settings. The margin in performance is most pronounced when the sequence similarity between the training and test sets drops below 40%, wherein, at a relatively high-confidence threshold of above 50%, PHIStruct presents a 7%–9% increase in class-averaged F1 over machine learning tools that do not directly incorporate structure information, as well as a 5%–6% increase over BLASTp.

The data and source code for our experiments and analyses are available at https://github.com/bioinfodlsu/PHIStruct.

[end paper 15]

[begin paper 16]

PMCID = 11245638

Title = ISEV2024 Abstract Book



[end paper 16]

[begin paper 17]

PMCID = 10849601

Title = ForceGen: End-to-end de novo protein generation based on nonlinear mechanical unfolding responses using a language diffusion model

Through evolution, nature has presented a set of remarkable protein materials, including elastins, silks, keratins and collagens with superior mechanical performances that play crucial roles in mechanobiology. However, going beyond natural designs to discover proteins that meet specified mechanical properties remains challenging. Here, we report a generative model that predicts protein designs to meet complex nonlinear mechanical property-design objectives. Our model leverages deep knowledge on protein sequences from a pretrained protein language model and maps mechanical unfolding responses to create proteins. Via full-atom molecular simulations for direct validation, we demonstrate that the designed proteins are de novo, and fulfill the targeted mechanical properties, including unfolding energy and mechanical strength, as well as the detailed unfolding force-separation curves. Our model offers rapid pathways to explore the enormous mechanobiological protein sequence space unconstrained by biological synthesis, using mechanical features as the target to enable the discovery of protein materials with superior mechanical properties.

A generative language diffusion model can design proteins with desired nonlinear mechanical properties.

[end paper 17]

[begin paper 18]

PMCID = 11576732

Title = Discovering CRISPR-Cas system with self-processing pre-crRNA capability by foundation models

The discovery of CRISPR-Cas systems has paved the way for advanced gene editing tools. However, traditional Cas discovery methods relying on sequence similarity may miss distant homologs and aren’t suitable for functional recognition. With protein large language models (LLMs) evolving, there is potential for Cas system modeling without extensive training data. Here, we introduce CHOOSER (Cas HOmlog Observing and SElf-processing scReening), an AI framework for alignment-free discovery of CRISPR-Cas systems with self-processing pre-crRNA capability using protein foundation models. By using CHOOSER, we identify 11 Casλ homologs, nearly doubling the known catalog. Notably, one homolog, EphcCasλ, is experimentally validated for self-processing pre-crRNA, DNA cleavage, and trans-cleavage, showing promise for CRISPR-based pathogen detection. This study highlights an innovative approach for discovering CRISPR-Cas systems with specific functions, emphasizing their potential in gene editing.

Identification of CRISPR-Cas systems by sequence alignment is limited by homolog sequence diversity. Here, the authors develop CHOOSER, and AI framework, for alignment free discovery of CRISPR-Cas systems, including EphcCasλ, which was validated for self-processing and DNA cleavage.

[end paper 18]

[begin paper 19]

PMCID = 11747409

Title = Recent advances in deep learning and language models for studying the microbiome

Recent advancements in deep learning, particularly large language models (LLMs), made a significant impact on how researchers study microbiome and metagenomics data. Microbial protein and genomic sequences, like natural languages, form a language of life, enabling the adoption of LLMs to extract useful insights from complex microbial ecologies. In this paper, we review applications of deep learning and language models in analyzing microbiome and metagenomics data. We focus on problem formulations, necessary datasets, and the integration of language modeling techniques. We provide an extensive overview of protein/genomic language modeling and their contributions to microbiome studies. We also discuss applications such as novel viromics language modeling, biosynthetic gene cluster prediction, and knowledge integration for metagenomics studies.

[end paper 19]

[begin paper 20]

PMCID = 11269938

Title = SENSE-PPI reconstructs interactomes within, across, and between species at the genome scale

Ab initio computational reconstructions of protein-protein interaction (PPI) networks will provide invaluable insights into cellular systems, enabling the discovery of novel molecular interactions and elucidating biological mechanisms within and between organisms. Leveraging the latest generation protein language models and recurrent neural networks, we present SENSE-PPI, a sequence-based deep learning model that efficiently reconstructs ab initio PPIs, distinguishing partners among tens of thousands of proteins and identifying specific interactions within functionally similar proteins. SENSE-PPI demonstrates high accuracy, limited training requirements, and versatility in cross-species predictions, even with non-model organisms and human-virus interactions. Its performance decreases for phylogenetically more distant model and non-model organisms, but signal alteration is very slow. In this regard, it demonstrates the important role of parameters in protein language models. SENSE-PPI is very fast and can test 10,000 proteins against themselves in a matter of hours, enabling the reconstruction of genome-wide proteomes.

SENSE-PPI enables PPI reconstruction at the genome level from sequences

10,000 proteins can be screened against themselves in a matter of hours

It finds interactions in non-model organisms, disordered proteins, human-virus pairs

Specific functional modules are sharply detected

Biocomputational method; Biological constraints; Molecular network; Neural networks; Sequence analysis

[end paper 20]

[begin paper 21]

PMCID = 7693317

Title = TNF Signaling Dictates Myeloid and Non-Myeloid Cell Crosstalk to Execute MCMV-Induced Extrinsic Apoptosis

Cytomegaloviruses all encode the viral inhibitor of caspase-8-induced apoptosis (vICA). After binding to this initiator caspase, vICA blocks caspase-8 proteolytic activity and ability to activate caspase-3 and/or caspase-7. In this manner, vICA has long been known to prevent apoptosis triggered via tumor necrosis factor (TNF) family death receptor-dependent extrinsic signaling. Here, we employ fully wild-type murine cytomegalovirus (MCMV) and vICA-deficient MCMV (∆M36) to investigate the contribution of TNF signaling to apoptosis during infection of different cell types. ∆M36 shows the expected ability to kill mouse splenic hematopoietic cells, bone marrow-derived macrophages (BMDM), and dendritic cells (BMDC). Antibody blockade or genetic elimination of TNF protects myeloid cells from death, and caspase-8 activation accompanies cell death. Interferons, necroptosis, and pyroptotic gasdermin D (GSDMD) do not contribute to myeloid cell death. Human and murine fibroblasts or murine endothelial cells (SVEC4-10) normally insensitive to TNF become sensitized to ∆M36-induced apoptosis when treated with TNF or TNF-containing BMDM-conditioned medium. We demonstrate that myeloid cells are the natural source of TNF that triggers apoptosis in either myeloid (autocrine) or non-myeloid cells (paracrine) during ∆M36 infection of mice. Caspase-8 suppression by vICA emerges as key to subverting innate immune elimination of a wide variety of infected cell types.

[end paper 21]

[begin paper 22]

PMCID = 10593082

Title = PepMLM: Target Sequence-Conditioned Generation of Peptide Binders via Masked Language Modeling

Target proteins that lack accessible binding pockets and conformational stability have posed increasing challenges for drug development. Induced proximity strategies, such as PROTACs and molecular glues, have thus gained attention as pharmacological alternatives, but still require small molecule docking at binding pockets for targeted protein degradation (TPD). The computational design of protein-based binders presents unique opportunities to access “undruggable” targets, but have often relied on stable 3D structures or predictions for effective binder generation. Recently, we have leveraged the expressive latent spaces of protein language models (pLMs) for the prioritization of peptide binders from sequence alone, which we have then fused to E3 ubiquitin ligase domains, creating a CRISPR-analogous TPD system for target proteins. However, our methods rely on training discriminator models for ranking heuristically or unconditionally-derived “guide” peptides for their target binding capability. In this work, we introduce PepMLM, a purely target sequence-conditioned de novo generator of linear peptide binders. By employing a novel masking strategy that uniquely positions cognate peptide sequences at the terminus of target protein sequences, PepMLM tasks the state-of-the-art ESM-2 pLM to fully reconstruct the binder region, achieving low perplexities matching or improving upon previously-validated peptide-protein sequence pairs. After successful in silico benchmarking with AlphaFold-Multimer, we experimentally verify PepMLM’s efficacy via fusion of model-derived peptides to E3 ubiquitin ligase domains, demonstrating endogenous degradation of target substrates in cellular models. In total, PepMLM enables the generative design of candidate binders to any target protein, without the requirement of target structure, empowering downstream programmable proteome editing applications.

[end paper 22]

[begin paper 23]

PMCID = 11071404

Title = Exploring the Potential of Structure-Based Deep Learning Approaches for T cell Receptor Design

Deep learning methods, trained on the increasing set of available protein 3D structures and sequences, have substantially impacted the protein modeling and design field. These advancements have facilitated the creation of novel proteins, or the optimization of existing ones designed for specific functions, such as binding a target protein. Despite the demonstrated potential of such approaches in designing general protein binders, their application in designing immunotherapeutics remains relatively unexplored. A relevant application is the design of T cell receptors (TCRs). Given the crucial role of T cells in mediating immune responses, redirecting these cells to tumor or infected target cells through the engineering of TCRs has shown promising results in treating diseases, especially cancer. However, the computational design of TCR interactions presents challenges for current physics-based methods, particularly due to the unique natural characteristics of these interfaces, such as low affinity and cross-reactivity. For this reason, in this study, we explored the potential of two structure-based deep learning protein design methods, ProteinMPNN and ESM-IF, in designing fixed-backbone TCRs for binding target antigenic peptides presented by the MHC through different design scenarios. To evaluate TCR designs, we employed a comprehensive set of sequence- and structure-based metrics, highlighting the benefits of these methods in comparison to classical physics-based design methods and identifying deficiencies for improvement.

[end paper 23]

[begin paper 24]

PMCID = 9382669

Title = Exploring whole proteome to contrive multi-epitope-based vaccine for NeoCoV: An immunoinformtics and in-silico approach

Neo-Coronavirus (NeoCoV) is a novel Betacoronavirus (β-CoVs or Beta-CoVs) discovered in bat specimens in South Africa during 2011. The viral sequence is highly similar to Middle East Respiratory Syndrome, particularly that of structural proteins. Thus, scientists have emphasized the threat posed by NeoCoV associated with human angiotensin-converting enzyme 2 (ACE2) usage, which could lead to a high death rate and faster transmission rate in humans. The development of a NeoCoV vaccine could provide a promising option for the future control of the virus in case of human infection. In silico predictions can decrease the number of experiments required, making the immunoinformatics approaches cost-effective and convenient. Herein, with the aid of immunoinformatics and reverse vaccinology, we aimed to formulate a multi-epitope vaccine that may be used to prevent and treat NeoCoV infection. Based on the NeoCoV proteins, B-cell, cytotoxic T lymphocyte (CTL), and helper T lymphocyte (HTL) epitopes were shortlisted. Four vaccines (Neo-1–4) were devised by fusing shortlisted epitopes with appropriate adjuvants and linkers. The secondary and three-dimensional structures of final vaccines were then predicted. The binding interactions of these potential vaccines with toll-like immune receptors (TLR-2, TLR-3, and TLR-4) and major histocompatibility complex molecules (MHC-I and II) reveal that they properly fit into the receptors’ binding domains. Besides, Neo-1 and Neo-4 vaccines exhibited better docking energies of -101.08 kcal/mol and -114.47 kcal/mol, respectively, with TLR-3 as compared to other vaccine constructs. The constructed vaccines are highly antigenic, non-allergenic, soluble, non-toxic, and topologically assessable with good physiochemical characteristics. Codon optimization and in-silico cloning confirmed efficient expression of the designed vaccines in Escherichia coli strain K12. In-silico immune simulation indicated that Neo-1 and Neo-4 vaccines could induce a strong immune response against NeoCoV. Lastly, the binding stability and strong binding affinity of Neo-1 and Neo-4 with TLR-3 receptor were validated using molecular dynamics simulations and free energy calculations (Molecular Mechanics/Generalized Born Surface Area method). The final vaccines require experimental validation to establish their safety and effectiveness in preventing NeoCoV infections.

[end paper 24]

[begin paper 25]

PMCID = 11477718

Title = Revolutionizing Molecular Design for Innovative Therapeutic Applications through Artificial Intelligence

The field of computational protein engineering has been transformed by recent advancements in machine learning, artificial intelligence, and molecular modeling, enabling the design of proteins with unprecedented precision and functionality. Computational methods now play a crucial role in enhancing the stability, activity, and specificity of proteins for diverse applications in biotechnology and medicine. Techniques such as deep learning, reinforcement learning, and transfer learning have dramatically improved protein structure prediction, optimization of binding affinities, and enzyme design. These innovations have streamlined the process of protein engineering by allowing the rapid generation of targeted libraries, reducing experimental sampling, and enabling the rational design of proteins with tailored properties. Furthermore, the integration of computational approaches with high-throughput experimental techniques has facilitated the development of multifunctional proteins and novel therapeutics. However, challenges remain in bridging the gap between computational predictions and experimental validation and in addressing ethical concerns related to AI-driven protein design. This review provides a comprehensive overview of the current state and future directions of computational methods in protein engineering, emphasizing their transformative potential in creating next-generation biologics and advancing synthetic biology.

[end paper 25]

[begin paper 26]

PMCID = 11753890

Title = TargetCLP: clathrin proteins prediction combining transformed and evolutionary scale modeling-based multi-view features via weighted feature integration approach

Clathrin proteins, key elements of the vesicle coat, play a crucial role in various cellular processes, including neural function, signal transduction, and endocytosis. Disruptions in clathrin protein functions have been associated with a wide range of diseases, such as Alzheimer’s, neurodegeneration, viral infection, and cancer. Therefore, correctly identifying clathrin protein functions is critical to unravel the mechanism of these fatal diseases and designing drug targets. This paper presents a novel computational method, named TargetCLP, to precisely identify clathrin proteins. TargetCLP leverages four single-view feature representation methods, including two transformed feature sets (PSSM-CLBP and RECM-CLBP), one qualitative characteristics feature, and one deep-learned-based embedding using ESM. The single-view features are integrated based on their weights using differential evolution, and the BTG feature selection algorithm is utilized to generate a more optimal and reduced subset. The model is trained using various classifiers, among which the proposed SnBiLSTM achieved remarkable performance. Experimental and comparative results on both training and independent datasets show that the proposed TargetCLP offers significant improvements in terms of both prediction accuracy and generalization to unseen data, furthering advancements in the research field.

[end paper 26]

[begin paper 27]

PMCID = 7476649

Title = Mesenchymal Stromal Cells in Viral Infections: Implications for COVID-19

Mesenchymal stromal cells (MSCs) constitute a heterogeneous population of stromal cells with immunomodulatory and regenerative properties that support their therapeutic use. MSCs isolated from many tissue sources replicate vigorously in vitro and maintain their main biological properties allowing their widespread clinical application. To date, most MSC-based preclinical and clinical trials targeted immune-mediated and inflammatory diseases. Nevertheless, MSCs have antiviral properties and have been used in the treatment of various viral infections in the last years. Here, we revised in detail the biological properties of MSCs and their preclinical and clinical applications in viral diseases, including the disease caused by the severe acute respiratory syndrome-coronavirus-2 (SARS-CoV-2) infection (COVID-19). Notably, rapidly increasing numbers of MSC-based therapies for COVID-19 have recently been reported. MSCs are theoretically capable of reducing inflammation and promote lung regeneration in severe COVID-19 patients. We critically discuss the rationale, advantages and disadvantages of MSC-based therapies for viral infections and also specifically for COVID-19 and point out some directions in this field. Finally, we argue that MSC-based therapy may be a promising therapeutic strategy for severe COVID-19 and other emergent respiratory tract viral infections, beyond the viral infection diseases in which MSCs have already been clinically applied.

Graphical Abstract

The online version of this article (10.1007/s12015-020-10032-7) contains supplementary material, which is available to authorized users.

[end paper 27]

[begin paper 28]

PMCID = 7297265

Title = Shape-preserving elastic solid models of macromolecules

Mass-spring models have been a standard approach in molecular modeling for the last few decades, such as elastic network models (ENMs) that are widely used for normal mode analysis. In this work, we present a vastly different elastic solid model (ESM) of macromolecules that shares the same simplicity and efficiency as ENMs in producing the equilibrium dynamics and moreover, offers some significant new features that may greatly benefit the research community. ESM is different from ENM in that it treats macromolecules as elastic solids. Our particular version of ESM presented in this work, named αESM, captures the shape of a given biomolecule most economically using alpha shape, a well-established technique from the computational geometry community. Consequently, it can produce most economical coarse-grained models while faithfully preserving the shape and thus makes normal mode computations and visualization of extremely large complexes more manageable. Secondly, as a solid model, ESM’s close link to finite element analysis renders it ideally suited for studying mechanical responses of macromolecules under external force. Lastly, we show that ESM can be applied also to structures without atomic coordinates such as those from cryo-electron microscopy. The complete MATLAB code of αESM is provided.

Mass-spring models have been a standard approach in classical molecular modeling where atoms are modeled as spheres with a mass and their interactions modeled as springs. The models have been extremely successful. Thinking ahead, however, as molecular systems of our interest grow more quickly in size or dimension than what our computation resources can keep up with, some adjustments in methodology are timely. This work presents a vastly different elastic solid model (ESM) of macromolecules that shares the same simplicity and efficiency as mass-spring models in producing the equilibrium dynamics and moreover, offers some unique features that make it suitable for much larger systems. ESM is different from ENMs in that it treats macromolecules as elastic solids. Our particular version of ESM model presented in this work, named αESM, captures the shape of a given biomolecule most economically using alpha shape, a well-established technique from the computational geometry community. Consequently, it can produce most economical coarse-grained models while faithfully preserving the shape. ESM can be applied also to structures without atomic coordinates such as those from cryo-electron microscopy.

[end paper 28]

[begin paper 29]

PMCID = 8143072

Title = In silico structural elucidation of the rabies RNA-dependent RNA polymerase (RdRp) toward the identification of potential rabies virus inhibitors

The rabies virus (RABV) is a non-segmented, negative single-stranded RNA virus which causes acute infection of the central nervous system in humans. Once symptoms appear, the result is nearly always death, and to date, post-exposure prophylaxis (PEP) is the only treatment applicable only immediately after an exposure. Previous studies have identified viral RNA-dependent RNA polymerase (RdRp) as a potential drug target due to its significant role in viral replication and transcription. Herein we generated an energy-minimized homology model of RABIES-RdRp and used it for virtual screening against 2045 NCI Diversity Set III library. The best five ligand-RdRp complexes were picked for further energy minimization via molecular dynamics (MDs) where the complex with ligand Z01690699 shows a minimum score characterized with stable hydrogen bonds and hydrophobic interactions with the catalytic site residues. Our study identified an important ligand for development of remedial approach for treatment of rabies infection.

The online version contains supplementary material available at 10.1007/s00894-021-04798-x.

[end paper 29]

[begin paper 30]

PMCID = 6516050

Title = Fabrication of KR-12 peptide-containing hyaluronic acid immobilized fibrous eggshell membrane effectively kills multi-drug-resistant bacteria, promotes angiogenesis and accelerates re-epithelialization

Background: Designing a wound dressing that effectively prevents multi-drug-resistant bacterial infection and promotes angiogenesis and re-epithelialization is of great significance for wound management.

Methods and results: In this study, a biocompatible composite membrane comprising biomimetic polydopamine-modified eggshell membrane nano/microfibres coated with KR-12 antimicrobial peptide and hyaluronic acid (HA) was developed in an eco-friendly manner. The physicochemical properties of the composite membrane were thoroughly characterized, and the results showed that the surface hydrophilicity and water absorption ability of the composite membrane were improved after the successive conjugation of the HA and the KR-12 peptide. Furthermore, the in vitrobiological results revealed that the composite membrane had excellent antibacterial activity against Gram-positive Staphylococcus aureus, methicillin-resistant Staphylococcus aureus (MRSA) and Gram-negative Escherichia coli, and it could prevent MRSA biofilm formation on its surface. Additionally, it promoted the proliferation of keratinocytes and human umbilical vein endothelial cells and increased the secretion of VEGF. Finally, an in vivo animal study indicated that the composite membrane could promote wound healing via accelerating angiogenesis and re-epithelialization, which were demonstrated by the enhanced expression of angiogenetic markers (CD31 and VEGF) and keratinocyte proliferation marker (PCNA), respectively.

Conclusion: These results indicated that the composite membrane is a potential candidate of wound dressings

[end paper 30]

[begin paper 31]

PMCID = 8716573

Title = Embeddings from protein language models predict conservation and variant effects

The emergence of SARS-CoV-2 variants stressed the demand for tools allowing to interpret the effect of single amino acid variants (SAVs) on protein function. While Deep Mutational Scanning (DMS) sets continue to expand our understanding of the mutational landscape of single proteins, the results continue to challenge analyses. Protein Language Models (pLMs) use the latest deep learning (DL) algorithms to leverage growing databases of protein sequences. These methods learn to predict missing or masked amino acids from the context of entire sequence regions. Here, we used pLM representations (embeddings) to predict sequence conservation and SAV effects without multiple sequence alignments (MSAs). Embeddings alone predicted residue conservation almost as accurately from single sequences as ConSeq using MSAs (two-state Matthews Correlation Coefficient—MCC—for ProtT5 embeddings of 0.596 ± 0.006 vs. 0.608 ± 0.006 for ConSeq). Inputting the conservation prediction along with BLOSUM62 substitution scores and pLM mask reconstruction probabilities into a simplistic logistic regression (LR) ensemble for Variant Effect Score Prediction without Alignments (VESPA) predicted SAV effect magnitude without any optimization on DMS data. Comparing predictions for a standard set of 39 DMS experiments to other methods (incl. ESM-1v, DeepSequence, and GEMME) revealed our approach as competitive with the state-of-the-art (SOTA) methods using MSA input. No method outperformed all others, neither consistently nor statistically significantly, independently of the performance measure applied (Spearman and Pearson correlation). Finally, we investigated binary effect predictions on DMS experiments for four human proteins. Overall, embedding-based methods have become competitive with methods relying on MSAs for SAV effect prediction at a fraction of the costs in computing/energy. Our method predicted SAV effects for the entire human proteome (~ 20 k proteins) within 40 min on one Nvidia Quadro RTX 8000. All methods and data sets are freely available for local and online execution through bioembeddings.com, https://github.com/Rostlab/VESPA, and PredictProtein.

The online version contains supplementary material available at 10.1007/s00439-021-02411-y.

[end paper 31]

[begin paper 32]

PMCID = 10792517

Title = Tertiary structure assessment at CASP15 

The results of tertiary structure assessment at CASP15 are reported. For the first time, recognizing the outstanding performance of AlphaFold 2 (AF2) at CASP14, all single‐chain predictions were assessed together, irrespective of whether a template was available. At CASP15, there was no single stand‐out group, with most of the best‐scoring groups—led by PEZYFoldings, UM‐TBM, and Yang Server—employing AF2 in one way or another. Many top groups paid special attention to generating deep Multiple Sequence Alignments (MSAs) and testing variant MSAs, thereby allowing them to successfully address some of the hardest targets. Such difficult targets, as well as lacking templates, were typically proteins with few homologues. Local divergence between prediction and target correlated with localization at crystal lattice or chain interfaces, and with regions exhibiting high B‐factor factors in crystal structure targets, and should not necessarily be considered as representing error in the prediction. However, analysis of exposed and buried side chain accuracy showed room for improvement even in the latter. Nevertheless, a majority of groups produced high‐quality predictions for most targets, which are valuable for experimental structure determination, functional analysis, and many other tasks across biology. These include those applying methods similar to those used to generate major resources such as the AlphaFold Protein Structure Database and the ESM Metagenomic atlas: the confidence estimates of the former were also notably accurate.

[end paper 32]

[begin paper 33]

PMCID = 9261893

Title = Allosteric Modulation of the Main Protease (MPro) of SARS-CoV-2 by Casticin—Insights from Molecular Dynamics Simulations

Inhibition of the main protease (Mpro) of SARS-CoV-2 has been suggested to be vital in shutting down viral replication in a host. Most efforts aimed at inhibiting MPro activity have been channeled into competitive inhibition at the active site, but this strategy will require a high inhibitor concentration and impressive inhibitor-MPro binding affinity. Allosteric inhibition can potentially serve as an effective strategy for alleviating these limitations. In this study, the ability of antiviral natural products to inhibit MPro in an allosteric fashion was explored with in silico techniques. Molecular docking revealed a strong interaction between casticin, an antiviral flavonoid, and Mpro at a site distant from the active site. This site, characterized as a distal site, has been shown to have an interdependent dynamic effect with the active site region. Mpro only, Mpro-peptide (binary) and Mpro-peptide-casticin (ternary) complexes were subjected to molecular dynamics simulations for 50 ns to investigate the modulatory activity of casticin binding on Mpro. Molecular dynamic simulations revealed that binding of casticin at the distal site interferes with the proper orientation of the peptide substrate in the oxyanion hole of the active site, and this could lead to a halt or decrease in catalytic activity. This study therefore highlights casticin as a potential allosteric modulator of the SARS-CoV-2 main protease, which could be optimized and developed into a potential lead compound for anti-SARS-CoV-2 chemotherapy.

The online version contains supplementary material available at 10.1007/s42250-022-00411-7.

[end paper 33]

[begin paper 34]

PMCID = 8035888

Title = Characterization and purification of pentameric chimeric protein particles using asymmetric flow field-flow fractionation coupled with multiple detectors

Porcine circovirus causes the post-weaning multi-systemic wasting syndrome. Despite the existence of commercial vaccines, the development of more effective and cheaper vaccines is expected. The usage of chimeric antigens allows serological differentiation between naturally infected and vaccinated animals. In this work, recombinant pentameric vaccination protein particles spontaneously assembled from identical subunits-chimeric fusion proteins derived from circovirus capsid antigen Cap and a multimerizing subunit of mouse polyomavirus capsid protein VP1 were purified and characterized using asymmetric flow field-flow fractionation (AF4) coupled with UV and MALS/DLS (multi-angle light scattering/dynamic light scattering) detectors. Various elution profiles were tested, including constant cross-flow and decreasing cross-flow (linearly and exponentially). The optimal sample retention, separation efficiency, and resolution were assessed by the comparison of the hydrodynamic radius (Rh) measured by online DLS with the Rh values calculated from the simplified retention equation according to the AF4 theory. The results show that the use of the combined elution profiles (exponential and constant cross-flow rates) reduces the time of the separation, prevents undesirable sample-membrane interaction, and yields better resolution. Besides, the results show no self-associations of the individual pentameric particles into larger clusters and no sample degradation during the AF4 separation. The Rg/Rh ratios for different fractions are in good correlation with morphological analyses performed by transmission electron microscopy (TEM). Additionally to the online analysis, the individual fractions were subjected to offline analysis, including batch DLS, TEM, and SDS-PAGE, followed by Western blot.

The online version contains supplementary material available at 10.1007/s00216-021-03323-6.

[end paper 34]

[begin paper 35]

PMCID = 10940830

Title = Single-residue linear and conformational B cell epitopes prediction using random and ESM-2 based projections

B cell epitope prediction methods are separated into linear sequence-based predictors and conformational epitope predictions that typically use the measured or predicted protein structure. Most linear predictions rely on the translation of the sequence to biologically based representations and the applications of machine learning on these representations. We here present CALIBER ‘Conformational And LInear B cell Epitopes pRediction’, and show that a bidirectional long short-term memory with random projection produces a more accurate prediction (test set AUC=0.789) than all current linear methods. The same predictor when combined with an Evolutionary Scale Modeling-2 projection also improves on the state of the art in conformational epitopes (AUC = 0.776). The inclusion of the graph of the 3D distances between residues did not increase the prediction accuracy. However, the long-range sequence information was essential for high accuracy. While the same model structure was applicable for linear and conformational epitopes, separate training was required for each. Combining the two slightly increased the linear accuracy (AUC 0.775 versus 0.768) and reduced the conformational accuracy (AUC = 0.769).

[end paper 35]

[begin paper 36]

PMCID = 9051210

Title = Evanescent scattering imaging of single protein binding kinetics and DNA conformation changes

Evanescent illumination has been widely used to detect single biological macromolecules because it can notably enhance light-analyte interaction. However, the current evanescent single-molecule detection system usually requires specially designed microspheres or nanomaterials. Here we show that single protein detection and imaging can be realized on a plain glass surface by imaging the interference between the evanescent lights scattered by the single proteins and by the natural roughness of the cover glass. This allows us to quantify the sizes of single proteins, characterize the protein–antibody interactions at the single-molecule level, and analyze the heterogeneity of single protein binding behaviors. In addition, owing to the exponential distribution of evanescent field intensity, the evanescent imaging system can track the analyte axial movement with high resolution, which can be used to analyze the DNA conformation changes, providing one solution for detecting small molecules, such as microRNA. This work demonstrates a label-free single protein imaging method with ordinary consumables and may pave a road for detecting small biological molecules.

Single molecule detection based on evanescent illumination usually require specially designed nanomaterials. Here, the authors show that single molecule detection can be realised on a plain glass surface via interference between the evanescent lights scattered by molecules and the natural roughness of the glass.

[end paper 36]

[begin paper 37]

PMCID = 11430650

Title = Integrating Computational Design and Experimental Approaches for Next-Generation Biologics

Therapeutic protein engineering has revolutionized medicine by enabling the development of highly specific and potent treatments for a wide range of diseases. This review examines recent advances in computational and experimental approaches for engineering improved protein therapeutics. Key areas of focus include antibody engineering, enzyme replacement therapies, and cytokine-based drugs. Computational methods like structure-based design, machine learning integration, and protein language models have dramatically enhanced our ability to predict protein properties and guide engineering efforts. Experimental techniques such as directed evolution and rational design approaches continue to evolve, with high-throughput methods accelerating the discovery process. Applications of these methods have led to breakthroughs in affinity maturation, bispecific antibodies, enzyme stability enhancement, and the development of conditionally active cytokines. Emerging approaches like intracellular protein delivery, stimulus-responsive proteins, and de novo designed therapeutic proteins offer exciting new possibilities. However, challenges remain in predicting in vivo behavior, scalable manufacturing, immunogenicity mitigation, and targeted delivery. Addressing these challenges will require continued integration of computational and experimental methods, as well as a deeper understanding of protein behavior in complex physiological environments. As the field advances, we can anticipate increasingly sophisticated and effective protein therapeutics for treating human diseases.

[end paper 37]

[begin paper 38]

PMCID = 10829072

Title = Harnessing generative AI to decode enzyme catalysis and evolution for enhanced engineering

Enzymes, as paramount protein catalysts, occupy a central role in fostering remarkable progress across numerous fields. However, the intricacy of sequence-function relationships continues to obscure our grasp of enzyme behaviors and curtails our capabilities in rational enzyme engineering. Generative artificial intelligence (AI), known for its proficiency in handling intricate data distributions, holds the potential to offer novel perspectives in enzyme research. Generative models could discern elusive patterns within the vast sequence space and uncover new functional enzyme sequences. This review highlights the recent advancements in employing generative AI for enzyme sequence analysis. We delve into the impact of generative AI in predicting mutation effects on enzyme fitness, catalytic activity and stability, rationalizing the laboratory evolution of de novo enzymes, and decoding protein sequence semantics and their application in enzyme engineering. Notably, the prediction of catalytic activity and stability of enzymes using natural protein sequences serves as a vital link, indicating how enzyme catalysis shapes enzyme evolution. Overall, we foresee that the integration of generative AI into enzyme studies will remarkably enhance our knowledge of enzymes and expedite the creation of superior biocatalysts.

This Review underscores the latest advances in applying generative AI to the analysis of enzyme sequences, which has deepened our insight into enzyme evolution and catalysis, thereby advancing enzyme engineering.

[end paper 38]

[begin paper 39]

PMCID = 10723403

Title = ProteinGym: Large-Scale Benchmarks for Protein Design and Fitness Prediction

Predicting the effects of mutations in proteins is critical to many applications, from understanding genetic disease to designing novel proteins that can address our most pressing challenges in climate, agriculture and healthcare. Despite a surge in machine learning-based protein models to tackle these questions, an assessment of their respective benefits is challenging due to the use of distinct, often contrived, experimental datasets, and the variable performance of models across different protein families. Addressing these challenges requires scale. To that end we introduce ProteinGym, a large-scale and holistic set of benchmarks specifically designed for protein fitness prediction and design. It encompasses both a broad collection of over 250 standardized deep mutational scanning assays, spanning millions of mutated sequences, as well as curated clinical datasets providing high-quality expert annotations about mutation effects. We devise a robust evaluation framework that combines metrics for both fitness prediction and design, factors in known limitations of the underlying experimental methods, and covers both zero-shot and supervised settings. We report the performance of a diverse set of over 70 high-performing models from various subfields (eg., alignment-based, inverse folding) into a unified benchmark suite. We open source the corresponding codebase, datasets, MSAs, structures, model predictions and develop a user-friendly website that facilitates data access and analysis.

[end paper 39]

[begin paper 40]

PMCID = 11745815

Title = Recent Advances in Mass Spectrometry-Based Protein Interactome Studies

The foundation of all biological processes is the network of diverse and dynamic protein interactions with other molecules in cells known as the interactome. Understanding the interactome is crucial for elucidating molecular mechanisms but has been a longstanding challenge. Recent developments in mass spectrometry (MS)-based techniques, including affinity purification, proximity labeling, cross-linking, and co-fractionation mass spectrometry (MS), have significantly enhanced our abilities to study the interactome. They do so by identifying and quantifying protein interactions yielding profound insights into protein organizations and functions. This review summarizes recent advances in MS-based interactomics, focusing on the development of techniques that capture protein-protein, protein-metabolite, and protein-nucleic acid interactions. Additionally, we discuss how integrated MS-based approaches have been applied to diverse biological samples, focusing on significant discoveries that have leveraged our understanding of cellular functions. Finally, we highlight state-of-the-art bioinformatic approaches for predictions of interactome and complex modeling, as well as strategies for combining experimental interactome data with computation methods, thereby enhancing the ability of MS-based techniques to identify protein interactomes. Indeed, advances in MS technologies and their integrations with computational biology provide new directions and avenues for interactome research, leveraging new insights into mechanisms that govern the molecular architecture of living cells and, thereby, our comprehension of biological processes.

Recent advances in MS-based techniques for comprehensive protein interactome mapping.

Integration of experimental MS methods with cutting-edge computational tools.

Emerging strategies for high-resolution interactome analysis in various biological contexts.

This review highlights recent advancements in mass spectrometry-based techniques for mapping protein interactomes, including affinity purification, proximity labeling, cross-linking, and co-fractionation approaches. It discusses the integration of these methods with cutting-edge computational tools, emphasizing their synergistic potential in elucidating complex cellular networks. The review explores how these technologies are revolutionizing our understanding of protein interactions, providing unprecedented insights into cellular processes and opening new avenues for biological research, drug discovery, and disease diagnostics.

[end paper 40]

[begin paper 41]

PMCID = 7900040

Title = 3D culture conditions support Kaposi’s sarcoma herpesvirus (KSHV) maintenance and viral spread in endothelial cells

Kaposi’s sarcoma–associated herpesvirus (KSHV) is a human tumorigenic virus and the etiological agent of an endothelial tumor (Kaposi’s sarcoma) and two B cell proliferative diseases (primary effusion lymphoma and multicentric Castleman’s disease). While in patients with late stage of Kaposi’s sarcoma the majority of spindle cells are KSHV-infected, viral copies are rapidly lost in vitro, both upon culture of tumor-derived cells or from newly infected endothelial cells. We addressed this discrepancy by investigating a KSHV-infected endothelial cell line in various culture conditions and in tumors of xenografted mice. We show that, in contrast to two-dimensional endothelial cell cultures, KSHV genomes are maintained under 3D cell culture conditions and in vivo. Additionally, an increased rate of newly infected cells was detected in 3D cell culture. Furthermore, we show that the PI3K/Akt/mTOR and ATM/γH2AX pathways are modulated and support an improved KSHV persistence in 3D cell culture. These mechanisms may contribute to the persistence of KSHV in tumor tissue in vivo and provide a novel target for KS specific therapeutic interventions.

In vivo maintenance of episomal KSHV can be mimicked in 3D spheroid cultures

3D maintenance of KSHV is associated with an increased de novo infection frequency

PI3K/Akt/mTOR and ATM/ γH2AX pathways contribute to viral maintenance

The online version contains supplementary material available at 10.1007/s00109-020-02020-8.

[end paper 41]

[begin paper 42]

PMCID = 11312608

Title = moPPIt: De Novo Generation of Motif-Specific Binders with Protein Language Models

The ability to precisely target specific motifs on disease-related proteins, whether conserved epitopes on viral proteins, intrinsically disordered regions within transcription factors, or breakpoint junctions in fusion oncoproteins, is essential for modulating their function while minimizing off-target effects. Current methods struggle to achieve this specificity without reliable structural information. In this work, we introduce a motif-specific PPI targeting algorithm, moPPIt, for de novo generation of motif-specific peptide binders from the target protein sequence alone. At the core of moPPIt is BindEvaluator, a transformer-based model that interpolates protein language model embeddings of two proteins via a series of multi-headed self-attention blocks, with a key focus on local motif features. Trained on over 510,000 annotated PPIs, BindEvaluator accurately predicts target binding sites given protein-protein sequence pairs with a test AUC > 0.94, improving to AUC > 0.96 when fine-tuned on peptide-protein pairs. By combining BindEvaluator with our PepMLM peptide generator and genetic algorithm-based optimization, moPPIt generates peptides that bind specifically to user-defined residues on target proteins. We demonstrate moPPIt’s efficacy in computationally designing binders to specific motifs, first on targets with known binding peptides and then extending to structured and disordered targets with no known binders. In total, moPPIt serves as a powerful tool for developing highly specific peptide therapeutics without relying on target structure or structure-dependent latent spaces.

[end paper 42]

[begin paper 43]

PMCID = 11161772

Title = Biophysical principles predict fitness of SARS-CoV-2 variants

This research presents a biophysical model that maps the molecular properties of SARS-CoV-2’s receptor binding domain into an epistatic fitness landscape. By linking the binding affinities of the virus to its epidemic fitness, we offer a powerful tool for understanding and predicting the emergence and success of new viral variants. Our model, validated with real-world data and informed by theoretical insights, provides a foundation for interpreting the evolutionary trajectory of past pandemics and predicting those of the future. The adaptability of this biophysical model extends to the key proteins of other viruses as well, signifying its potential in guiding public health interventions, and advancing our understanding of viral evolution.

SARS-CoV-2 employs its spike protein’s receptor binding domain (RBD) to enter host cells. The RBD is constantly subjected to immune responses, while requiring efficient binding to host cell receptors for successful infection. However, our understanding of how RBD’s biophysical properties contribute to SARS-CoV-2’s epidemiological fitness remains largely incomplete. Through a comprehensive approach, comprising large-scale sequence analysis of SARS-CoV-2 variants and the identification of a fitness function based on binding thermodynamics, we unravel the relationship between the biophysical properties of RBD variants and their contribution to viral fitness. We developed a biophysical model that uses statistical mechanics to map the molecular phenotype space, characterized by dissociation constants of RBD to ACE2, LY-CoV016, LY-CoV555, REGN10987, and S309, onto an epistatic fitness landscape. We validate our findings through experimentally measured and machine learning (ML) estimated binding affinities, coupled with infectivity data derived from population-level sequencing. Our analysis reveals that this model effectively predicts the fitness of novel RBD variants and can account for the epistatic interactions among mutations, including explaining the later reversal of Q493R. Our study sheds light on the impact of specific mutations on viral fitness and delivers a tool for predicting the future epidemiological trajectory of previously unseen or emerging low-frequency variants. These insights offer not only greater understanding of viral evolution but also potentially aid in guiding public health decisions in the battle against COVID-19 and future pandemics.

[end paper 43]

[begin paper 44]

PMCID = 8935878

Title = Avian Egg: A Multifaceted Biomaterial for Tissue Engineering

Most components in avian eggs, offering a natural and environmentally friendly source of raw materials, hold great potential in tissue engineering. An avian egg consists of several beneficial elements: the protective eggshell, the eggshell membrane, the egg white (albumen), and the egg yolk (vitellus). The eggshell is mostly composed of calcium carbonate and has intrinsic biological properties that stimulate bone repair. It is a suitable precursor for the synthesis of hydroxyapatite and calcium phosphate, which are particularly relevant for bone tissue engineering. The eggshell membrane is a thin protein-based layer with a fibrous structure and is constituted of several valuable biopolymers, such as collagen and hyaluronic acid, that are also found in the human extracellular matrix. As a result, the eggshell membrane has found several applications in skin tissue repair and regeneration. The egg white is a protein-rich material that is under investigation for the design of functional protein-based hydrogel scaffolds. The egg yolk, mostly composed of lipids but also diverse essential nutrients (e.g., proteins, minerals, vitamins), has potential applications in wound healing and bone tissue engineering. This review summarizes the advantages and status of each egg component in tissue engineering and regenerative medicine, but also covers their current limitations and future perspectives.

[end paper 44]

[begin paper 45]

PMCID = 10093788

Title = Accurate Prediction of Transcriptional Activity of Single Missense Variants in HIV Tat with Deep Learning

Tat is an essential gene for increasing the transcription of all HIV genes, and affects HIV replication, HIV exit from latency, and AIDS progression. The Tat gene frequently mutates in vivo and produces variants with diverse activities, contributing to HIV viral heterogeneity as well as drug-resistant clones. Thus, identifying the transcriptional activities of Tat variants will help to better understand AIDS pathology and treatment. We recently reported the missense mutation landscape of all single amino acid Tat variants. In these experiments, a fraction of double missense alleles exhibited intragenic epistasis. However, it is too time-consuming and costly to determine the effect of the variants for all double mutant alleles through experiments. Therefore, we propose a combined GigaAssay/deep learning approach. As a first step to determine activity landscapes for complex variants, we evaluated a deep learning framework using previously reported GigaAssay experiments to predict how transcription activity is affected by Tat variants with single missense substitutions. Our approach achieved a 0.94 Pearson correlation coefficient when comparing the predicted to experimental activities. This hybrid approach can be extensible to more complex Tat alleles for a better understanding of the genetic control of HIV genome transcription.

[end paper 45]

[begin paper 46]

PMCID = 9188115

Title = Contrastive learning on protein embeddings enlightens midnight zone

Experimental structures are leveraged through multiple sequence alignments, or more generally through homology-based inference (HBI), facilitating the transfer of information from a protein with known annotation to a query without any annotation. A recent alternative expands the concept of HBI from sequence-distance lookup to embedding-based annotation transfer (EAT). These embeddings are derived from protein Language Models (pLMs). Here, we introduce using single protein representations from pLMs for contrastive learning. This learning procedure creates a new set of embeddings that optimizes constraints captured by hierarchical classifications of protein 3D structures defined by the CATH resource. The approach, dubbed ProtTucker, has an improved ability to recognize distant homologous relationships than more traditional techniques such as threading or fold recognition. Thus, these embeddings have allowed sequence comparison to step into the ‘midnight zone’ of protein similarity, i.e. the region in which distantly related sequences have a seemingly random pairwise sequence similarity. The novelty of this work is in the particular combination of tools and sampling techniques that ascertained good performance comparable or better to existing state-of-the-art sequence comparison methods. Additionally, since this method does not need to generate alignments it is also orders of magnitudes faster. The code is available at https://github.com/Rostlab/EAT.

[end paper 46]

[begin paper 47]

PMCID = 10313851

Title = Linocin M18 protein from the insect pathogenic bacterium Brevibacillus laterosporus isolates

Brevibacillus laterosporus (Bl) is a Gram-positive and spore-forming bacterium. Insect pathogenic strains have been characterised in New Zealand, and two isolates, Bl 1821L and Bl 1951, are under development for use in biopesticides. However, growth in culture is sometimes disrupted, affecting mass production. Based on previous work, it was hypothesised that Tectiviridae phages might be implicated. While investigating the cause of the disrupted growth, electron micrographs of crude lysates showed structural components of putative phages including capsid and tail-like structures. Sucrose density gradient purification yielded a putative self-killing protein of ~30 kDa. N-terminal sequencing of the ~30 kDa protein identified matches to a predicted 25 kDa hypothetical and a 31.4 kDa putative encapsulating protein homologs, with the genes encoding each protein adjacent in the genomes. BLASTp analysis of the homologs of 31.4 kDa amino acid sequences shared 98.6% amino acid identity to the Linocin M18 bacteriocin family protein of Brevibacterium sp. JNUCC-42. Bioinformatic tools including AMPA and CellPPD defined that the bactericidal potential originated from a putative encapsulating protein. Antagonistic activity of the ~30 kDa encapsulating protein of Bl 1821L and Bl 1951during growth in broth exhibited bacterial autolytic activity. LIVE/DEAD staining of Bl 1821L cells after treatment with the ~30 kDa encapsulating protein of Bl 1821L substantiated the findings by showing 58.8% cells with the compromised cell membranes as compared to 37.5% cells in the control. Furthermore, antibacterial activity of the identified proteins of Bl 1821L was validated through gene expression in a Gram-positive bacterium Bacillus subtilis WB800N.

• Gene encoding the 31.4 kDa antibacterial Linocin M18 protein was identified

• It defined the autocidal activity of Linocin M18 (encapsulating) protein

• Identified the possible killing mechanism of the encapsulins

The online version contains supplementary material available at 10.1007/s00253-023-12563-8.

[end paper 47]

[begin paper 48]

PMCID = 10370184

Title = Deciphering Phage-Host Specificity Based on the Association of Phage Depolymerases and Bacterial Surface Glycan with Deep Learning

Phage tailspike proteins are depolymerases that target diverse bacterial surface glycans with high specificity, determining the host-specificity of numerous phages. To address the challenge of identifying tailspike proteins due to their sequence diversity, we developed SpikeHunter, an approach based on the ESM-2 protein language model. Using SpikeHunter, we successfully identified 231,965 tailspike proteins from a dataset comprising 8,434,494 prophages found within 165,365 genomes of five common pathogens. Among these proteins, 143,035 tailspike proteins displayed strong associations with serotypes. Moreover, we observed highly similar tailspike proteins in species that share closely related serotypes. We found extensive domain swapping in all five species, with the C-terminal domain being significantly associated with host serotype highlighting its role in host range determination. Our study presents a comprehensive cross-species analysis of tailspike protein to serotype associations, providing insights applicable to phage therapy and biotechnology.

[end paper 48]

[begin paper 49]

PMCID = 7536135

Title = The novel SARS-CoV-2 pandemic: Possible environmental transmission, detection, persistence and fate during wastewater and water treatment

The contagious SARS-CoV-2 virus, responsible for COVID-19 disease, has infected over 27 million people across the globe within a few months. While literature on SARS-CoV-2 indicates that its transmission may occur predominantly via aerosolization of virus-laden droplets, the possibility of alternate routes of transmission and/or reinfection via the environment requires considerable scientific attention. This review aims to collate information on possible transmission routes of this virus, to ascertain its fate in the environment. Concomitant with the presence of SARS-CoV-2 viral RNA in faeces and saliva of infected patients, studies also indicated its occurrence in raw wastewater, primary sludge and river water. Therefore sewerage system could be a possible route of virus outbreak, a possible tool to assess viral community spread and future surveillance technique. Hence, this review looked into detection, occurrence and fate of SARS-CoV-2 during primary, secondary, and tertiary wastewater and water treatment processes based on published literature on SARS-CoV and other enveloped viruses. The review also highlights the need for focused research on occurrence and fate of SARS-CoV-2 in various environmental matrices. Utilization of this information in environmental transmission models developed for other enveloped and enteric viruses can facilitate risk assessment studies. Preliminary research efforts with SARS-CoV-2 and established scientific reports on other coronaviruses indicate that the threat of virus transmission from the aquatic environment may be currently non-existent. However, the presence of viral RNA in wastewater provides an early warning that highlights the need for effective sewage treatment to prevent a future outbreak of SARS-CoV-2.

[end paper 49]

[begin paper 50]

PMCID = 10869273

Title = Efficient evolution of human antibodies from general protein language models

Natural evolution must explore a vast landscape of possible sequences for desirable yet rare mutations, suggesting that learning from natural evolutionary strategies could guide artificial evolution. Here we report that general protein language models can efficiently evolve human antibodies by suggesting mutations that are evolutionarily plausible, despite providing the model with no information about the target antigen, binding specificity or protein structure. We performed language-model-guided affinity maturation of seven antibodies, screening 20 or fewer variants of each antibody across only two rounds of laboratory evolution, and improved the binding affinities of four clinically relevant, highly mature antibodies up to sevenfold and three unmatured antibodies up to 160-fold, with many designs also demonstrating favorable thermostability and viral neutralization activity against Ebola and severe acute respiratory syndrome coronavirus 2 (SARS-CoV-2) pseudoviruses. The same models that improve antibody binding also guide efficient evolution across diverse protein families and selection pressures, including antibiotic resistance and enzyme activity, suggesting that these results generalize to many settings.

A general protein language model guides protein evolution with 20 or fewer variants needed for testing.

[end paper 50]

[begin paper 51]

PMCID = 7183142

Title = Proteomic profiling of exosomes derived from plasma of HIV- infected alcohol drinkers and cigarette smokers

Abuse of alcohol and tobacco could exacerbate HIV pathogenesis by transferring materials through exosomes (small nanovesicles). Exosomes present a stable and accessible source of information concerning the health and/or disease status of patients, which can provide diagnostic and prognostic biomarkers for myriad conditions. Therefore, we aimed to study the specific exosomal proteins, which are altered in both HIV-infected subjects and alcohol/tobacco users. Exosomes were isolated from plasma of the following subjects: a) HIV-negative subjects (healthy), b) HIV-positive subjects (HIV), c) HIV-negative alcohol drinkers (drinkers), d) HIV-negative tobacco smokers (smokers), e) HIV-positive drinkers (HIV+drinkers), and f) HIV-positive smokers (HIV+smokers). Quantitative proteomic profiling was then performed from these exosomes. Sixteen proteins were significantly altered in the HIV group, ten in drinkers, four in HIV+drinkers, and fifteen in smokers compared to healthy subjects. Only one protein, fibulin-1 (FBLN1), was significantly altered in HIV+smokers. Interestingly, hemopexin was not significantly altered in drinkers or HIV patients but was significantly altered in HIV+drinkers. Further, our study is the first to show properdin expression in plasma exosomes, which was decreased in HIV+smokers and HIV+drinkers compared to HIV patients. The present findings suggest that hemopexin and properdin show potential as markers for physiological effects that may arise in HIV-infected individuals who abuse alcohol and tobacco.

This study presents a proteomic analysis of plasma-derived exosomes from HIV-infected alcohol drinkers and smokers. Among the proteins altered due to drug-abuse, hemopexin and properdin were of highest significance. These proteins can be potential biomarkers for co-morbid conditions associated with drug abuse in HIV-patients.

[end paper 51]

[begin paper 52]

PMCID = 9062077

Title = The Basis and Advances in Clinical Application of Cytomegalovirus-Specific Cytotoxic T Cell Immunotherapy for Glioblastoma Multiforme

A high percentage of malignant gliomas are infected by human cytomegalovirus (HCMV), and the endogenous expression of HCMV genes and their products are found in these tumors. HCMV antigen expression and its implications in gliomagenesis have emerged as a promising target for adoptive cellular immunotherapy (ACT) strategies in glioblastoma multiforme (GB) patients. Since antigen-specific T cells in the tumor microenvironments lack efficient anti-tumor immune response due to the immunosuppressive nature of glioblastoma, CMV-specific ACT relies on in vitro expansion of CMV-specific CD8+ T cells employing immunodominant HCMV antigens. Given the fact that several hurdles remain to be conquered, recent clinical trials have outlined the feasibility of CMV-specific ACT prior to tumor recurrence with minimal adverse effects and a substantial improvement in median overall survival and progression-free survival. This review discusses the role of HCMV in gliomagenesis, disease prognosis, and recent breakthroughs in harnessing HCMV-induced immunogenicity in the GB tumor microenvironment to develop effective CMV-specific ACT.

[end paper 52]

[begin paper 53]

PMCID = 11507661

Title = SeqDance: A Protein Language Model for Representing Protein Dynamic Properties

Proteins perform their functions by folding amino acid sequences into dynamic structural ensembles. Despite the important role of protein dynamics, their complexity and the absence of efficient representation methods have limited their integration into studies on protein function and mutation fitness, especially in deep learning applications. To address this, we present SeqDance, a protein language model designed to learn representation of protein dynamic properties directly from sequence alone. SeqDance is pre-trained on dynamic biophysical properties derived from over 30,400 molecular dynamics trajectories and 28,600 normal mode analyses. Our results show that SeqDance effectively captures local dynamic interactions, co-movement patterns, and global conformational features, even for proteins lacking homologs in the pre-training set. Additionally, we showed that SeqDance enhances the prediction of protein fitness landscapes, disorder-to-order transition binding regions, and phase-separating proteins. By learning dynamic properties from sequence, SeqDance complements conventional evolution- and static structure-based methods, offering new insights into protein behavior and function.

[end paper 53]

[begin paper 54]

PMCID = 11750110

Title = Connectome-based biophysical models of pathological protein spreading in neurodegenerative diseases

Neurodegenerative diseases are a group of disorders characterized by progressive degeneration or death of neurons. The complexity of clinical symptoms and irreversibility of disease progression significantly affects individual lives, leading to premature mortality. The prevalence of neurodegenerative diseases keeps increasing, yet the specific pathogenic mechanisms remain incompletely understood and effective treatment strategies are lacking. In recent years, convergent experimental evidence supports the “prion-like transmission” assumption that abnormal proteins induce misfolding of normal proteins, and these misfolded proteins propagate throughout the neural networks to cause neuronal death. To elucidate this dynamic process in vivo from a computational perspective, researchers have proposed three connectome-based biophysical models to simulate the spread of pathological proteins: the Network Diffusion Model, the Epidemic Spreading Model, and the agent-based Susceptible-Infectious-Removed model. These models have demonstrated promising predictive capabilities. This review focuses on the explanations of their fundamental principles and applications. Then, we compare the strengths and weaknesses of the models. Building upon this foundation, we introduce new directions for model optimization and propose a unified framework for the evaluation of connectome-based biophysical models. We expect that this review could lower the entry barrier for researchers in this field, accelerate model optimization, and thereby advance the clinical translation of connectome-based biophysical models.

[end paper 54]

[begin paper 55]

PMCID = 11140922

Title = Genetics of flight in spongy moths (Lymantria dispar ssp.): functionally integrated profiling of a complex invasive trait

Flight can drastically enhance dispersal capacity and is a key trait defining the potential of exotic insect species to spread and invade new habitats. The phytophagous European spongy moths (ESM, Lymantria dispar dispar) and Asian spongy moths (ASM; a multi–species group represented here by L. d. asiatica and L. d. japonica), are globally invasive species that vary in adult female flight capability—female ASM are typically flight capable, whereas female ESM are typically flightless. Genetic markers of flight capability would supply a powerful tool for flight profiling of these species at any intercepted life stage. To assess the functional complexity of spongy moth flight and to identify potential markers of flight capability, we used multiple genetic approaches aimed at capturing complementary signals of putative flight–relevant genetic divergence between ESM and ASM: reduced representation genome–wide association studies, whole genome sequence comparisons, and developmental transcriptomics. We then judged the candidacy of flight–associated genes through functional analyses aimed at addressing the proximate demands of flight and salient features of the ecological context of spongy moth flight evolution.

Candidate gene sets were typically non–overlapping across different genetic approaches, with only nine gene annotations shared between any pair of approaches. We detected an array of flight–relevant functional themes across gene sets that collectively suggest divergence in flight capability between European and Asian spongy moth lineages has coincided with evolutionary differentiation in multiple aspects of flight development, execution, and surrounding life history. Overall, our results indicate that spongy moth flight evolution has shaped or been influenced by a large and functionally broad network of traits.

Our study identified a suite of flight–associated genes in spongy moths suited to exploration of the genetic architecture and evolution of flight, or validation for flight profiling purposes. This work illustrates how complementary genetic approaches combined with phenotypically targeted functional analyses can help to characterize genetically complex traits.

The online version contains supplementary material available at 10.1186/s12864-023-09936-8.

[end paper 55]

[begin paper 56]

PMCID = 10029925

Title = Exploring microbial functional biodiversity at the protein family level—From metagenomic sequence reads to annotated protein clusters

Metagenomics has enabled accessing the genetic repertoire of natural microbial communities. Metagenome shotgun sequencing has become the method of choice for studying and classifying microorganisms from various environments. To this end, several methods have been developed to process and analyze the sequence data from raw reads to end-products such as predicted protein sequences or families. In this article, we provide a thorough review to simplify such processes and discuss the alternative methodologies that can be followed in order to explore biodiversity at the protein family level. We provide details for analysis tools and we comment on their scalability as well as their advantages and disadvantages. Finally, we report the available data repositories and recommend various approaches for protein family annotation related to phylogenetic distribution, structure prediction and metadata enrichment.

[end paper 56]

[begin paper 57]

PMCID = 9066385

Title = Artificial Neural Network-Based Study Predicts GS-441524 as a Potential Inhibitor of SARS-CoV-2 Activator Protein Furin: a Polypharmacology Approach

Furin, a pro-protein convertase, plays a significant role as a biological scissor in bacterial, viral, and even mammalian substrates which in turn decides the fate of many viral and bacterial infections along with the numerous ailments caused by cancer, diabetes, inflammations, and neurological disorders. In the wake of the current pandemic caused by the virus SARS-CoV-2, furin has become the center of attraction for researchers as the spike protein contains a polybasic furin cleavage site. In the present work, we have searched for novel inhibitors against this interesting human target from FDA-approved antiviral. To enhance the selection of new inhibitors, we employed Kohonen’s artificial neural network-based self-organizing maps for ligand-based virtual screening. Promising results were obtained which can help in drug repurposing and network pharmacology studies can address the errors generated due to promiscuity/polypharmacology. We found 15 existing FDA antiviral drugs having the potential to inhibit furin. Among these, six compounds have targets on important human proteins (LDLR, FCGR1A, PCK1, TLR7, DNA, and PNP). The role of these 15 drugs inhibiting furin can be established by studying further on patients infected with number of viruses including SARS-CoV-2. Here we propose two promising candidate FDA drugs GS-441524 and Grazoprevir (MK-5172) for repurposing as inhibitors of furin. The best results were observed with GS-441524.

The online version contains supplementary material available at 10.1007/s12010-022-03928-2.

[end paper 57]

[begin paper 58]

PMCID = 10440047

Title = Single-sequence protein structure prediction using language models and deep learning

AlphaFold2 and related computational systems predict protein structure using deep learning and co-evolutionary relationships encoded in multiple sequence alignments (MSAs). Despite dramatic increases in prediction accuracy achieved by these systems, challenges remain in: (i) prediction of orphan and rapidly evolving proteins for which an MSA cannot be generated, (ii) rapid exploration of designed structures, and (iii) understanding the rules governing spontaneous polypeptide folding in solution. Here we report development of an end-to-end differentiable recurrent geometric network (RGN) that uses a protein language model (AminoBERT) to learn latent structural information from unaligned proteins. A linked geometric module compactly represents Cα backbone geometry. On average RGN2 outperforms AlphaFold2 and RoseTTAFold on orphan proteins and classes of designed proteins while achieving up to a 106-fold reduction in compute time. These findings demonstrate the practical and theoretical strengths of protein language models relative to MSAs in structure prediction.

[end paper 58]

[begin paper 59]

PMCID = 8883239

Title = In silico studies on structural inhibition of SARS-CoV-2 main protease Mpro by major secondary metabolites of Andrographis paniculata and Cinchona officinalis

The COVID-19 infection by Novel Corona Virus (SARS-CoV-2) has become one of the largest pandemic diseases, with cumulative confirmed infections of 275,233,892 and 5,364,996 deaths to date according to World Health Organization. Due to the absence of any approved antiviral drug to treat COVID-19, its lethality is getting severe with time. The main protease of SARS-CoV-2, Mpro is considered one of the potential drug targets because of its role in processing proteins translated from viral RNA. In the present study, four of the plant metabolites, 14-deoxy-11,12-didehydroandrographolide, andrograpanin, quinine, cinchonine from two eminent medicinal plants Andrographis paniculata and Cinchona officinalis, have been evaluated against the main protease of SARS-CoV-2 through in-silico molecular docking and molecular dynamics simulation study. From the result interpretations, it is found that andrograpanin has strong binding affinities with the target protein in its active site with potential negative energies. Molecular Dynamic simulation and MMGBSA studies suggest that earlier reported N3 inhibitor and andrograpanin exhibit effective binding interactions involving identical amino acid residues with the same binding pockets of the main protease of SARS-CoV-2. Therefore, the theoretical experiment suggests that andrograpanin, could be considered the promising inhibitor against SARS-CoV-2 Mpro.

The online version contains supplementary material available at 10.1007/s11756-022-01012-y.

[end paper 59]

[begin paper 60]

PMCID = 10456983

Title = Persistent spectral theory-guided protein engineering

While protein engineering, which iteratively optimizes protein fitness by screening the gigantic mutational space, is constrained by experimental capacity, various machine learning models have substantially expedited protein engineering. Three-dimensional protein structures promise further advantages, but their intricate geometric complexity hinders their applications in deep mutational screening. Persistent homology, an established algebraic topology tool for protein structural complexity reduction, fails to capture the homotopic shape evolution during the filtration of a given data. This work introduces a Topology-offered protein Fitness (TopFit) framework to complement protein sequence and structure embeddings. Equipped with an ensemble regression strategy, TopFit integrates the persistent spectral theory, a new topological Laplacian, and two auxiliary sequence embeddings to capture mutation-induced topological invariant, shape evolution, and sequence disparity in the protein fitness landscape. The performance of TopFit is assessed by 34 benchmark datasets with 128,634 variants, involving a vast variety of protein structure acquisition modalities and training set size variations.

[end paper 60]

[begin paper 61]

PMCID = 10592750

Title = Harnessing Generative AI to Decode Enzyme Catalysis and Evolution for Enhanced Engineering

Enzymes, as paramount protein catalysts, occupy a central role in fostering remarkable progress across numerous fields. However, the intricacy of sequence-function relationships continues to obscure our grasp of enzyme behaviors and curtails our capabilities in rational enzyme engineering. Generative artificial intelligence (AI), known for its proficiency in handling intricate data distributions, holds the potential to offer novel perspectives in enzyme research. By applying generative models, we could discern elusive patterns within the vast sequence space and uncover new functional enzyme sequences. This review highlights the recent advancements in employing generative AI for enzyme sequence analysis. We delve into the impact of generative AI in predicting mutation effects on enzyme fitness, activity, and stability, rationalizing the laboratory evolution of de novo enzymes, decoding protein sequence semantics, and its applications in enzyme engineering. Notably, the prediction of enzyme activity and stability using natural enzyme sequences serves as a vital link, indicating how enzyme catalysis shapes enzyme evolution. Overall, we foresee that the integration of generative AI into enzyme studies will remarkably enhance our knowledge of enzymes and expedite the creation of superior biocatalysts.

[end paper 61]

[begin paper 62]

PMCID = 8069921

Title = Utilization of Eggshell Membrane and Olive Leaf Extract for the Preparation of Functional Materials

Eggshell membrane (ESM) is a natural proteinaceous by-product of the food industry, especially in the pasteurized egg industry, resulting in the availability of much discarded egg waste. In the literature, eggshell (ES) and ESM usage for their adsorbent properties to remove various organic and inorganic hazardous chemicals, especially from wastewater, has gained interest. In addition, agricultural (olive leaf) and food industry (eggshell and eggshell membrane) waste can together be valorized to produce value-added functional products. This study’s objective was to evaluate the eggshell membrane’s loading capacity for bioactive compounds obtained from olive leaf extract (OLE) in order to prepare functional biomaterial. In this study, waste eggshell membranes were used to adsorb the phenolic compounds from olive leaf extract to design functional biomaterials. Using the foam separation method, both separation of the eggshell membrane and adsorption of bioactive compounds to the eggshell membrane were achieved simultaneously. The characterization studies showed that OLE was successfully adsorbed to the eggshell membrane. Cytotoxicity and antimicrobial studies showed that prepared OLE-loaded membranes were functional materials with bioactive properties. In conclusion, ESM was determined as a promising protein in the production of functional antioxidative and antimicrobial food or dietary supplement after the adsorption of bioactive olive leaf polyphenols.

[end paper 62]

[begin paper 63]

PMCID = 10997877

Title = Databases of ligand-binding pockets and protein-ligand interactions

Many research groups and institutions have created a variety of databases curating experimental and predicted data related to protein-ligand binding. The landscape of available databases is dynamic, with new databases emerging and established databases becoming defunct. Here, we review the current state of databases that contain binding pockets and protein-ligand binding interactions. We have compiled a list of such databases, fifty-three of which are currently available for use. We discuss variation in how binding pockets are defined and summarize pocket-finding methods. We organize the fifty-three databases into subgroups based on goals and contents, and describe standard use cases. We also illustrate that pockets within the same protein are characterized differently across different databases. Finally, we assess critical issues of sustainability, accessibility and redundancy.

[end paper 63]

[begin paper 64]

PMCID = 11566746

Title = T4Seeker: a hybrid model for type IV secretion effectors identification

The type IV secretion system is widely present in various bacteria, such as Salmonella, Escherichia coli, and Helicobacter pylori. These bacteria use the type IV secretion system to secrete type IV secretion effectors, infect host cells, and disrupt or modulate the communication pathways. In this study, type III and type VI secretion effectors were used as negative samples to train a robust model.

The area under the curve of T4Seeker on the validation and independent test sets were 0.947 and 0.970, respectively, demonstrating the strong predictive capacity and robustness of T4Seeker. After comparing with the classic and state-of-the-art T4SE identification models, we found that T4Seeker, which is based on traditional features and large language model features, had a higher predictive ability.

The T4Seeker proposed in this study demonstrates superior performance in the field of T4SEs prediction. By integrating features at multiple levels, it achieves higher predictive accuracy and strong generalization capability, providing an effective tool for future T4SE research.

[end paper 64]

[begin paper 65]

PMCID = 11340954

Title = PredIL13: Stacking a variety of machine and deep learning methods with ESM-2 language model for identifying IL13-inducing peptides

Interleukin (IL)-13 has emerged as one of the recently identified cytokine. Since IL-13 causes the severity of COVID-19 and alters crucial biological processes, it is urgent to explore novel molecules or peptides capable of including IL-13. Computational prediction has received attention as a complementary method to in-vivo and in-vitro experimental identification of IL-13 inducing peptides, because experimental identification is time-consuming, laborious, and expensive. A few computational tools have been presented, including the IL13Pred and iIL13Pred. To increase prediction capability, we have developed PredIL13, a cutting-edge ensemble learning method with the latest ESM-2 protein language model. This method stacked the probability scores outputted by 168 single-feature machine/deep learning models, and then trained a logistic regression-based meta-classifier with the stacked probability score vectors. The key technology was to implement ESM-2 and to select the optimal single-feature models according to their absolute weight coefficient for logistic regression (AWCLR), an indicator of the importance of each single-feature model. Especially, the sequential deletion of single-feature models based on the iterative AWCLR ranking (SDIWC) method constructed the meta-classifier consisting of the top 16 single-feature models, named PredIL13, while considering the model’s accuracy. The PredIL13 greatly outperformed the-state-of-the-art predictors, thus is an invaluable tool for accelerating the detection of IL13-inducing peptide within the human genome.

[end paper 65]

[begin paper 66]

PMCID = 9362051

Title = Viruses of Atlantic Bonefish (Albula vulpes) in Florida and the Caribbean show geographic patterns consistent with population declines

Atlantic Bonefish (Albula vulpes) are economically important due to their popularity with recreational anglers. In the State of Florida, USA, bonefish population numbers declined by approximately 60% between the 1990s and 2015. Habitat loss, water quality impairment, chemical inputs, and other anthropogenic factors have been implicated as causes, but the role of pathogens has been largely overlooked, especially with respect to viruses. We used a metagenomic approach to identify and quantify viruses in the blood of 103 A. vulpes sampled throughout their Western Atlantic range, including populations in Florida that have experienced population declines and populations in Belize, Mexico, Puerto Rico, and The Bahamas that have remained apparently stable. We identified four viruses, all of which are members of families known to infect marine fishes (Flaviviridae, Iflaviridae, Narnaviridae, and Nodaviridae), but all of which were previously undescribed. Bonefish from Florida and Mexico had higher viral richness (numbers of distinct viruses per individual fish) than fish sampled from other areas, and bonefish from the Upper Florida Keys had the highest prevalence of viral infection (proportion of positive fish) than fish sampled from any other location. Bonefish from Florida also had markedly higher viral loads than fish sampled from any other area, both for a novel narnavirus and for all viruses combined. Bonefish viruses may be indicators of environmentally driven physiological and immunological compromise, causes of ill health, or both.

The online version contains supplementary material available at 10.1007/s10641-022-01306-9.

[end paper 66]

[begin paper 67]

PMCID = 7979453

Title = Docking and in silico toxicity assessment of Arthrospira compounds as potential antiviral agents against SARS-CoV-2

A race is currently being launched as a result of the international health situation. This race aims to find, by various means, weapons to counter the Covid-19 pandemic now widespread on all continents. The aquatic world and in particular that of photosynthetic organisms is regularly highlighted but paradoxically little exploited in view of the tremendous possibilities it offers. Computational tools allow not only to clear the existence and activity of many molecules but also to model their relationships with receptors identified in potential hosts. On a routine basis, our laboratory carries out a research activity on functionalities of molecules derived from algae using in silico tools. We have implemented our skills in algae biology and in modeling, as tests in order to identify molecules expressed by the genus Arthrospira showing an antiviral potential and more particularly anti-SARS-CoV-2. Using consensus docking and redocking with Autodock Vina and SwissDock, we were able to identify several promising molecules from Arthrospira: phycocyanobilin, phycoerythrobilin, phycourobilin, and folic acid. These four compounds showed reliable binding energies comprised between − 6.95 and − 7.45 kcal.mol−1 in Autodock Vina and between − 9.285 and − 10.35 kcal.mol−1 with SwissDock. Toxicity prediction as well as current regulations provided promising arguments for the inclusion of these compounds in further studies to assess their ability to compete with the SARS-CoV-2/ACE2 complex both in vitro and in vivo.

The online version contains supplementary material available at 10.1007/s10811-021-02372-9.

[end paper 67]

[begin paper 68]

PMCID = 11751191

Title = Paying attention to the SARS-CoV-2 dialect : a deep neural network approach to predicting novel protein mutations

Predicting novel mutations has long-lasting impacts on life science research. Traditionally, this problem is addressed through wet-lab experiments, which are often expensive and time consuming. The recent advancement in neural language models has provided stunning results in modeling and deciphering sequences. In this paper, we propose a Deep Novel Mutation Search (DNMS) method, using deep neural networks, to model protein sequence for mutation prediction. We use SARS-CoV-2 spike protein as the target and use a protein language model to predict novel mutations. Different from existing research which is often limited to mutating the reference sequence for prediction, we propose a parent-child mutation prediction paradigm where a parent sequence is modeled for mutation prediction. Because mutations introduce changing context to the underlying sequence, DNMS models three aspects of the protein sequences: semantic changes, grammatical changes, and attention changes, each modeling protein sequence aspects from shifting of semantics, grammar coherence, and amino-acid interactions in latent space. A ranking approach is proposed to combine all three aspects to capture mutations demonstrating evolving traits, in accordance with real-world SARS-CoV-2 spike protein sequence evolution. DNMS can be adopted for an early warning variant detection system, creating public health awareness of future SARS-CoV-2 mutations.

Elkin and Zhu propose a Deep Novel Mutation Search (DNMS) method, using deep neural networks to model SARS-CoV-2 spike protein sequence for novel mutation prediction, by calculating semantic change, attention change, and grammaticality of an amino acid sequence to rank all possible substitutions.

[end paper 68]

[begin paper 69]

PMCID = 9963931

Title = The Dynamic Linkage between Provirus Integration Sites and the Host Functional Genome Property Alongside HIV-1 Infections Associated with Antiretroviral Therapy

(1) Background: The HIV-1 latent reservoir harboring replication-competent proviruses is the major barrier in the quest for an HIV-1 infection cure. HIV-1 infection at all stages of disease progression is associated with immune activation and dysfunctional production of proinflammatory soluble factors (cytokines and chemokines), and it is expected that during HIV-1 infection, different immune components and immune cells, in turn, participate in immune responses, subsequently activating downstream biological pathways. However, the functional interaction between HIV-1 integration and the activation of host biological pathways is presently not fully understood. (2) Methods: In this work, I used genes targeted by proviruses from published datasets to seek enriched immunologic signatures and host biological pathways alongside HIV-1 infections based on MSigDb and KEGG over-representation analysis. (3) Results: I observed that different combinations of immunologic signatures of immune cell types and proinflammatory soluble factors appeared alongside HIV-1 infections associated with antiretroviral therapy. Moreover, enriched KEGG pathways were often related to “cancer specific types”, “immune system”, “infectious disease viral”, and “signal transduction”. (4) Conclusions: The observations in this work suggest that the gene sets harboring provirus integration sites may define specific immune cells and proinflammatory soluble factors during HIV-1 infections associated with antiretroviral therapy.

[end paper 69]

[begin paper 70]

PMCID = 8105700

Title = Analysis of natural compounds against the activity of SARS-CoV-2 NSP15 protein towards an effective treatment against COVID-19: a theoretical and computational biology approach

Coronavirus infectious disease 2019 (COVID-19), a viral infection caused by a novel coronavirus (nCoV), continues to emerge as a serious threat to public health. This pandemic caused by SARS-CoV-2 (severe acute respiratory syndrome–coronavirus-2) has infected globally with 1,550,000 plus deaths to date, representing a high risk to public health. No effective drug or vaccine is available to curb down this deadly virus. The expedition for searching for a potential drug or vaccine against COVID-19 is of massive potential and favour to the community. This study is focused on finding an effective natural compound that can be processed further into a potential inhibitor to check the activity of SARS-CoV-2 with minimal side effects targeting NSP15 protein, which belongs to the EndoU enzyme family. The natural screening suggested two efficient compounds (PubChem ID: 95372568 and 1776037) with dihydroxyphenyl region of the compound, found to be important in the interaction with the viral protein showing promising activity which may act as a potent lead inhibitory molecule against the virus. In combination with virtual screening, modelling, drug likeliness, molecular docking, and 500 ns cumulative molecular dynamics simulations (100 ns for each complex) along with the decomposition analysis to calculate and confirm the stability and fold, we propose 95372568 and 1776037 as novel compounds of natural origin capable of getting developed into potent lead molecules against SARS-CoV-2 target protein NSP15.

The online version contains supplementary material available at 10.1007/s00894-021-04750-z.

[end paper 70]

[begin paper 71]

PMCID = 10365317

Title = Protein embeddings improve phage-host interaction prediction

With the growing interest in using phages to combat antimicrobial resistance, computational methods for predicting phage-host interactions have been explored to help shortlist candidate phages. Most existing models consider entire proteomes and rely on manual feature engineering, which poses difficulty in selecting the most informative sequence properties to serve as input to the model. In this paper, we framed phage-host interaction prediction as a multiclass classification problem that takes as input the embeddings of a phage’s receptor-binding proteins, which are known to be the key machinery for host recognition, and predicts the host genus. We explored different protein language models to automatically encode these protein sequences into dense embeddings without the need for additional alignment or structural information. We show that the use of embeddings of receptor-binding proteins presents improvements over handcrafted genomic and protein sequence features. The highest performance was obtained using the transformer-based protein language model ProtT5, resulting in a 3% to 4% increase in weighted F1 and recall scores across different prediction confidence thresholds, compared to using selected handcrafted sequence features.

[end paper 71]

[begin paper 72]

PMCID = 11331094

Title = Leveraging a large language model to predict protein phase transition: A physical, multiscale, and interpretable approach

Protein phase transition (PPT) is a physical mechanism associated with both physiological processes and age-related diseases. We present a modeling approach for predicting the protein propensity to undergo PPT, forming droplets or amyloids, directly from its sequence. We utilize a large language model (LLM) and demonstrate how variants within the protein sequence affect PPT. Because the LLM is naturally domain-agnostic, to enhance interpretability, we compare it with a classical knowledge-based model. Furthermore, our findings suggest the possible regulation of PPT by gene expression and transcription factors, hinting at potential targets for drug development. Our approach demonstrates the usefulness of fine-tuning a LLM for downstream tasks where only small datasets are available.

Protein phase transitions (PPTs) from the soluble state to a dense liquid phase (forming droplets via liquid–liquid phase separation) or to solid aggregates (such as amyloids) play key roles in pathological processes associated with age-related diseases such as Alzheimer’s disease. Several computational frameworks are capable of separately predicting the formation of droplets or amyloid aggregates based on protein sequences, yet none have tackled the prediction of both within a unified framework. Recently, large language models (LLMs) have exhibited great success in protein structure prediction; however, they have not yet been used for PPTs. Here, we fine-tune a LLM for predicting PPTs and demonstrate its usage in evaluating how sequence variants affect PPTs, an operation useful for protein design. In addition, we show its superior performance compared to suitable classical benchmarks. Due to the “black-box” nature of the LLM, we also employ a classical random forest model along with biophysical features to facilitate interpretation. Finally, focusing on Alzheimer’s disease-related proteins, we demonstrate that greater aggregation is associated with reduced gene expression in Alzheimer’s disease, suggesting a natural defense mechanism.

[end paper 72]

[begin paper 73]

PMCID = 9916901

Title = Exploring AlphaFold2′s Performance on Predicting Amino Acid Side-Chain Conformations and Its Utility in Crystal Structure Determination of B318L Protein

Recent technological breakthroughs in machine-learning-based AlphaFold2 (AF2) are pushing the prediction accuracy of protein structures to an unprecedented level that is on par with experimental structural quality. Despite its outstanding structural modeling capability, further experimental validations and performance assessments of AF2 predictions are still required, thus necessitating the development of integrative structural biology in synergy with both computational and experimental methods. Focusing on the B318L protein that plays an essential role in the African swine fever virus (ASFV) for viral replication, we experimentally demonstrate the high quality of the AF2 predicted model and its practical utility in crystal structural determination. Structural alignment implies that the AF2 model shares nearly the same atomic arrangement as the B318L crystal structure except for some flexible and disordered regions. More importantly, side-chain-based analysis at the individual residue level reveals that AF2′s performance is likely dependent on the specific amino acid type and that hydrophobic residues tend to be more accurately predicted by AF2 than hydrophilic residues. Quantitative per-residue RMSD comparisons and further molecular replacement trials suggest that AF2 has a large potential to outperform other computational modeling methods in terms of structural determination. Additionally, it is numerically confirmed that the AF2 model is accurate enough so that it may well potentially withstand experimental data quality to a large extent for structural determination. Finally, an overall structural analysis and molecular docking simulation of the B318L protein are performed. Taken together, our study not only provides new insights into AF2′s performance in predicting side-chain conformations but also sheds light upon the significance of AF2 in promoting crystal structural determination, especially when the experimental data quality of the protein crystal is poor.

[end paper 73]

[begin paper 74]

PMCID = 11685842

Title = Protein engineering in the deep learning era

Advances in deep learning have significantly aided protein engineering in addressing challenges in industrial production, healthcare, and environmental sustainability. This review frames frequently researched problems in protein understanding and engineering from the perspective of deep learning. It provides a thorough discussion of representation methods for protein sequences and structures, along with general encoding pipelines that support both pre‐training and supervised learning tasks. We summarize state‐of‐the‐art protein language models, geometric deep learning techniques, and the combination of distinct approaches to learning from multi‐modal biological data. Additionally, we outline common downstream tasks and relevant benchmark datasets for training and evaluating deep learning models, focusing on satisfying the particular needs of protein engineering applications, such as identifying mutation sites and predicting properties for candidates' virtual screening. This review offers biologists the latest tools for assisting their engineering projects while providing a clear and comprehensive guide for computer scientists to develop more powerful solutions by standardizing problem formulation and consolidating data resources. Future research can foresee a deeper integration of the communities of biology and computer science, unleashing the full potential of deep learning in protein engineering and driving new scientific breakthroughs.

[end paper 74]

[begin paper 75]

PMCID = 11275896

Title = Rapid protein evolution by few-shot learning with a protein language model

Directed evolution of proteins is critical for applications in basic biological research, therapeutics, diagnostics, and sustainability. However, directed evolution methods are labor intensive, cannot efficiently optimize over multiple protein properties, and are often trapped by local maxima. In silico-directed evolution methods incorporating protein language models (PLMs) have the potential to accelerate this engineering process, but current approaches fail to generalize across diverse protein families. We introduce EVOLVEpro, a few-shot active learning framework to rapidly improve protein activity using a combination of PLMs and protein activity predictors, achieving improved activity with as few as four rounds of evolution. EVOLVEpro substantially enhances the efficiency and effectiveness of in silico protein evolution, surpassing current state-of-the-art methods and yielding proteins with up to 100-fold improvement of desired properties. We showcase EVOLVEpro for five proteins across three applications: T7 RNA polymerase for RNA production, a miniature CRISPR nuclease, a prime editor, and an integrase for genome editing, and a monoclonal antibody for epitope binding. These results demonstrate the advantages of few-shot active learning with small amounts of experimental data over zero-shot predictions. EVOLVEpro paves the way for broader applications of AI-guided protein engineering in biology and medicine.

[end paper 75]

[begin paper 76]

PMCID = 11794456

Title = DeepPFP: a multi-task-aware architecture for protein function prediction

Deriving protein function from protein sequences poses a significant challenge due to the intricate relationship between sequence and function. Deep learning has made remarkable strides in predicting sequence-function relationships. However, models tailored for specific tasks or protein types encounter difficulties when using transfer learning across domains. This is attributed to the fact that protein function relies heavily on structural characteristics rather than mere sequence information. Consequently, there is a pressing need for a model capable of capturing shared features among diverse sequence-function mapping tasks to address the generalization issue. In this study, we explore the potential of Model-Agnostic Meta-Learning combined with a protein language model called Evolutionary Scale Modeling to tackle this challenge. Our approach involves training the architecture on five out-domain deep mutational scanning (DMS) datasets and evaluating its performance across four key dimensions. Our findings demonstrate that the proposed architecture exhibits satisfactory performance in terms of generalization and employs an effective few-shot learning strategy. To explain further, Compared to the best results, the Pearson’s correlation coefficient (PCC) in the final stage increased by ~0.31%. Furthermore, we leverage the trained architecture to predict binding affinity scores of the DMS dataset of SARS-CoV-2 using transfer learning. Notably, training on a subset of the Ube4b dataset with 500 samples resulted in a notable improvement of 0.11 in the PCC. These results underscore the potential of our conceptual architecture as a promising methodology for multi-task protein function prediction.

[end paper 76]

[begin paper 77]

PMCID = 9898993

Title = SESNet: sequence-structure feature-integrated deep learning method for data-efficient protein engineering

Deep learning has been widely used for protein engineering. However, it is limited by the lack of sufficient experimental data to train an accurate model for predicting the functional fitness of high-order mutants. Here, we develop SESNet, a supervised deep-learning model to predict the fitness for protein mutants by leveraging both sequence and structure information, and exploiting attention mechanism. Our model integrates local evolutionary context from homologous sequences, the global evolutionary context encoding rich semantic from the universal protein sequence space and the structure information accounting for the microenvironment around each residue in a protein. We show that SESNet outperforms state-of-the-art models for predicting the sequence-function relationship on 26 deep mutational scanning datasets. More importantly, we propose a data augmentation strategy by leveraging the data from unsupervised models to pre-train our model. After that, our model can achieve strikingly high accuracy in prediction of the fitness of protein mutants, especially for the higher order variants (> 4 mutation sites), when finetuned by using only a small number of experimental mutation data (< 50). The strategy proposed is of great practical value as the required experimental effort, i.e., producing a few tens of experimental mutation data on a given protein, is generally affordable by an ordinary biochemical group and can be applied on almost any protein.

The online version contains supplementary material available at 10.1186/s13321-023-00688-x.

[end paper 77]

[begin paper 78]

PMCID = 10831124

Title = Binding affinity between coronavirus spike protein and human ACE2 receptor

Coronaviruses (CoVs) pose a major risk to global public health due to their ability to infect diverse animal species and potential for emergence in humans. The CoV spike protein mediates viral entry into the cell and plays a crucial role in determining the binding affinity to host cell receptors. With particular emphasis on α- and β-coronaviruses that infect humans and domestic animals, current research on CoV receptor use suggests that the exploitation of the angiotensin-converting enzyme 2 (ACE2) receptor poses a significant threat for viral emergence with pandemic potential. This review summarizes the approaches used to study binding interactions between CoV spike proteins and the human ACE2 (hACE2) receptor. Solid-phase enzyme immunoassays and cell binding assays allow qualitative assessment of binding but lack quantitative evaluation of affinity. Surface plasmon resonance, Bio-layer interferometry, and Microscale Thermophoresis on the other hand, provide accurate affinity measurement through equilibrium dissociation constants (KD). In silico modeling predicts affinity through binding structure modeling, protein-protein docking simulations, and binding energy calculations but reveals inconsistent results due to the lack of a standardized approach. Machine learning and deep learning models utilize simulated and experimental protein-protein interaction data to elucidate the critical residues associated with CoV binding affinity to hACE2. Further optimization and standardization of existing approaches for studying binding affinity could aid pandemic preparedness. Specifically, prioritizing surveillance of CoVs that can bind to human receptors stands to mitigate the risk of zoonotic spillover.

[end paper 78]

[begin paper 79]

PMCID = 10683363

Title = Exploring the promising potential of induced pluripotent stem cells in cancer research and therapy

The advent of iPSCs has brought about a significant transformation in stem cell research, opening up promising avenues for advancing cancer treatment. The formation of cancer is a multifaceted process influenced by genetic, epigenetic, and environmental factors. iPSCs offer a distinctive platform for investigating the origin of cancer, paving the way for novel approaches to cancer treatment, drug testing, and tailored medical interventions. This review article will provide an overview of the science behind iPSCs, the current limitations and challenges in iPSC-based cancer therapy, the ethical and social implications, and the comparative analysis with other stem cell types for cancer treatment. The article will also discuss the applications of iPSCs in tumorigenesis, the future of iPSCs in tumorigenesis research, and highlight successful case studies utilizing iPSCs in tumorigenesis research. The conclusion will summarize the advancements made in iPSC-based tumorigenesis research and the importance of continued investment in iPSC research to unlock the full potential of these cells.

[end paper 79]

[begin paper 80]

PMCID = 11185609

Title = FusOn-pLM: A Fusion Oncoprotein-Specific Language Model via Focused Probabilistic Masking

Fusion oncoproteins, a class of chimeric proteins arising from chromosomal translocations, drive and sustain various cancers, particularly those impacting children. Unfortunately, due to their intrinsically disordered nature, large size, and lack of well-defined, druggable pockets, they have been historically challenging to target therapeutically: neither small molecule-based methods nor structure-based approaches for binder design are strong options for this class of molecules. Recently, protein language models (pLMs) have demonstrated success at representing protein sequences with information-rich embeddings, enabling downstream design applications from sequence alone. However, no current pLM has been trained on fusion oncoprotein sequences and thus may not produce optimal representations for these proteins. In this work, we introduce FusOn-pLM, a novel pLM that fine-tunes the state-of-the-art ESM-2 model on fusion oncoprotein sequences. We specifically introduce a novel masked language modeling (MLM) strategy, employing a binding-site probability predictor to focus masking on key amino acid residues, thereby generating more optimal fusion oncoprotein-aware embeddings. Our model improves performance on both fusion oncoprotein-specific benchmarks and disorder prediction tasks in comparison to baseline ESM-2 representations, as well as manually-constructed biophysical embeddings, motivating downstream usage of FusOn-pLM embeddings for therapeutic design tasks targeting these fusions. We have made our model publicly available to the community at https://huggingface.co/ChatterjeeLab/FusOn-pLM.

[end paper 80]

[begin paper 81]

PMCID = 7079981

Title = Design and application of GB virus C (GBV-C) peptide microarrays for diagnosis of GBV-C/HIV-1 co-infection

The main objectives of the design of GB virus C (GBV-C) peptide microarrays are the miniaturisation of antigen–antibody interaction assays, the simultaneous analysis of several peptide sequences and the reduction in the volume of serum required from patients since this always represents a limiting factor in studies to develop new systems for diagnosing human diseases. We herein report the design of a microarray immunoassay based on synthetic peptides derived from the GBV-C E2 protein to evaluate their diagnostic value in detecting anti-E2 antibodies in HIV-1 patients. To this end, peptide microarrays were initially prepared to identify the most relevant epitopes in the GBV-C E2 protein. Thus, 124 peptides composed of 18 amino acids covering the whole E2-protein sequence, with 15 residue overlaps, were spotted in triplicate onto γ-aminopropyl silane-functionalised adsorbent binding slides. The procedure to select the E2 protein epitopes was carried out using serum samples from HIV-1-infected patients. The samples had previously been tested for the presence or absence of GBV-C anti-E2 antibodies by means of the Abbott test. Thus, 11 specific epitopes in the GBV-C E2 protein were identified. Subsequently, peptide antigen microarrays were constructed using the E2 epitopes identified to detect GBV-C anti-E2 antibodies in the serum of HIV-1-infected patients with no known GBV-C co-infection. The 11 peptides selected identified anti-E2 GBV-C antibodies among HIV-1-infected patients, and a reactivity of 47 % was established. The potential antigenic peptides selected could be considered a useful tool for designing a new diagnostic system based on peptide microarrays to determine anti-GBV-C E2 antibodies in the serum of HIV-1-infected patients.

The online version of this article (doi:10.1007/s00216-012-6585-3) contains supplementary material, which is available to authorized users.

[end paper 81]

[begin paper 82]

PMCID = 9116377

Title = Protein design via deep learning

Proteins with desired functions and properties are important in fields like nanotechnology and biomedicine. De novo protein design enables the production of previously unseen proteins from the ground up and is believed as a key point for handling real social challenges. Recent introduction of deep learning into design methods exhibits a transformative influence and is expected to represent a promising and exciting future direction. In this review, we retrospect the major aspects of current advances in deep-learning-based design procedures and illustrate their novelty in comparison with conventional knowledge-based approaches through noticeable cases. We not only describe deep learning developments in structure-based protein design and direct sequence design, but also highlight recent applications of deep reinforcement learning in protein design. The future perspectives on design goals, challenges and opportunities are also comprehensively discussed.

[end paper 82]

[begin paper 83]

PMCID = 11230163

Title = ProBASS – a language model with sequence and structural features for predicting the effect of mutations on binding affinity

Protein-protein interactions (PPIs) govern virtually all cellular processes. Even a single mutation within PPI can significantly influence overall protein functionality and potentially lead to various types of diseases. To date, numerous approaches have emerged for predicting the change in free energy of binding (ΔΔGbind) resulting from mutations, yet the majority of these methods lack precision. In recent years, protein language models (PLMs) have been developed and shown powerful predictive capabilities by leveraging both sequence and structural data from protein-protein complexes. Yet, PLMs have not been optimized specifically for predicting ΔΔGbind. We developed an approach to predict effects of mutations on PPI binding affinity based on two most advanced protein language models ESM2 and ESM-IF1 that incorporate PPI sequence and structural features, respectively. We used the two models to generate embeddings for each PPI mutant and subsequently fine-tuned our model by training on a large dataset of experimental ΔΔGbind values. Our model, ProBASS (Protein Binding Affinity from Structure and Sequence) achieved a correlation with experimental ΔΔGbind values of 0.83 ± 0.05 for single mutations and 0.69 ± 0.04 for double mutations when model training and testing was done on the same PDB. Moreover, ProBASS exhibited very high correlation (0.81 ± 0.02) between prediction and experiment when training and testing was performed on a dataset containing 2325 single mutations in 132 PPIs. ProBASS surpasses the state-of-the-art methods in correlation with experimental data and could be further trained as more experimental data becomes available. Our results demonstrate that the integration of extensive datasets containing ΔΔGbind values across multiple PPIs to refine the pre-trained PLMs represents a successful approach for achieving a precise and broadly applicable model for ΔΔGbind prediction, greatly facilitating future protein engineering and design studies.

[end paper 83]

[begin paper 84]

PMCID = 8728848

Title = LectinOracle: A Generalizable Deep Learning Model for Lectin–Glycan Binding Prediction

Ranging from bacterial cell adhesion over viral cell entry to human innate immunity, glycan‐binding proteins or lectins are abound in nature. Widely used as staining and characterization reagents in cell biology and crucial for understanding the interactions in biological systems, lectins are a focal point of study in glycobiology. Yet the sheer breadth and depth of specificity for diverse oligosaccharide motifs has made studying lectins a largely piecemeal approach, with few options to generalize. Here, LectinOracle, a model combining transformer‐based representations for proteins and graph convolutional neural networks for glycans to predict their interaction, is presented. Using a curated data set of 564,647 unique protein–glycan interactions, it is shown that LectinOracle predictions agree with literature‐annotated specificities for a wide range of lectins. Using a range of specialized glycan arrays, it is shown that LectinOracle predictions generalize to new glycans and lectins, with qualitative and quantitative agreement with experimental data. It is further demonstrated that LectinOracle can be used to improve lectin classification, accelerate lectin directed evolution, predict epidemiological outcomes in the context of influenza virus, and analyze whole lectomes in host–microbe interactions. It is envisioned that the herein presented platform will advance both the study of lectins and their role in (glyco)biology.

Using a large, curated data set of protein–carbohydrate interactions, a new deep learning model, LectinOracle, is introduced. LectinOracle predicts protein–carbohydrate interactions from their sequences and generalizes to new proteins, carbohydrates, and contexts. Applying LectinOracle to the microbiome and virus epidemics demonstrates its utility for analyzing carbohydrate‐binding proteins in health and disease.  

[end paper 84]

[begin paper 85]

PMCID = 11745544

Title = Twenty years of advances in prediction of nucleic acid-binding residues in protein sequences

Computational prediction of nucleic acid-binding residues in protein sequences is an active field of research, with over 80 methods that were released in the past 2 decades. We identify and discuss 87 sequence-based predictors that include dozens of recently published methods that are surveyed for the first time. We overview historical progress and examine multiple practical issues that include availability and impact of predictors, key features of their predictive models, and important aspects related to their training and assessment. We observe that the past decade has brought increased use of deep neural networks and protein language models, which contributed to substantial gains in the predictive performance. We also highlight advancements in vital and challenging issues that include cross-predictions between deoxyribonucleic acid (DNA)-binding and ribonucleic acid (RNA)-binding residues and targeting the two distinct sources of binding annotations, structure-based versus intrinsic disorder-based. The methods trained on the structure-annotated interactions tend to perform poorly on the disorder-annotated binding and vice versa, with only a few methods that target and perform well across both annotation types. The cross-predictions are a significant problem, with some predictors of DNA-binding or RNA-binding residues indiscriminately predicting interactions with both nucleic acid types. Moreover, we show that methods with web servers are cited substantially more than tools without implementation or with no longer working implementations, motivating the development and long-term maintenance of the web servers. We close by discussing future research directions that aim to drive further progress in this area.

[end paper 85]

[begin paper 86]

PMCID = 11796103

Title = Transitioning from wet lab to artificial intelligence: a systematic review of AI predictors in CRISPR

The revolutionary CRISPR-Cas9 system leverages a programmable guide RNA (gRNA) and Cas9 proteins to precisely cleave problematic regions within DNA sequences. This groundbreaking technology holds immense potential for the development of targeted therapies for a wide range of diseases, including cancers, genetic disorders, and hereditary diseases. CRISPR-Cas9 based genome editing is a multi-step process such as designing a precise gRNA, selecting the appropriate Cas protein, and thoroughly evaluating both on-target and off-target activity of the Cas9-gRNA complex. To ensure the accuracy and effectiveness of CRISPR-Cas9 system, after the targeted DNA cleavage, the process requires careful analysis of the resultant outcomes such as indels and deletions. Following the success of artificial intelligence (AI) in various fields, researchers are now leveraging AI algorithms to catalyze and optimize the multi-step process of CRISPR-Cas9 system. To achieve this goal AI-driven applications are being integrated into each step, but existing AI predictors have limited performance and many steps still rely on expensive and time-consuming wet-lab experiments. The primary reason behind low performance of AI predictors is the gap between CRISPR and AI fields. Effective integration of AI into multi-step CRISPR-Cas9 system demands comprehensive knowledge of both domains. This paper bridges the knowledge gap between AI and CRISPR-Cas9 research. It offers a unique platform for AI researchers to grasp deep understanding of the biological foundations behind each step in the CRISPR-Cas9 multi-step process. Furthermore, it provides details of 80 available CRISPR-Cas9 system-related datasets that can be utilized to develop AI-driven applications. Within the landscape of AI predictors in CRISPR-Cas9 multi-step process, it provides insights of representation learning methods, machine and deep learning methods trends, and performance values of existing 50 predictive pipelines. In the context of representation learning methods and classifiers/regressors, a thorough analysis of existing predictive pipelines is utilized for recommendations to develop more robust and precise predictive pipelines.

[end paper 86]

[begin paper 87]

PMCID = 11783440

Title = RNA sequence analysis landscape: A comprehensive review of task types, databases, datasets, word embedding methods, and language models

Deciphering information of RNA sequences reveals their diverse roles in living organisms, including gene regulation and protein synthesis. Aberrations in RNA sequence such as dysregulation and mutations can drive a diverse spectrum of diseases including cancers, genetic disorders, and neurodegenerative conditions. Furthermore, researchers are harnessing RNA's therapeutic potential for transforming traditional treatment paradigms into personalized therapies through the development of RNA-based drugs and gene therapies. To gain insights of biological functions and to detect diseases at early stages and develop potent therapeutics, researchers are performing diverse types RNA sequence analysis tasks. RNA sequence analysis through conventional wet-lab methods is expensive, time-consuming and error prone. To enable large-scale RNA sequence analysis, empowerment of wet-lab experimental methods with Artificial Intelligence (AI) applications necessitates scientists to have a comprehensive knowledge of both DNA and AI fields. While molecular biologists encounter challenges in understanding AI methods, computer scientists often lack basic foundations of RNA sequence analysis tasks. Considering the absence of a comprehensive literature that bridges this research gap and promotes the development of AI-driven RNA sequence analysis applications, the contributions of this manuscript are manifold: It equips AI researchers with biological foundations of 47 distinct RNA sequence analysis tasks. It sets a stage for development of benchmark datasets related to 47 distinct RNA sequence analysis tasks by facilitating cruxes of 64 different biological databases. It presents word embeddings and language models applications across 47 distinct RNA sequence analysis tasks. It streamlines the development of new predictors by providing a comprehensive survey of 58 word embeddings and 70 language models based predictive pipelines performance values as well as top performing traditional sequence encoding based predictors and their performances across 47 RNA sequence analysis tasks.

Bridged RNA sequence analysis and AI fields by presenting 47 tasks and matching AI methodologies.

Mapped 47 RNA sequence tasks to AI paradigms - classification, regression, and clustering.

Performance of 58 word embeddings and 70 language model on 310 RNA sequence benchmarks.

Illustrated information of 310 benchmark datasets based on 64 biological databases.

Demonstrated state-of-the-art AI predictor performance for RNA sequence analysis tasks.

[end paper 87]

[begin paper 88]

PMCID = 5423494

Title = Designing the Sniper: Improving Targeted Human Cytolytic Fusion Proteins for Anti-Cancer Therapy via Molecular Simulation

Targeted human cytolytic fusion proteins (hCFPs) are humanized immunotoxins for selective treatment of different diseases including cancer. They are composed of a ligand specifically binding to target cells genetically linked to a human apoptosis-inducing enzyme. hCFPs target cancer cells via an antibody or derivative (scFv) specifically binding to e.g., tumor associated antigens (TAAs). After internalization and translocation of the enzyme from endocytosed endosomes, the human enzymes introduced into the cytosol are efficiently inducing apoptosis. Under in vivo conditions such enzymes are subject to tight regulation by native inhibitors in order to prevent inappropriate induction of cell death in healthy cells. Tumor cells are known to up-regulate these inhibitors as a survival mechanism resulting in escape of malignant cells from elimination by immune effector cells. Cytosolic inhibitors of Granzyme B and Angiogenin (Serpin P9 and RNH1, respectively), reduce the efficacy of hCFPs with these enzymes as effector domains, requiring detrimentally high doses in order to saturate inhibitor binding and rescue cytolytic activity. Variants of Granzyme B and Angiogenin might feature reduced affinity for their respective inhibitors, while retaining or even enhancing their catalytic activity. A powerful tool to design hCFPs mutants with improved potency is given by in silico methods. These include molecular dynamics (MD) simulations and enhanced sampling methods (ESM). MD and ESM allow predicting the enzyme-protein inhibitor binding stability and the associated conformational changes, provided that structural information is available. Such “high-resolution” detailed description enables the elucidation of interaction domains and the identification of sites where particular point mutations may modify those interactions. This review discusses recent advances in the use of MD and ESM for hCFP development from the viewpoints of scientists involved in both fields.

[end paper 88]

[begin paper 89]

PMCID = 8165686

Title = Plausible blockers of Spike RBD in SARS-CoV2—molecular design and underlying interaction dynamics from high-level structural descriptors

COVID-19 is characterized by an unprecedented abrupt increase in the viral transmission rate (SARS-CoV-2) relative to its pandemic evolutionary ancestor, SARS-CoV (2003). The complex molecular cascade of events related to the viral pathogenicity is triggered by the Spike protein upon interacting with the ACE2 receptor on human lung cells through its receptor binding domain (RBDSpike). One potential therapeutic strategy to combat COVID-19 could thus be limiting the infection by blocking this key interaction. In this current study, we adopt a protein design approach to predict and propose non-virulent structural mimics of the RBDSpike which can potentially serve as its competitive inhibitors in binding to ACE2. The RBDSpike is an independently foldable protein domain, resilient to conformational changes upon mutations and therefore an attractive target for strategic re-design. Interestingly, in spite of displaying an optimal shape fit between their interacting surfaces (attributed to a consequently high mutual affinity), the RBDSpike–ACE2 interaction appears to have a quasi-stable character due to a poor electrostatic match at their interface. Structural analyses of homologous protein complexes reveal that the ACE2 binding site of RBDSpike has an unusually high degree of solvent-exposed hydrophobic residues, attributed to key evolutionary changes, making it inherently “reaction-prone.” The designed mimics aimed to block the viral entry by occupying the available binding sites on ACE2, are tested to have signatures of stable high-affinity binding with ACE2 (cross-validated by appropriate free energy estimates), overriding the native quasi-stable feature. The results show the apt of directly adapting natural examples in rational protein design, wherein, homology-based threading coupled with strategic “hydrophobic ↔ polar” mutations serve as a potential breakthrough.

The online version contains supplementary material available at 10.1007/s00894-021-04779-0.

[end paper 89]

[begin paper 90]

PMCID = 10802675

Title = Large language models in bioinformatics: applications and perspectives

Large language models (LLMs) are a class of artificial intelligence models based on deep learning, which have great performance in various tasks, especially in natural language processing (NLP). Large language models typically consist of artificial neural networks with numerous parameters, trained on large amounts of unlabeled input using self-supervised or semi-supervised learning. However, their potential for solving bioinformatics problems may even exceed their proficiency in modeling human language. In this review, we will present a summary of the prominent large language models used in natural language processing, such as BERT and GPT, and focus on exploring the applications of large language models at different omics levels in bioinformatics, mainly including applications of large language models in genomics, transcriptomics, proteomics, drug discovery and single cell analysis. Finally, this review summarizes the potential and prospects of large language models in solving bioinformatic problems.

[end paper 90]

[begin paper 91]

PMCID = 5928017

Title = A single point mutation in precursor protein VI doubles the mechanical strength of human adenovirus

Viruses are extensively studied as vectors for vaccine applications and gene therapies. For these applications, understanding the material properties of viruses is crucial for creating optimal functionality. Using atomic force microscopy (AFM) nanoindentation, we studied the mechanical properties of human adenovirus type 5 with the fiber of type 35 (Ad5F35) and compared it to viral capsids with a single point mutation in the protein VI precursor protein (pVI-S28C). Surprisingly, the pVI-S28C mutant turned out to be twice as stiff as the Ad5F35 capsids. We suggest that this major increase in strength is the result of the DNA crosslinking activity of precursor protein VII, as this protein was detected in the pVI-S28C mutant capsids. The infectivity was similar for both capsids, indicating that mutation did not affect the ability of protein VI to lyse the endosomal membrane. This study highlights that it is possible to increase the mechanical stability of a capsid even with a single point mutation while not affecting the viral life cycle. Such insight can help enable the development of more stable vectors for therapeutic applications.

The online version of this article (10.1007/s10867-017-9479-y) contains supplementary material, which is available to authorized users.

[end paper 91]

[begin paper 92]

PMCID = 11558674

Title = AlphaFold Meets De Novo Drug Design: Leveraging Structural Protein Information in Multitarget Molecular Generative Models

Recent advancements in deep learning and generative models have significantly expanded the applications of virtual screening for drug-like compounds. Here, we introduce a multitarget transformer model, PCMol, that leverages the latent protein embeddings derived from AlphaFold2 as a means of conditioning a de novo generative model on different targets. Incorporating rich protein representations allows the model to capture their structural relationships, enabling the chemical space interpolation of active compounds and target-side generalization to new proteins based on embedding similarities. In this work, we benchmark against other existing target-conditioned transformer models to illustrate the validity of using AlphaFold protein representations over raw amino acid sequences. We show that low-dimensional projections of these protein embeddings cluster appropriately based on target families and that model performance declines when these representations are intentionally corrupted. We also show that the PCMol model generates diverse, potentially active molecules for a wide array of proteins, including those with sparse ligand bioactivity data. The generated compounds display higher similarity known active ligands of held-out targets and have comparable molecular docking scores while maintaining novelty. Additionally, we demonstrate the important role of data augmentation in bolstering the performance of generative models in low-data regimes. Software package and AlphaFold protein embeddings are freely available at .

[end paper 92]

[begin paper 93]

PMCID = 10991518

Title = Genomic language model predicts protein co-regulation and function

Deciphering the relationship between a gene and its genomic context is fundamental to understanding and engineering biological systems. Machine learning has shown promise in learning latent relationships underlying the sequence-structure-function paradigm from massive protein sequence datasets. However, to date, limited attempts have been made in extending this continuum to include higher order genomic context information. Evolutionary processes dictate the specificity of genomic contexts in which a gene is found across phylogenetic distances, and these emergent genomic patterns can be leveraged to uncover functional relationships between gene products. Here, we train a genomic language model (gLM) on millions of metagenomic scaffolds to learn the latent functional and regulatory relationships between genes. gLM learns contextualized protein embeddings that capture the genomic context as well as the protein sequence itself, and encode biologically meaningful and functionally relevant information (e.g. enzymatic function, taxonomy). Our analysis of the attention patterns demonstrates that gLM is learning co-regulated functional modules (i.e. operons). Our findings illustrate that gLM’s unsupervised deep learning of the metagenomic corpus is an effective and promising approach to encode functional semantics and regulatory syntax of genes in their genomic contexts and uncover complex relationships between genes in a genomic region.

A gene’s function is governed by its sequence, structure and context. Here, the authors develop a genomic language model that learns contextualized functional representations from diverse and large-scale metagenomic datasets.

[end paper 93]

[begin paper 94]

PMCID = 10659302

Title = TRILL: ORCHESTRATING MODULAR DEEP-LEARNING WORKFLOWS FOR DEMOCRATIZED, SCALABLE PROTEIN ANALYSIS AND ENGINEERING

Deep-learning models have been rapidly adopted by many fields, partly due to the deluge of data humanity has amassed. In particular, the petabases of biological sequencing data enable the unsupervised training of protein language models that learn the “language of life.” However, due to their prohibitive size and complexity, contemporary deep-learning models are often unwieldy, especially for scientists with limited machine learning backgrounds. TRILL (TRaining and Inference using the Language of Life) is a platform for creative protein design and discovery. Leveraging several state-of-the-art models such as ESM-2, DiffDock, and RFDiffusion, TRILL allows researchers to generate novel proteins, predict 3-D structures, extract high-dimensional representations of proteins, functionally classify proteins and more. What sets TRILL apart is its ability to enable complex pipelines by chaining together models and effectively merging the capabilities of different models to achieve a sum greater than its individual parts. Whether using Google Colab with one GPU or a supercomputer with hundreds, TRILL allows scientists to effectively utilize models with millions to billions of parameters by using optimized training strategies such as ZeRO-Offload and distributed data parallel. Therefore, TRILL not only bridges the gap between complex deep-learning models and their practical application in the field of biology, but also simplifies the orchestration of these models into comprehensive workflows, democratizing access to powerful methods. Documentation: https://trill.readthedocs.io/en/latest/home.html.

[end paper 94]

[begin paper 95]

PMCID = 7998085

Title = Essentials in saline pharmacology for nasal or respiratory hygiene in times of COVID-19

Nasal irrigation or nebulizing aerosol of isotonic or hypertonic saline is a traditional method for respiratory or nasal care. A recent small study in outpatients with COVID-19 without acute respiratory distress syndrome suggests substantial symptom resolution. We therefore analyzed pharmacological/pharmacodynamic effects of isotonic or hypertonic saline, relevant to SARS-CoV-2 infection and respiratory care.

Mixed search method.

Due to its wetting properties, saline achieves an improved spreading of alveolar lining fluid and has been shown to reduce bio-aerosols and viral load. Saline provides moisture to respiratory epithelia and gels mucus, promotes ciliary beating, and improves mucociliary clearance. Coronaviruses and SARS-CoV-2 damage ciliated epithelium in the nose and airways. Saline inhibits SARS-CoV-2 replication in Vero cells; possible interactions involve the viral ACE2-entry mechanism (chloride-dependent ACE2 configuration), furin and 3CLpro (inhibition by NaCl), and the sodium channel ENaC. Saline shifts myeloperoxidase activity in epithelial or phagocytic cells to produce hypochlorous acid. Clinically, nasal or respiratory airway care with saline reduces symptoms of seasonal coronaviruses and other common cold viruses. Its use as aerosol reduces hospitalization rates for bronchiolitis in children. Preliminary data suggest symptom reduction in symptomatic COVID-19 patients if saline is initiated within 48 h of symptom onset.

Saline interacts at various levels relevant to nasal or respiratory hygiene (nasal irrigation, gargling or aerosol). If used from the onset of common cold symptoms, it may represent a useful add-on to first-line interventions for COVID-19. Formal evaluation in mild COVID-19 is desirable as to establish efficacy and optimal treatment regimens.

The online version contains supplementary material available at 10.1007/s00228-021-03102-3.

[end paper 95]

[begin paper 96]

PMCID = 10893003

Title = Recent Progress of Protein Tertiary Structure Prediction

The prediction of three-dimensional (3D) protein structure from amino acid sequences has stood as a significant challenge in computational and structural bioinformatics for decades. Recently, the widespread integration of artificial intelligence (AI) algorithms has substantially expedited advancements in protein structure prediction, yielding numerous significant milestones. In particular, the end-to-end deep learning method AlphaFold2 has facilitated the rise of structure prediction performance to new heights, regularly competitive with experimental structures in the 14th Critical Assessment of Protein Structure Prediction (CASP14). To provide a comprehensive understanding and guide future research in the field of protein structure prediction for researchers, this review describes various methodologies, assessments, and databases in protein structure prediction, including traditionally used protein structure prediction methods, such as template-based modeling (TBM) and template-free modeling (FM) approaches; recently developed deep learning-based methods, such as contact/distance-guided methods, end-to-end folding methods, and protein language model (PLM)-based methods; multi-domain protein structure prediction methods; the CASP experiments and related assessments; and the recently released AlphaFold Protein Structure Database (AlphaFold DB). We discuss their advantages, disadvantages, and application scopes, aiming to provide researchers with insights through which to understand the limitations, contexts, and effective selections of protein structure prediction methods in protein-related fields.

[end paper 96]

[begin paper 97]

PMCID = 10707872

Title = Intelligent Protein Design and Molecular Characterization Techniques: A Comprehensive Review

In recent years, the widespread application of artificial intelligence algorithms in protein structure, function prediction, and de novo protein design has significantly accelerated the process of intelligent protein design and led to many noteworthy achievements. This advancement in protein intelligent design holds great potential to accelerate the development of new drugs, enhance the efficiency of biocatalysts, and even create entirely new biomaterials. Protein characterization is the key to the performance of intelligent protein design. However, there is no consensus on the most suitable characterization method for intelligent protein design tasks. This review describes the methods, characteristics, and representative applications of traditional descriptors, sequence-based and structure-based protein characterization. It discusses their advantages, disadvantages, and scope of application. It is hoped that this could help researchers to better understand the limitations and application scenarios of these methods, and provide valuable references for choosing appropriate protein characterization techniques for related research in the field, so as to better carry out protein research.

[end paper 97]

[begin paper 98]

PMCID = 6706367

Title = Virus-like particle size and molecular weight/mass determination applying gas-phase electrophoresis (native nES GEMMA)

(Bio-)nanoparticle analysis employing a nano-electrospray gas-phase electrophoretic mobility molecular analyzer (native nES GEMMA) also known as nES differential mobility analyzer (nES DMA) is based on surface-dry analyte separation at ambient pressure. Based on electrophoretic principles, single-charged nanoparticles are separated according to their electrophoretic mobility diameter (EMD) corresponding to the particle size for spherical analytes. Subsequently, it is possible to correlate the (bio-)nanoparticle EMDs to their molecular weight (MW) yielding a corresponding fitted curve for an investigated analyte class. Based on such a correlation, (bio-)nanoparticle MW determination via its EMD within one analyte class is possible. Turning our attention to icosahedral, non-enveloped virus-like particles (VLPs), proteinaceous shells, we set up an EMD/MW correlation. We employed native electrospray ionization mass spectrometry (native ESI MS) to obtain MW values of investigated analytes, where possible, after extensive purification. We experienced difficulties in native ESI MS with time-of-flight (ToF) detection to determine MW due to sample inherent characteristics, which was not the case for charge detection (CDMS). nES GEMMA exceeds CDMS in speed of analysis and is likewise less dependent on sample purity and homogeneity. Hence, gas-phase electrophoresis yields calculated MW values in good approximation even when charge resolution was not obtained in native ESI ToF MS. Therefore, both methods-native nES GEMMA-based MW determination via an analyte class inherent EMD/MW correlation and native ESI MS-in the end relate (bio-)nanoparticle MW values. However, they differ significantly in, e.g., ease of instrument operation, sample and analyte handling, or costs of instrumentation.

Graphical abstract

The online version of this article (10.1007/s00216-019-01998-6) contains supplementary material, which is available to authorized users.

[end paper 98]

[begin paper 99]

PMCID = 8865759

Title = AI-powered drug repurposing for developing COVID-19 treatments*

Emerging infectious diseases are an ever-present threat to public health, and COVID-19 is the most recent example. There is an urgent need to develop a robust framework to combat the disease with safe and effective therapeutic options. Compared to de novo drug discovery, drug repurposing may offer a lower-cost and faster drug discovery paradigm to explore potential treatment options of existing drugs. This chapter elucidates the advantages of artificial intelligence (AI) in enhancing the drug repurposing process from a data science perspective, using COVID-19 as an example. First, we elaborate on how AI-powered drug repurposing benefits from the accumulated data and knowledge of COVID-19 natural history and pathogenesis. Second, we summarize the pros and cons of AI-powered drug repurposing strategies to facilitate fit-for-purpose selection. Finally, we outline challenges of AI-powered drug repurposing from a regulatory perspective and suggest some potential solutions.

AI-powered drug purposing is promising for emerging treatments for COVID-19 infection.

Accumulated biological data profiles facilitate AI-based drug repurposing efforts for development of COVID-19 therapies.

The ‘fit-for-purpose selection of AI-powered drug repurposing strategies is key to uncovering hidden information among drugs, targets, and diseases.

Efforts from different stakeholders boost the adoption of AI-powered drug repurposing in the regulatory setting.

[end paper 99]

[begin paper 100]

PMCID = 10968151

Title = Advances in AI for Protein Structure Prediction: Implications for Cancer Drug Discovery and Development

Recent advancements in AI-driven technologies, particularly in protein structure prediction, are significantly reshaping the landscape of drug discovery and development. This review focuses on the question of how these technological breakthroughs, exemplified by AlphaFold2, are revolutionizing our understanding of protein structure and function changes underlying cancer and improve our approaches to counter them. By enhancing the precision and speed at which drug targets are identified and drug candidates can be designed and optimized, these technologies are streamlining the entire drug development process. We explore the use of AlphaFold2 in cancer drug development, scrutinizing its efficacy, limitations, and potential challenges. We also compare AlphaFold2 with other algorithms like ESMFold, explaining the diverse methodologies employed in this field and the practical effects of these differences for the application of specific algorithms. Additionally, we discuss the broader applications of these technologies, including the prediction of protein complex structures and the generative AI-driven design of novel proteins.

[end paper 100]



