## User

This is the beginning of an individual meeting with Computational Biologist to discuss your research project.

Here is the agenda for the meeting:

You are working on a research project to use machine learning to develop antibodies or nanobodies for the newest variant of the SARS-CoV-2 spike protein that also, ideally, have activity against other circulating minor variants and past variants. Your team previous decided to modify existing nanobodies to improve their binding to the newest variant of the SARS-CoV-2 spike protein. You are responsible for understanding the topic "Rosetta" in the context of designing nanobody binders for SARS-CoV-2. You need to fine-tune yourself on the relevant literature on Rosetta to improve your ability to design SARS-CoV-2 nanobody binders. Please use PubMed Central and search for relevant papers on Rosetta using the query "Machine learning Rosetta nanobody optimization" and request 100 articles with abstracts only. Read all of the abstracts and based on each abstract individually, decide whether you want to fine-tune yourself on the full text of that paper. Include as many papers as possible, but only include papers that are directly relevant to Rosetta. Please provide the PMCIDs and titles of all the papers that you wish to fine-tune yourself on as a Python dictionary mapping PMCID as a double-quoted string to title as a double-quoted string.

Here are the agenda questions that must be answered:

1. What are the PMCIDs and titles of the papers you wish to fine-tune yourself on (as a Python dictionary mapping PMCID as a double-quoted string to title as double-quoted string)?

Computational Biologist, please provide your response to the agenda.

## Computational Biologist

Based on the abstracts provided, here are the papers that are directly relevant to Rosetta in the context of designing nanobody binders for SARS-CoV-2, which I would like to fine-tune myself on:

```python
{
    "7993800": "Robustification of RosettaAntibody and Rosetta SnugDock",
    "9015148": "RosettaSurf—A surface-centric computational design approach",
    "10468394": "De novo design of protein structure and function with RFdiffusion",
    "10361724": "Structural modeling of antibody variable regions using deep learning—progress and perspectives on drug discovery",
    "10402144": "Reliable protein-protein docking with AlphaFold, Rosetta, and replica-exchange"
}
```

These papers are selected because they specifically mention Rosetta or are closely related to its methodologies, which are pertinent to the design and optimization of nanobody binders.

## User

Tool Output:

Here are the top 100 articles on PubMed Central for the query "Machine learning Rosetta nanobody optimization":

[begin paper 1]

PMCID = 9294429

Title = Machine-designed biotherapeutics: opportunities, feasibility and advantages of deep learning in computational antibody discovery

Antibodies are versatile molecular binders with an established and growing role as therapeutics. Computational approaches to developing and designing these molecules are being increasingly used to complement traditional lab-based processes. Nowadays, in silico methods fill multiple elements of the discovery stage, such as characterizing antibody–antigen interactions and identifying developability liabilities. Recently, computational methods tackling such problems have begun to follow machine learning paradigms, in many cases deep learning specifically. This paradigm shift offers improvements in established areas such as structure or binding prediction and opens up new possibilities such as language-based modeling of antibody repertoires or machine-learning-based generation of novel sequences. In this review, we critically examine the recent developments in (deep) machine learning approaches to therapeutic antibody design with implications for fully computational antibody design.

[end paper 1]

[begin paper 2]

PMCID = 10023680

Title = Targeting Ras-binding domain of ELMO1 by computational nanobody design

The control of cell movement through manipulation of cytoskeletal structure has therapeutic prospects notably in the development of novel anti-metastatic drugs. In this study, we determine the structure of Ras-binding domain (RBD) of ELMO1, a protein involved in cytoskeletal regulation, both alone and in complex with the activator RhoG and verify its targetability through computational nanobody design. Using our dock-and-design approach optimized with native-like initial pose selection, we obtain Nb01, a detectable binder from scratch in the first-round design. An affinity maturation step guided by structure-activity relationship at the interface generates 23 Nb01 sequence variants and 17 of them show enhanced binding to ELMO1-RBD and are modeled to form major spatial overlaps with RhoG. The best binder, Nb29, inhibited ELMO1-RBD/RhoG interaction. Molecular dynamics simulation of the flexibility of CDR2 and CDR3 of Nb29 reveal the design of stabilizing mutations at the CDR-framework junctions potentially confers the affinity enhancement.

Structural analysis of the Ras-binding domain (RBD) of ELMO1 alone and in complex with the activator RhoG enables rational engineering and validation of a nanobody targeting ELMO1 RBD.

[end paper 2]

[begin paper 3]

PMCID = 8537642

Title = NbX: Machine Learning-Guided Re-Ranking of Nanobody–Antigen Binding Poses

Modeling the binding pose of an antibody is a prerequisite to structure-based affinity maturation and design. Without knowing a reliable binding pose, the subsequent structural simulation is largely futile. In this study, we have developed a method of machine learning-guided re-ranking of antigen binding poses of nanobodies, the single-domain antibody which has drawn much interest recently in antibody drug development. We performed a large-scale self-docking experiment of nanobody–antigen complexes. By training a decision tree classifier through mapping a feature set consisting of energy, contact and interface property descriptors to a measure of their docking quality of the refined poses, significant improvement in the median ranking of native-like nanobody poses by was achieved eightfold compared with ClusPro and an established deep 3D CNN classifier of native protein–protein interaction. We further interpreted our model by identifying features that showed relatively important contributions to the prediction performance. This study demonstrated a useful method in improving our current ability in pose prediction of nanobodies.

[end paper 3]

[begin paper 4]

PMCID = 11679646

Title = The Application of Machine Learning on Antibody Discovery and Optimization

Antibodies play critical roles in modern medicine, serving as diagnostics and therapeutics for various diseases due to their ability to specifically bind to target antigens. Traditional antibody discovery and optimization methods are time-consuming and resource-intensive, though they have successfully generated antibodies for diagnosing and treating diseases. The advancements in protein data, computational hardware, and machine learning (ML) models have the opportunity to disrupt antibody discovery and optimization research. Machine learning models have demonstrated their abilities in antibody design. These machine learning models enable rapid in silico design of antibody candidates within a few days, achieving approximately a 60% reduction in time and a 50% reduction in cost compared to traditional methods. This review focuses on the latest machine learning-based antibody discovery and optimization developments. We briefly discuss the limitations of traditional methods and then explore the machine learning-based antibody discovery and optimization methodologies. We also focus on future research directions, including developing Antibody Design AI Agents and data foundries, alongside the ethical and regulatory considerations essential for successfully adopting machine learning-driven antibody designs.

[end paper 4]

[begin paper 5]

PMCID = 11788755

Title = Nanobody engineering: computational modelling and design for biomedical and therapeutic applications

Nanobodies, the smallest functional antibody fragment derived from camelid heavy‐chain‐only antibodies, have emerged as powerful tools for diverse biomedical applications. In this comprehensive review, we discuss the structural characteristics, functional properties, and computational approaches driving the design and optimisation of synthetic nanobodies. We explore their unique antigen‐binding domains, highlighting the critical role of complementarity‐determining regions in target recognition and specificity. This review further underscores the advantages of nanobodies over conventional antibodies from a biosynthesis perspective, including their small size, stability, and solubility, which make them ideal candidates for economical antigen capture in diagnostics, therapeutics, and biosensing. We discuss the recent advancements in computational methods for nanobody modelling, epitope prediction, and affinity maturation, shedding light on their intricate antigen‐binding mechanisms and conformational dynamics. Finally, we examine a direct example of how computational design strategies were implemented for improving a nanobody‐based immunosensor, known as a Quenchbody. Through combining experimental findings and computational insights, this review elucidates the transformative impact of nanobodies in biotechnology and biomedical research, offering a roadmap for future advancements and applications in healthcare and diagnostics.

This review focuses on structural characteristics, functional properties, and computational approaches driving the design and optimisation of synthetic nanobodies. We discuss recent advancements in computational methods for nanobody modelling, epitope prediction, and affinity maturation, shedding light on their intricate antigen‐binding mechanisms and conformational dynamics. It underscores their advantages over conventional antibodies from a biosynthesis perspective in diagnostics, therapeutics, and biosensing. 

[end paper 5]

[begin paper 6]

PMCID = 8812776

Title = Current advances in biopharmaceutical informatics: guidelines, impact and challenges in the computational developability assessment of antibody therapeutics

Therapeutic monoclonal antibodies and their derivatives are key components of clinical pipelines in the global biopharmaceutical industry. The availability of large datasets of antibody sequences, structures, and biophysical properties is increasingly enabling the development of predictive models and computational tools for the “developability assessment” of antibody drug candidates. Here, we provide an overview of the antibody informatics tools applicable to the prediction of developability issues such as stability, aggregation, immunogenicity, and chemical degradation. We further evaluate the opportunities and challenges of using biopharmaceutical informatics for drug discovery and optimization. Finally, we discuss the potential of developability guidelines based on in silico metrics that can be used for the assessment of antibody stability and manufacturability.

[end paper 6]

[begin paper 7]

PMCID = 7993800

Title = Robustification of RosettaAntibody and Rosetta SnugDock

In recent years, the observed antibody sequence space has grown exponentially due to advances in high-throughput sequencing of immune receptors. The rise in sequences has not been mirrored by a rise in structures, as experimental structure determination techniques have remained low-throughput. Computational modeling, however, has the potential to close the sequence–structure gap. To achieve this goal, computational methods must be robust, fast, easy to use, and accurate. Here we report on the latest advances made in RosettaAntibody and Rosetta SnugDock—methods for antibody structure prediction and antibody–antigen docking. We simplified the user interface, expanded and automated the template database, generalized the kinematics of antibody–antigen docking (which enabled modeling of single-domain antibodies) and incorporated new loop modeling techniques. To evaluate the effects of our updates on modeling accuracy, we developed rigorous tests under a new scientific benchmarking framework within Rosetta. Benchmarking revealed that more structurally similar templates could be identified in the updated database and that SnugDock broadened its applicability without losing accuracy. However, there are further advances to be made, including increasing the accuracy and speed of CDR-H3 loop modeling, before computational approaches can accurately model any antibody.

[end paper 7]

[begin paper 8]

PMCID = 8715506

Title = Allosteric Effect of Nanobody Binding on Ligand-Specific Active States of the β2 Adrenergic Receptor

Nanobody binding stabilizes G-protein-coupled receptors (GPCR) in a fully active state and modulates their affinity for bound ligands. However, the atomic-level basis for this allosteric regulation remains elusive. Here, we investigate the conformational changes induced by the binding of a nanobody (Nb80) on the active-like β2 adrenergic receptor (β2AR) via enhanced sampling molecular dynamics simulations. Dimensionality reduction analysis shows that Nb80 stabilizes structural features of the β2AR with an ∼14 Å outward movement of transmembrane helix 6 and a close proximity of transmembrane (TM) helices 5 and 7, and favors the fully active-like conformation of the receptor, independent of ligand binding, in contrast to the conditions under which no intracellular binding partner is bound, in which case the receptor is only stabilized in an intermediate-active state. This activation is supported by the residues located at hotspots located on TMs 5, 6, and 7, as shown by supervised machine learning methods. Besides, ligand-specific subtle differences in the conformations assumed by intracellular loop 2 and extracellular loop 2 are captured from the trajectories of various ligand-bound receptors in the presence of Nb80. Dynamic network analysis further reveals that Nb80 binding triggers tighter and stronger local communication networks between the Nb80 and the ligand-binding sites, primarily involving residues around ICL2 and the intracellular end of TM3, TM5, TM6, as well as ECL2, ECL3, and the extracellular ends of TM6 and TM7. In particular, we identify unique allosteric signal transmission mechanisms between the Nb80-binding site and the extracellular domains in conformations modulated by a full agonist, BI167107, and a G-protein-biased partial agonist, salmeterol, involving mainly TM1 and TM2, and TM5, respectively. Altogether, our results provide insights into the effect of intracellular binding partners on the GPCR activation mechanism, which should be taken into account in structure-based drug discovery.

[end paper 8]

[begin paper 9]

PMCID = 8928824

Title = Progress and challenges for the machine learning-based design of fit-for-purpose monoclonal antibodies

Although the therapeutic efficacy and commercial success of monoclonal antibodies (mAbs) are tremendous, the design and discovery of new candidates remain a time and cost-intensive endeavor. In this regard, progress in the generation of data describing antigen binding and developability, computational methodology, and artificial intelligence may pave the way for a new era of in silico on-demand immunotherapeutics design and discovery. Here, we argue that the main necessary machine learning (ML) components for an in silico mAb sequence generator are: understanding of the rules of mAb-antigen binding, capacity to modularly combine mAb design parameters, and algorithms for unconstrained parameter-driven in silico mAb sequence synthesis. We review the current progress toward the realization of these necessary components and discuss the challenges that must be overcome to allow the on-demand ML-based discovery and design of fit-for-purpose mAb therapeutic candidates.

[end paper 9]

[begin paper 10]

PMCID = 8848015

Title = Antibody structure prediction using interpretable deep learning

Therapeutic antibodies make up a rapidly growing segment of the biologics market. However, rational design of antibodies is hindered by reliance on experimental methods for determining antibody structures. Here, we present DeepAb, a deep learning method for predicting accurate antibody FV structures from sequence. We evaluate DeepAb on a set of structurally diverse, therapeutically relevant antibodies and find that our method consistently outperforms the leading alternatives. Previous deep learning methods have operated as “black boxes” and offered few insights into their predictions. By introducing a directly interpretable attention mechanism, we show our network attends to physically important residue pairs (e.g., proximal aromatics and key hydrogen bonding interactions). Finally, we present a novel mutant scoring metric derived from network confidence and show that for a particular antibody, all eight of the top-ranked mutations improve binding affinity. This model will be useful for a broad range of antibody prediction and design tasks.

DeepAb, a deep learning method for antibody structure, is presented

Structures from DeepAb are more accurate than alternatives

Outputs of DeepAb provide interpretable insights into structure predictions

DeepAb predictions should facilitate design of novel antibody therapeutics

Accurate structure models are critical for understanding the properties of potential therapeutic antibodies. Conventional methods for protein structure determination require significant investments of time and resources and may fail. Although greatly improved, methods for general protein structure prediction still cannot consistently provide the accuracy necessary to understand or design antibodies. We present a deep learning method for antibody structure prediction and demonstrate improvement over alternatives on diverse, therapeutically relevant benchmarks. In addition to its improved accuracy, our method reveals interpretable outputs about specific amino acids and residue interactions that should facilitate design of novel therapeutic antibodies.

Accurate models of antibody structures are critical for the design of novel antibody therapeutics. We present DeepAb, a deep learning method for predicting antibody structure directly from amino acid sequence. When evaluated on benchmarks balanced for structural diversity and therapeutical relevance, DeepAb outperforms alternative methods. Finally, we dissect the interpretable elements of DeepAb to better understand the features contributing to its predictions and demonstrate how DeepAb could be applied to antibody design.

[end paper 10]

[begin paper 11]

PMCID = 11793827

Title = Nanobody screening and machine learning guided identification of cross-variant anti-SARS-CoV-2 neutralizing heavy-chain only antibodies

Severe Acute Respiratory Syndrome Coronavirus 2 (SARS-CoV-2) continues to persist, demonstrating the risks posed by emerging infectious diseases to national security, public health, and the economy. Development of new vaccines and antibodies for emerging viral threats requires substantial resources and time, and traditional development platforms for vaccines and antibodies are often too slow to combat continuously evolving immunological escape variants, reducing their efficacy over time. Previously, we designed a next-generation synthetic humanized nanobody (Nb) phage display library and demonstrated that this library could be used to rapidly identify highly specific and potent neutralizing heavy chain-only antibodies (HCAbs) with prophylactic and therapeutic efficacy in vivo against the original SARS-CoV-2. In this study, we used a combination of high throughput screening and machine learning (ML) models to identify HCAbs with potent efficacy against SARS-CoV-2 viral variants of interest (VOIs) and concern (VOCs). To start, we screened our highly diverse Nb phage display library against several pre-Omicron VOI and VOC receptor binding domains (RBDs) to identify panels of cross-reactive HCAbs. Using HCAb affinity for SARS-CoV-2 VOI and VOCs (pre-Omicron variants) and model features from other published data, we were able to develop a ML model that successfully identified HCAbs with efficacy against Omicron variants, independent of our experimental biopanning workflow. This biopanning informed ML approach reduced the experimental screening burden by 78% to 90% for the Omicron BA.5 and Omicron BA.1 variants, respectively. The combined approach can be applied to other emerging viruses with pandemic potential to rapidly identify effective therapeutic antibodies against emerging variants.

We leveraged a robust experimental pipeline for heavy chain-only (HCAb) library screening to identify 59 potent HCAbs that can cross-neutralize different SARS-CoV-2 variants. Several of these HCAbs with efficacy against different variants also bind to different SARS-CoV-2 epitopes, suggesting they could be used in antibody cocktails or be engineered as bispecific antibodies that are cross-variant and resistant to viral escape. Using existing published data and data generated from our library of HCAbs against diverse pre-Omicron SARS-CoV-2 variants, we developed an ML model to rapidly predict which HCAbs would be effective against Omicron BA.1 and Omicron BA.5. Using this ML model three HCAbs with efficacy against Omicron BA.1 and BA.5 were identified without requiring additional biopanning. This integrated computational and experimental pipeline can be leveraged for future outbreaks to rapidly identify cross-variant countermeasures that are effective against potential emerging variants.

[end paper 11]

[begin paper 12]

PMCID = 7947987

Title = Computational approaches to therapeutic antibody design: established methods and emerging trends

Antibodies are proteins that recognize the molecular surfaces of potentially noxious molecules to mount an adaptive immune response or, in the case of autoimmune diseases, molecules that are part of healthy cells and tissues. Due to their binding versatility, antibodies are currently the largest class of biotherapeutics, with five monoclonal antibodies ranked in the top 10 blockbuster drugs. Computational advances in protein modelling and design can have a tangible impact on antibody-based therapeutic development. Antibody-specific computational protocols currently benefit from an increasing volume of data provided by next generation sequencing and application to related drug modalities based on traditional antibodies, such as nanobodies. Here we present a structured overview of available databases, methods and emerging trends in computational antibody analysis and contextualize them towards the engineering of candidate antibody therapeutics.

[end paper 12]

[begin paper 13]

PMCID = 9015148

Title = RosettaSurf—A surface-centric computational design approach

Proteins are typically represented by discrete atomic coordinates providing an accessible framework to describe different conformations. However, in some fields proteins are more accurately represented as near-continuous surfaces, as these are imprinted with geometric (shape) and chemical (electrostatics) features of the underlying protein structure. Protein surfaces are dependent on their chemical composition and, ultimately determine protein function, acting as the interface that engages in interactions with other molecules. In the past, such representations were utilized to compare protein structures on global and local scales and have shed light on functional properties of proteins. Here we describe RosettaSurf, a surface-centric computational design protocol, that focuses on the molecular surface shape and electrostatic properties as means for protein engineering, offering a unique approach for the design of proteins and their functions. The RosettaSurf protocol combines the explicit optimization of molecular surface features with a global scoring function during the sequence design process, diverging from the typical design approaches that rely solely on an energy scoring function. With this computational approach, we attempt to address a fundamental problem in protein design related to the design of functional sites in proteins, even when structurally similar templates are absent in the characterized structural repertoire. Surface-centric design exploits the premise that molecular surfaces are, to a certain extent, independent of the underlying sequence and backbone configuration, meaning that different sequences in different proteins may present similar surfaces. We benchmarked RosettaSurf on various sequence recovery datasets and showcased its design capabilities by generating epitope mimics that were biochemically validated. Overall, our results indicate that the explicit optimization of surface features may lead to new routes for the design of functional proteins.

Finely orchestrated protein-protein interactions are at the heart of virtually all fundamental cellular processes. Altering these processes or encoding new functions in proteins has been a long-standing goal in computational protein design. Protein design methods commonly rely on scoring functions that seek to identify amino acid sequences that optimize structural configurations of atoms while minimizing a variety of physics-based and statistical terms. The objectives of the large majority of computational design protocols have been focused on obtaining a predefined structural conformation. However, routinely introducing a functional aspect on designer proteins has been more challenging. Our results suggest that the molecular surface features can be a useful optimization parameter to guide the design process towards functional surfaces that mimic known protein binding sites and interact with their intended targets. Specifically, we demonstrate that our design method can optimize experimental libraries through computational screening, creating a basis for highly specific protein binders, as well as design a potent immunogen that engages with site-specific antibodies. The ability to create proteins with novel functions will be transformative for biomedical applications, providing many opportunities for the design of novel immunogens, protein components for synthetic biology, and other protein-based biotechnologies.

[end paper 13]

[begin paper 14]

PMCID = 6247239

Title = Award Winners and Abstracts of the 32nd Annual Symposium of The Protein Society; Boston, MA, July 9–12, 2018



[end paper 14]

[begin paper 15]

PMCID = 11066466

Title = Recent advances and challenges in protein complex model accuracy estimation

Estimation of model accuracy plays a crucial role in protein structure prediction, aiming to evaluate the quality of predicted protein structure models accurately and objectively. This process is not only key to screening candidate models that are close to the real structure, but also provides guidance for further optimization of protein structures. With the significant advancements made by AlphaFold2 in monomer structure, the problem of single-domain protein structure prediction has been widely solved. Correspondingly, the importance of assessing the quality of single-domain protein models decreased, and the research focus has shifted to estimation of model accuracy of protein complexes. In this review, our goal is to provide a comprehensive overview of the reference and statistical metrics, as well as representative methods, and the current challenges within four distinct facets (Topology Global Score, Interface Total Score, Interface Residue-Wise Score, and Tertiary Residue-Wise Score) in the field of complex EMA.

[end paper 15]

[begin paper 16]

PMCID = 9112195

Title = ISEV2022 Abstract Book



[end paper 16]

[begin paper 17]

PMCID = 9523718

Title = Protein Design: From the Aspect of Water Solubility and Stability

Water solubility and structural stability are key merits for proteins defined by the primary sequence and 3D-conformation. Their manipulation represents important aspects of the protein design field that relies on the accurate placement of amino acids and molecular interactions, guided by underlying physiochemical principles. Emulated designer proteins with well-defined properties both fuel the knowledge-base for more precise computational design models and are used in various biomedical and nanotechnological applications. The continuous developments in protein science, increasing computing power, new algorithms, and characterization techniques provide sophisticated toolkits for solubility design beyond guess work. In this review, we summarize recent advances in the protein design field with respect to water solubility and structural stability. After introducing fundamental design rules, we discuss the transmembrane protein solubilization and de novo transmembrane protein design. Traditional strategies to enhance protein solubility and structural stability are introduced. The designs of stable protein complexes and high-order assemblies are covered. Computational methodologies behind these endeavors, including structure prediction programs, machine learning algorithms, and specialty software dedicated to the evaluation of protein solubility and aggregation, are discussed. The findings and opportunities for Cryo-EM are presented. This review provides an overview of significant progress and prospects in accurate protein design for solubility and stability.

[end paper 17]

[begin paper 18]

PMCID = 8728148

Title = SYNBIP: synthetic binding proteins for research, diagnosis and therapy

The success of protein engineering and design has extensively expanded the protein space, which presents a promising strategy for creating next-generation proteins of diverse functions. Among these proteins, the synthetic binding proteins (SBPs) are smaller, more stable, less immunogenic, and better of tissue penetration than others, which make the SBP-related data attracting extensive interest from worldwide scientists. However, no database has been developed to systematically provide the valuable information of SBPs yet. In this study, a database named ‘Synthetic Binding Proteins for Research, Diagnosis, and Therapy (SYNBIP)’ was thus introduced. This database is unique in (a) comprehensively describing thousands of SBPs from the perspectives of scaffolds, biophysical & functional properties, etc.; (b) panoramically illustrating the binding targets & the broad application of each SBP and (c) enabling a similarity search against the sequences of all SBPs and their binding targets. Since SBP is a human-made protein that has not been found in nature, the discovery of novel SBPs relied heavily on experimental protein engineering and could be greatly facilitated by in-silico studies (such as AI and computational modeling). Thus, the data provided in SYNBIP could lay a solid foundation for the future development of novel SBPs. The SYNBIP is accessible without login requirement at both official (https://idrblab.org/synbip/) and mirror (http://synbip.idrblab.net/) sites.

SYNBIP is a database extensively describing a comprehensive set of synthetic binding proteins (SBPs) from the perspectives of scaffolds, biophysical & functional properties, etc.; panoramically illustrating the binding targets and broad applications of each SBP; and enabling the sequence-based similarity search against SBPs and their binding targets.

[end paper 18]

[begin paper 19]

PMCID = 10792694

Title = Systematic investigation of machine learning on limited data: A study on predicting protein-protein binding strength

The application of machine learning techniques in biological research, especially when dealing with limited data availability, poses significant challenges. In this study, we leveraged advancements in method development for predicting protein-protein binding strength to conduct a systematic investigation into the application of machine learning on limited data. The binding strength, quantitatively measured as binding affinity, is vital for understanding the processes of recognition, association, and dysfunction that occur within protein complexes. By incorporating transfer learning, integrating domain knowledge, and employing both deep learning and traditional machine learning algorithms, we mitigated the impact of data limitations and made significant advancements in predicting protein-protein binding affinity. In particular, we developed over 20 models, ultimately selecting three representative best-performing ones that belong to distinct categories. The first model is structure-based, consisting of a random forest regression and thirteen handcrafted features. The second model is sequence-based, employing an architecture that combines transferred embedding features with a multilayer perceptron. Finally, we created an ensemble model by averaging the predictions of the two aforementioned models. The comparison with other predictors on three independent datasets confirms the significant improvements achieved by our models in predicting protein-protein binding affinity. The programs for running these three models are available at https://github.com/minghuilab/BindPPI.

[end paper 19]

[begin paper 20]

PMCID = 10941601

Title = Optimization strategies and advances in the research and development of AAV‐based gene therapy to deliver large transgenes

Adeno‐associated virus (AAV)‐based therapies are recognized as one of the most potent next‐generation treatments for inherited and genetic diseases. However, several biological and technological aspects of AAV vectors remain a critical issue for their widespread clinical application. Among them, the limited capacity of the AAV genome significantly hinders the development of AAV‐based gene therapy. In this context, genetically modified transgenes compatible with AAV are opening up new opportunities for unlimited gene therapies for many genetic disorders. Recent advances in de novo protein design and remodelling are paving the way for new, more efficient and targeted gene therapeutics. Using computational and genetic tools, AAV expression cassette and transgenic DNA can be split, miniaturized, shuffled or created from scratch to mediate efficient gene transfer into targeted cells. In this review, we highlight recent advances in AAV‐based gene therapy with a focus on its use in translational research. We summarize recent research and development in gene therapy, with an emphasis on large transgenes (>4.8 kb) and optimizing strategies applied by biomedical companies in the research pipeline. We critically discuss the prospects for AAV‐based treatment and some emerging challenges. We anticipate that the continued development of novel computational tools will lead to rapid advances in basic gene therapy research and translational studies.

AAV‐based gene therapy are on increasing demand to cover the needs in the patient communities with inherited genetic disorders.

Single AAV vectors delivering functional gene copy are the most popular approach in RnD pipeline.

Multiple split vectors, inteins and trans‐splicing strategy so far underperform monovector AAV‐delivery.

Neural networks guided by protein fitness data facilitate de novo protein design to fit into AAV capsid.

[end paper 20]

[begin paper 21]

PMCID = 9720949

Title = Prediction of polyreactive and nonspecific single-chain fragment variables through structural biochemical features and protein language-based descriptors

Monoclonal antibodies (mAbs) have been used as therapeutic agents, which must overcome many developability issues after the discovery from in vitro display libraries. Especially, polyreactive mAbs can strongly bind to a specific target and weakly bind to off-target proteins, which leads to poor antibody pharmacokinetics in clinical development. Although early assessment of polyreactive mAbs is important in the early discovery stage, experimental assessments are usually time-consuming and expensive. Therefore, computational approaches for predicting the polyreactivity of single-chain fragment variables (scFvs) in the early discovery stage would be promising for reducing experimental efforts. 

Here, we made prediction models for the polyreactivity of scFvs with the known polyreactive antibody features and natural language model descriptors. We predicted 19,426 protein structures of scFvs with trRosetta to calculate the polyreactive antibody features and investigated the classifying performance of each factor for polyreactivity. In the known polyreactive features, the net charge of the CDR2 loop, the tryptophan and glycine residues in CDR-H3, and the lengths of the CDR1 and CDR2 loops, importantly contributed to the performance of the models. Additionally, the hydrodynamic features, such as partial specific volume, gyration radius, and isoelectric points of CDR loops and scFvs, were newly added to improve model performance. Finally, we made the prediction model with a robust performance () with an ensemble learning of the top 3 best models.

The prediction models for polyreactivity would help assess polyreactive scFvs in the early discovery stage and our approaches would be promising to develop machine learning models with quantitative data from high throughput assays for antibody screening. 

The online version contains supplementary material available at 10.1186/s12859-022-05010-4.

[end paper 21]

[begin paper 22]

PMCID = 9947925

Title = Deep learning of protein sequence design of protein–protein interactions

As more data of experimentally determined protein structures are becoming available, data-driven models to describe protein sequence–structure relationships become more feasible. Within this space, the amino acid sequence design of protein–protein interactions is still a rather challenging subproblem with very low success rates—yet, it is central to most biological processes.

We developed an attention-based deep learning model inspired by algorithms used for image-caption assignments to design peptides or protein fragment sequences. Our trained model can be applied for the redesign of natural protein interfaces or the designed protein interaction fragments. Here, we validate the potential by recapitulating naturally occurring protein–protein interactions including antibody–antigen complexes. The designed interfaces accurately capture essential native interactions and have comparable native-like binding affinities in silico. Furthermore, our model does not need a precise backbone location, making it an attractive tool for working with de novo design of protein–protein interactions.

The source code of the method is available at https://github.com/strauchlab/iNNterfaceDesign

 Supplementary data are available at Bioinformatics online.

[end paper 22]

[begin paper 23]

PMCID = 8863144

Title = Reduced antigenicity of Omicron lowers host serologic response

SARS-CoV-2 Omicron variant of concern (VOC) contains fifteen mutations on the receptor binding domain (RBD), evading most neutralizing antibodies from vaccinated sera. Emerging evidence suggests that Omicron breakthrough cases are associated with substantially lower antibody titers than other VOC cases. However, the mechanism remains unclear. Here, using a novel geometric deep-learning model, we discovered that the antigenic profile of Omicron RBD is distinct from the prior VOCs, featuring reduced antigenicity in its remodeled receptor binding sites (RBS). To substantiate our deep-learning prediction, we immunized mice with different recombinant RBD variants and found that the Omicron’s extensive mutations can lead to a drastically attenuated serologic response with limited neutralizing activity in vivo, while the T cell response remains potent. Analyses of serum cross-reactivity and competitive ELISA with epitope-specific nanobodies revealed that the antibody response to Omicron was reduced across RBD epitopes, including both the variable RBS and epitopes without any known VOC mutations. Moreover, computational modeling confirmed that the RBS is highly versatile with a capacity to further decrease antigenicity while retaining efficient receptor binding. Longitudinal analysis showed that this evolutionary trend of decrease in antigenicity was also found in hCoV229E, a common cold coronavirus that has been circulating in humans for decades. Thus, our study provided unprecedented insights into the reduced antibody titers associated with Omicron infection, revealed a possible trajectory of future viral evolution and may inform the vaccine development against future outbreaks.

[end paper 23]

[begin paper 24]

PMCID = 10886287

Title = Leveraging Artificial Intelligence to Expedite Antibody Design and Enhance Antibody–Antigen Interactions

This perspective sheds light on the transformative impact of recent computational advancements in the field of protein therapeutics, with a particular focus on the design and development of antibodies. Cutting-edge computational methods have revolutionized our understanding of protein–protein interactions (PPIs), enhancing the efficacy of protein therapeutics in preclinical and clinical settings. Central to these advancements is the application of machine learning and deep learning, which offers unprecedented insights into the intricate mechanisms of PPIs and facilitates precise control over protein functions. Despite these advancements, the complex structural nuances of antibodies pose ongoing challenges in their design and optimization. Our review provides a comprehensive exploration of the latest deep learning approaches, including language models and diffusion techniques, and their role in surmounting these challenges. We also present a critical analysis of these methods, offering insights to drive further progress in this rapidly evolving field. The paper includes practical recommendations for the application of these computational techniques, supplemented with independent benchmark studies. These studies focus on key performance metrics such as accuracy and the ease of program execution, providing a valuable resource for researchers engaged in antibody design and development. Through this detailed perspective, we aim to contribute to the advancement of antibody design, equipping researchers with the tools and knowledge to navigate the complexities of this field.

[end paper 24]

[begin paper 25]

PMCID = 6963682

Title = Antibody Structure and Function: The Basis for Engineering Therapeutics

Antibodies and antibody-derived macromolecules have established themselves as the mainstay in protein-based therapeutic molecules (biologics). Our knowledge of the structure–function relationships of antibodies provides a platform for protein engineering that has been exploited to generate a wide range of biologics for a host of therapeutic indications. In this review, our basic understanding of the antibody structure is described along with how that knowledge has leveraged the engineering of antibody and antibody-related therapeutics having the appropriate antigen affinity, effector function, and biophysical properties. The platforms examined include the development of antibodies, antibody fragments, bispecific antibody, and antibody fusion products, whose efficacy and manufacturability can be improved via humanization, affinity modulation, and stability enhancement. We also review the design and selection of binding arms, and avidity modulation. Different strategies of preparing bispecific and multispecific molecules for an array of therapeutic applications are included.

[end paper 25]

[begin paper 26]

PMCID = 10781723

Title = Accelerating therapeutic protein design with computational approaches toward the clinical stage

Therapeutic protein, represented by antibodies, is of increasing interest in human medicine. However, clinical translation of therapeutic protein is still largely hindered by different aspects of developability, including affinity and selectivity, stability and aggregation prevention, solubility and viscosity reduction, and deimmunization. Conventional optimization of the developability with widely used methods, like display technologies and library screening approaches, is a time and cost-intensive endeavor, and the efficiency in finding suitable solutions is still not enough to meet clinical needs. In recent years, the accelerated advancement of computational methodologies has ushered in a transformative era in the field of therapeutic protein design. Owing to their remarkable capabilities in feature extraction and modeling, the integration of cutting-edge computational strategies with conventional techniques presents a promising avenue to accelerate the progression of therapeutic protein design and optimization toward clinical implementation. Here, we compared the differences between therapeutic protein and small molecules in developability and provided an overview of the computational approaches applicable to the design or optimization of therapeutic protein in several developability issues.

[end paper 26]

[begin paper 27]

PMCID = 9515332

Title = Reduced B cell antigenicity of Omicron lowers host serologic response

The SARS-CoV-2 Omicron variant evades most neutralizing vaccine-induced antibodies and is associated with lower antibody titers upon breakthrough infections than previous variants. However, the mechanism remains unclear. Here, we find using a geometric deep-learning model that Omicron’s extensively mutated receptor binding site (RBS) features reduced antigenicity compared with previous variants. Mice immunization experiments with different recombinant receptor binding domain (RBD) variants confirm that the serological response to Omicron is drastically attenuated and less potent. Analyses of serum cross-reactivity and competitive ELISA reveal a reduction in antibody response across both variable and conserved RBD epitopes. Computational modeling confirms that the RBS has a potential for further antigenicity reduction while retaining efficient receptor binding. Finally, we find a similar trend of antigenicity reduction over decades for hCoV229E, a common cold coronavirus. Thus, our study explains the reduced antibody titers associated with Omicron infection and reveals a possible trajectory of future viral evolution.

SARS-CoV-2 Omicron variant evades most neutralizing vaccine-induced antibodies and is associated with lower antibody titers upon breakthrough infections than previous variants. Tubiana et al. investigate the underlying mechanism using geometric deep learning, mice immunization experiments, and biochemical assays. Mutations reduce antigenicity of the receptor binding site, leading to lower antibody response.

[end paper 27]

[begin paper 28]

PMCID = 11172335

Title = Artificial Intelligence in Point-of-Care Biosensing: Challenges and Opportunities

The integration of artificial intelligence (AI) into point-of-care (POC) biosensing has the potential to revolutionize diagnostic methodologies by offering rapid, accurate, and accessible health assessment directly at the patient level. This review paper explores the transformative impact of AI technologies on POC biosensing, emphasizing recent computational advancements, ongoing challenges, and future prospects in the field. We provide an overview of core biosensing technologies and their use at the POC, highlighting ongoing issues and challenges that may be solved with AI. We follow with an overview of AI methodologies that can be applied to biosensing, including machine learning algorithms, neural networks, and data processing frameworks that facilitate real-time analytical decision-making. We explore the applications of AI at each stage of the biosensor development process, highlighting the diverse opportunities beyond simple data analysis procedures. We include a thorough analysis of outstanding challenges in the field of AI-assisted biosensing, focusing on the technical and ethical challenges regarding the widespread adoption of these technologies, such as data security, algorithmic bias, and regulatory compliance. Through this review, we aim to emphasize the role of AI in advancing POC biosensing and inform researchers, clinicians, and policymakers about the potential of these technologies in reshaping global healthcare landscapes.

[end paper 28]

[begin paper 29]

PMCID = 7168573

Title = The 44th Annual Meeting of the European Society for Blood and Marrow Transplantation: Physicians Poster Sessions



[end paper 29]

[begin paper 30]

PMCID = 8178184

Title = An Expanded Benchmark for Antibody-Antigen Docking and Affinity Prediction Reveals Insights into Antibody Recognition Determinants

Accurate predictive modeling of antibody-antigen complex structures and structure-based antibody design remain major challenges in computational biology, with implications for biotherapeutics, immunity, and vaccines. Through a systematic search for high resolution structures of antibody-antigen complexes and unbound antibody and antigen structures, in conjunction with identification of experimentally determined binding affinities, we have assembled a non-redundant set of test cases for antibody-antigen docking and affinity prediction. This benchmark more than doubles the number of antibody-antigen complexes and corresponding affinities available in our previous benchmarks, providing an unprecedented view of the determinants of antibody recognition and insights into molecular flexibility. Initial assessments of docking and affinity prediction tools highlight the challenges posed by this diverse set of cases, which includes camelid nanobodies, therapeutic monoclonal antibodies, and broadly neutralizing antibodies targeting viral glycoproteins. This dataset will enable development of advanced predictive modeling and design methods for this therapeutically relevant class of protein-protein interactions.

Predictive antibody-antigen docking and structure-based design represent longstanding and therapeutically important challenges in computational biology. Guest et al. assembled a large and nonredundant set of antibody-antigen test cases, with high resolution bound and unbound structures and binding affinities, to enable advanced algorithm developments and benchmarking in this area.

[end paper 30]

[begin paper 31]

PMCID = 10983868

Title = Atomically accurate de novo design of single-domain antibodies

Despite the central role that antibodies play in modern medicine, there is currently no way to rationally design novel antibodies to bind a specific epitope on a target. Instead, antibody discovery currently involves time-consuming immunization of an animal or library screening approaches. Here we demonstrate that a fine-tuned RFdiffusion network is capable of designing de novo antibody variable heavy chains (VHH’s) that bind user-specified epitopes. We experimentally confirm binders to four disease-relevant epitopes, and the cryo-EM structure of a designed VHH bound to influenza hemagglutinin is nearly identical to the design model both in the configuration of the CDR loops and the overall binding pose.

[end paper 31]

[begin paper 32]

PMCID = 7718903

Title = Integrative modeling of membrane-associated protein assemblies

Membrane proteins are among the most challenging systems to study with experimental structural biology techniques. The increased number of deposited structures of membrane proteins has opened the route to modeling their complexes by methods such as docking. Here, we present an integrative computational protocol for the modeling of membrane-associated protein assemblies. The information encoded by the membrane is represented by artificial beads, which allow targeting of the docking toward the binding-competent regions. It combines efficient, artificial intelligence-based rigid-body docking by LightDock with a flexible final refinement with HADDOCK to remove potential clashes at the interface. We demonstrate the performance of this protocol on eighteen membrane-associated complexes, whose interface lies between the membrane and either the cytosolic or periplasmic regions. In addition, we provide a comparison to another state-of-the-art docking software, ZDOCK. This protocol should shed light on the still dark fraction of the interactome consisting of membrane proteins.

Most approaches for modeling the membrane protein complexes are not capable of incorporating the topological information provided by the membrane. Here authors present an integrative computational protocol for the modeling of membrane-associated protein assemblies, specifically complexes consisting of a membrane-embedded protein and a soluble partner.

[end paper 32]

[begin paper 33]

PMCID = 10129313

Title = Fast, accurate antibody structure prediction from deep learning on massive set of natural antibodies

Antibodies have the capacity to bind a diverse set of antigens, and they have become critical therapeutics and diagnostic molecules. The binding of antibodies is facilitated by a set of six hypervariable loops that are diversified through genetic recombination and mutation. Even with recent advances, accurate structural prediction of these loops remains a challenge. Here, we present IgFold, a fast deep learning method for antibody structure prediction. IgFold consists of a pre-trained language model trained on 558 million natural antibody sequences followed by graph networks that directly predict backbone atom coordinates. IgFold predicts structures of similar or better quality than alternative methods (including AlphaFold) in significantly less time (under 25 s). Accurate structure prediction on this timescale makes possible avenues of investigation that were previously infeasible. As a demonstration of IgFold’s capabilities, we predicted structures for 1.4 million paired antibody sequences, providing structural insights to 500-fold more antibodies than have experimentally determined structures.

Prediction of antibody structures is critical for understanding and designing novel therapeutic and diagnostic molecules. Here, the authors present IgFold: a fast, accurate method for antibody structure prediction using an end-to-end deep learning model.

[end paper 33]

[begin paper 34]

PMCID = 11788748

Title = Structure‐based computational design of antibody mimetics: challenges and perspectives

The design of antibody mimetics holds great promise for revolutionizing therapeutic interventions by offering alternatives to conventional antibody therapies. Structure‐based computational approaches have emerged as indispensable tools in the rational design of those molecules, enabling the precise manipulation of their structural and functional properties. This review covers the main classes of designed antigen‐binding motifs, as well as alternative strategies to develop tailored ones. We discuss the intricacies of different computational protein–protein interaction design strategies, showcased by selected successful cases in the literature. Subsequently, we explore the latest advancements in the computational techniques including the integration of machine and deep learning methodologies into the design framework, which has led to an augmented design pipeline. Finally, we verse onto the current challenges that stand in the way between high‐throughput computer design of antibody mimetics and experimental realization, offering a forward‐looking perspective into the field and the promises it holds to biotechnology.

Computer graphics representation of an artificial intelligence–driven protein design pipeline, where building blocks are fed into the birth of a novel protein structure. 

[end paper 34]

[begin paper 35]

PMCID = 11221890

Title = Antibody design using deep learning: from sequence and structure design to affinity maturation

Deep learning has achieved impressive results in various fields such as computer vision and natural language processing, making it a powerful tool in biology. Its applications now encompass cellular image classification, genomic studies and drug discovery. While drug development traditionally focused deep learning applications on small molecules, recent innovations have incorporated it in the discovery and development of biological molecules, particularly antibodies. Researchers have devised novel techniques to streamline antibody development, combining in vitro and in silico methods. In particular, computational power expedites lead candidate generation, scaling and potential antibody development against complex antigens. This survey highlights significant advancements in protein design and optimization, specifically focusing on antibodies. This includes various aspects such as design, folding, antibody–antigen interactions docking and affinity maturation.

[end paper 35]

[begin paper 36]

PMCID = 9411858

Title = NanoNet: Rapid and accurate end-to-end nanobody modeling by deep learning

Antibodies are a rapidly growing class of therapeutics. Recently, single domain camelid VHH antibodies, and their recognition nanobody domain (Nb) appeared as a cost-effective highly stable alternative to full-length antibodies. There is a growing need for high-throughput epitope mapping based on accurate structural modeling of the variable domains that share a common fold and differ in the Complementarity Determining Regions (CDRs). We develop a deep learning end-to-end model, NanoNet, that given a sequence directly produces the 3D coordinates of the backbone and Cβ atoms of the entire VH domain. For the Nb test set, NanoNet achieves 3.16Å average RMSD for the most variable CDR3 loops and 2.65Å, 1.73Å for the CDR1, CDR2 loops, respectively. The accuracy for antibody VH domains is even higher: 2.38Å RMSD for CDR3 and 0.89Å, 0.96Å for the CDR1, CDR2 loops, respectively. NanoNet run times allow generation of ∼1M nanobody structures in less than 4 hours on a standard CPU computer enabling high-throughput structure modeling. NanoNet is available at GitHub:  

[end paper 36]

[begin paper 37]

PMCID = 11195458

Title = Toward enhancement of antibody thermostability and affinity by computational design in the absence of antigen

Over the past two decades, therapeutic antibodies have emerged as a rapidly expanding domain within the field of biologics. In silico tools that can streamline the process of antibody discovery and optimization are critical to support a pipeline that is growing more numerous and complex every year. High-quality structural information remains critical for the antibody optimization process, but antibody-antigen complex structures are often unavailable and in silico antibody docking methods are still unreliable. In this study, DeepAb, a deep learning model for predicting antibody Fv structure directly from sequence, was used in conjunction with single-point experimental deep mutational scanning (DMS) enrichment data to design 200 potentially optimized variants of an anti-hen egg lysozyme (HEL) antibody. We sought to determine whether DeepAb-designed variants containing combinations of beneficial mutations from the DMS exhibit enhanced thermostability and whether this optimization affected their developability profile. The 200 variants were produced through a robust high-throughput method and tested for thermal and colloidal stability (Tonset, Tm, Tagg), affinity (KD) relative to the parental antibody, and for developability parameters (nonspecific binding, aggregation propensity, self-association). Of the designed clones, 91% and 94% exhibited increased thermal and colloidal stability and affinity, respectively. Of these, 10% showed a significantly increased affinity for HEL (5- to 21-fold increase) and thermostability (>2.5C increase in Tm1), with most clones retaining the favorable developability profile of the parental antibody. Additional in silico tests suggest that these methods would enrich for binding affinity even without first collecting experimental DMS measurements. These data open the possibility of in silico antibody optimization without the need to predict the antibody–antigen interface, which is notoriously difficult in the absence of crystal structures.

[end paper 37]

[begin paper 38]

PMCID = 10656474

Title = Simultaneous selection of nanobodies for accessible epitopes on immune cells in the tumor microenvironment

In the rapidly advancing field of synthetic biology, there exists a critical need for technology to discover targeting moieties for therapeutic biologics. Here we present INSPIRE-seq, an approach that utilizes a nanobody library and next-generation sequencing to identify nanobodies selected for complex environments. INSPIRE-seq enables the parallel enrichment of immune cell-binding nanobodies that penetrate the tumor microenvironment. Clone enrichment and specificity vary across immune cell subtypes in the tumor, lymph node, and spleen. INSPIRE-seq identifies a dendritic cell binding clone that binds PHB2. Single-cell RNA sequencing reveals a connection with cDC1s, and immunofluorescence confirms nanobody-PHB2 colocalization along cell membranes. Structural modeling and docking studies assist binding predictions and will guide nanobody selection. In this work, we demonstrate that INSPIRE-seq offers an unbiased approach to examine complex microenvironments and assist in the development of nanobodies, which could serve as active drugs, modified to become drugs, or used as targeting moieties.

INSPIREseq discovers accessible epitopes in complex environments and leads to nanobodies targeting thousands of epitopes. This in vivo diversity selection identifies selective nanobodies, potentially expediting target discovery and drug development.

[end paper 38]

[begin paper 39]

PMCID = 11160594

Title = Ion channel inhibition by targeted recruitment of NEDD4–2 with divalent nanobodies

Targeted recruitment of E3 ubiquitin ligases to degrade traditionally undruggable proteins is a disruptive paradigm for developing new therapeutics. Two salient limitations are that <2% of the ~600 E3 ligases in the human genome have been exploited to produce proteolysis targeting chimeras (PROTACs), and the efficacy of the approach has not been demonstrated for a vital class of complex multi-subunit membrane proteins— ion channels. NEDD4–1 and NEDD4–2 are physiological regulators of myriad ion channels, and belong to the 28-member HECT (homologous to E6AP C-terminus) family of E3 ligases with widespread roles in cell/developmental biology and diverse diseases including various cancers, immunological and neurological disorders, and chronic pain. The potential efficacy of HECT E3 ligases for targeted protein degradation is unexplored, constrained by a lack of appropriate binders, and uncertain due to their complex regulation by layered intra-molecular and posttranslational mechanisms. Here, we identified a nanobody that binds with high affinity and specificity to a unique site on the N-lobe of the NEDD4–2 HECT domain at a location physically separate from sites critical for catalysis— the E2 binding site, the catalytic cysteine, and the ubiquitin exosite— as revealed by a 3.1 Å cryo-electron microscopy reconstruction. Recruiting endogenous NEDD4–2 to diverse ion channel proteins (KCNQ1, ENaC, and CaV2.2) using a divalent (DiVa) nanobody format strongly reduced their functional expression with minimal off-target effects as assessed by global proteomics, compared to simple NEDD4–2 overexpression. The results establish utility of a HECT E3 ligase for targeted protein downregulation, validate a class of complex multi-subunit membrane proteins as susceptible to this modality, and introduce endogenous E3 ligase recruitment with DiVa nanobodies as a general method to generate novel genetically-encoded ion channel inhibitors.

[end paper 39]

[begin paper 40]

PMCID = 6309182

Title = A brief history of macromolecular crystallography, illustrated by a family tree and its Nobel fruits

As a contribution to the celebration of the year 2014, declared by the United Nations to be “The International Year of Crystallography”, the FEBS Journal is dedicating this issue to papers showcasing the intimate union between macromolecular crystallography and structural biology, both in historical perspective and in current research. Instead of a formal editorial piece, by way of introduction, this review discusses the most important, often iconic, achievements of crystallographers that led to major advances in our understanding of the structure and function of biological macromolecules. We identified at least 42 scientists who received Nobel Prizes in Physics, Chemistry, or Medicine for their contributions that included the use of X-rays or neutrons and crystallography, including 24 who made seminal discoveries in macromolecular sciences. Our spotlight is mostly, but not only, on the recipients of this most prestigious scientific honor - presented in roughly chronological order. As a summary of the review, we attempt to construct a genealogy tree of the principal lineages of protein crystallography, leading from the founding members to the present generation.

[end paper 40]

[begin paper 41]

PMCID = 11405125

Title = AI-based IsAb2.0 for antibody design

Therapeutic antibody design has garnered widespread attention, highlighting its interdisciplinary importance. Advancements in technology emphasize the critical role of designing nanobodies and humanized antibodies in antibody engineering. However, current experimental methods are costly and time-consuming. Computational approaches, while progressing, faced limitations due to insufficient structural data and the absence of a standardized protocol. To tackle these challenges, our lab previously developed IsAb1.0, an in silico antibody design protocol. Yet, IsAb1.0 lacked accuracy, had a complex procedure, and required extensive antibody bioinformation. Moreover, it overlooked nanobody and humanized antibody design, hindering therapeutic antibody development. Building upon IsAb1.0, we enhanced our design protocol with artificial intelligence methods to create IsAb2.0. IsAb2.0 utilized AlphaFold-Multimer (2.3/3.0) for accurate modeling and complex construction without templates and employed the precise FlexddG method for in silico antibody optimization. Validated through optimization of a humanized nanobody J3 (HuJ3) targeting HIV-1 gp120, IsAb2.0 predicted five mutations that can improve HuJ3-gp120 binding affinity. These predictions were confirmed by commercial software and validated through binding and neutralization assays. IsAb2.0 streamlined antibody design, offering insights into future techniques to accelerate immunotherapy development.

[end paper 41]

[begin paper 42]

PMCID = 11254834

Title = A comprehensive overview of recent advances in generative models for antibodies

Therapeutic antibodies are an important class of biopharmaceuticals. With the rapid development of deep learning methods and the increasing amount of antibody data, antibody generative models have made great progress recently. They aim to solve the antibody space searching problems and are widely incorporated into the antibody development process. Therefore, a comprehensive introduction to the development methods in this field is imperative. Here, we collected 34 representative antibody generative models published recently and all generative models can be divided into three categories: sequence-generating models, structure-generating models, and hybrid models, based on their principles and algorithms. We further studied their performance and contributions to antibody sequence prediction, structure optimization, and affinity enhancement. Our manuscript will provide a comprehensive overview of the status of antibody generative models and also offer guidance for selecting different approaches.

[end paper 42]

[begin paper 43]

PMCID = 9279371

Title = Model building of protein complexes from intermediate-resolution cryo-EM maps with deep learning-guided automatic assembly

Advances in microscopy instruments and image processing algorithms have led to an increasing number of cryo-electron microscopy (cryo-EM) maps. However, building accurate models into intermediate-resolution EM maps remains challenging and labor-intensive. Here, we propose an automatic model building method of multi-chain protein complexes from intermediate-resolution cryo-EM maps, named EMBuild, by integrating AlphaFold structure prediction, FFT-based global fitting, domain-based semi-flexible refinement, and graph-based iterative assembling on the main-chain probability map predicted by a deep convolutional network. EMBuild is extensively evaluated on diverse test sets of 47 single-particle EM maps at 4.0–8.0 Å resolution and 16 subtomogram averaging maps of cryo-ET data at 3.7–9.3 Å resolution, and compared with state-of-the-art approaches. We demonstrate that EMBuild is able to build high-quality complex structures that are comparably accurate to the manually built PDB structures from the cryo-EM maps. These results demonstrate the accuracy and reliability of EMBuild in automatic model building.

One challenge in cryo-EM is to build atomic models into intermediate resolution maps. Here, the authors present a deep learning-guided iterative assembling method by integrating AlphaFold, FFTbased fitting, and domain-based refinement.

[end paper 43]

[begin paper 44]

PMCID = 10636138

Title = Enhancing antibody affinity through experimental sampling of non-deleterious CDR mutations predicted by machine learning

The application of machine learning (ML) models to optimize antibody affinity to an antigen is gaining prominence. Unfortunately, the small and biased nature of the publicly available antibody-antigen interaction datasets makes it challenging to build an ML model that can accurately predict binding affinity changes due to mutations (ΔΔG). Recognizing these inherent limitations, we reformulated the problem to ask whether an ML model capable of classifying deleterious vs non-deleterious mutations can guide antibody affinity maturation in a practical setting. To test this hypothesis, we developed a Random Forest classifier (Antibody Random Forest Classifier or AbRFC) with expert-guided features and integrated it into a computational-experimental workflow. AbRFC effectively predicted non-deleterious mutations on an in-house validation dataset that is free of biases seen in the publicly available training datasets. Furthermore, experimental screening of a limited number of predictions from the model (<10^2 designs) identified affinity-enhancing mutations in two unrelated SARS-CoV-2 antibodies, resulting in constructs with up to 1000-fold increased binding to the SARS-COV-2 RBD. Our findings indicate that accurate prediction and screening of non-deleterious mutations using machine learning offers a powerful approach to improving antibody affinity.

The endeavor to harness machine learning to improve antibody-antigen interaction is not only significant but also fraught with challenges due to the limitations of the publicly available datasets. Here, the authors introduce an Antibody Random Forest Classifier that classifies mutations as either deleterious or non-deleterious based on physicochemical features, which enabled the identification of affinity-enhancing mutations in SARS-CoV-2 antibodies with an up to 1000-fold increased binding affinity.

[end paper 44]

[begin paper 45]

PMCID = 10373554

Title = Broad Sarbecovirus Neutralizing Antibodies Obtained by Computational Design and Synthetic Library Screening

Members of the Sarbecovirus subgenus of Coronaviridae have twice caused deadly threats to humans. There is increasing concern about the rapid mutation of severe acute respiratory syndrome coronavirus 2 (SARS-CoV-2), which has evolved into multiple generations of epidemic variants in 3 years. Broad neutralizing antibodies are of great importance for pandemic preparedness against SARS-CoV-2 variants and divergent zoonotic sarbecoviruses. Here, we analyzed the structural conservation of the receptor-binding domain (RBD) from representative sarbecoviruses and chose S2H97, a previously reported RBD antibody with ideal breadth and resistance to escape, as a template for computational design to enhance the neutralization activity and spectrum. A total of 35 designs were purified for evaluation. The neutralizing activity of a large proportion of these designs against multiple variants was increased from several to hundreds of times. Molecular dynamics simulation suggested that extra interface contacts and enhanced intermolecular interactions between the RBD and the designed antibodies are established. After light and heavy chain reconstitution, AI-1028, with five complementarity determining regions optimized, showed the best neutralizing activity across all tested sarbecoviruses, including SARS-CoV, multiple SARS-CoV-2 variants, and bat-derived viruses. AI-1028 recognized the same cryptic RBD epitope as the parental prototype antibody. In addition to computational design, chemically synthesized nanobody libraries are also a precious resource for rapid antibody development. By applying distinct RBDs as baits for reciprocal screening, we identified two novel nanobodies with broad activities. These findings provide potential pan-sarbecovirus neutralizing drugs and highlight new pathways to rapidly optimize therapeutic candidates when novel SARS-CoV-2 escape variants or new zoonotic coronaviruses emerge.

IMPORTANCE The subgenus Sarbecovirus includes human SARS-CoV, SARS-CoV-2, and hundreds of genetically related bat viruses. The continuous evolution of SARS-CoV-2 has led to the striking evasion of neutralizing antibody (NAb) drugs and convalescent plasma. Antibodies with broad activity across sarbecoviruses would be helpful to combat current SARS-CoV-2 mutations and longer term animal virus spillovers. The study of pan-sarbecovirus NAbs described here is significant for the following reasons. First, we established a structure-based computational pipeline to design and optimize NAbs to obtain more potent and broader neutralizing activity across multiple sarbecoviruses. Second, we screened and identified nanobodies from a highly diversified synthetic library with a broad neutralizing spectrum using an elaborate screening strategy. These methodologies provide guidance for the rapid development of antibody therapeutics against emerging pathogens with highly variable characteristics.

[end paper 45]

[begin paper 46]

PMCID = 10510469

Title = Rational design of small‐molecule responsive protein switches

Small‐molecule responsive protein switches are powerful tools for controlling cellular processes. These switches are designed to respond rapidly and specifically to their inducer. They have been used in numerous applications, including the regulation of gene expression, post‐translational protein modification, and signal transduction. Typically, small‐molecule responsive protein switches consist of two proteins that interact with each other in the presence or absence of a small molecule. Recent advances in computational protein design already contributed to the development of protein switches with an expanded range of small‐molecule inducers and increasingly sophisticated switch mechanisms. Further progress in the engineering of small‐molecule responsive switches is fueled by cutting‐edge computational design approaches, which will enable more complex and precise control over cellular processes and advance synthetic biology applications in biotechnology and medicine. Here, we discuss recent milestones and how technological advances are impacting the development of chemical switches.

[end paper 46]

[begin paper 47]

PMCID = 10220908

Title = Structural Modeling of Nanobodies: A Benchmark of State-of-the-Art Artificial Intelligence Programs

The number of applications for nanobodies is steadily expanding, positioning these molecules as fast-growing biologic products in the biotechnology market. Several of their applications require protein engineering, which in turn would greatly benefit from having a reliable structural model of the nanobody of interest. However, as with antibodies, the structural modeling of nanobodies is still a challenge. With the rise of artificial intelligence (AI), several methods have been developed in recent years that attempt to solve the problem of protein modeling. In this study, we have compared the performance in nanobody modeling of several state-of-the-art AI-based programs, either designed for general protein modeling, such as AlphaFold2, OmegaFold, ESMFold, and Yang-Server, or specifically designed for antibody modeling, such as IgFold, and Nanonet. While all these programs performed rather well in constructing the nanobody framework and CDRs 1 and 2, modeling CDR3 still represents a big challenge. Interestingly, tailoring an AI method for antibody modeling does not necessarily translate into better results for nanobodies.

[end paper 47]

[begin paper 48]

PMCID = 10849486

Title = MagIC-Cryo-EM: Structural determination on magnetic beads for scarce macromolecules in heterogeneous samples

Cryo-EM single-particle analyses typically require target macromolecule concentration at 0.05~5.0 mg/ml, which is often difficult to achieve. Here, we devise Magnetic Isolation and Concentration (MagIC)-cryo-EM, a technique enabling direct structural analysis of targets captured on magnetic beads, thereby reducing the targets’ concentration requirement to < 0.0005 mg/ml. Adapting MagIC-cryo-EM to a Chromatin Immunoprecipitation protocol, we characterized structural variations of the linker histone H1.8-associated nucleosomes that were isolated from interphase and metaphase chromosomes in Xenopus egg extract. Combining Duplicated Selection To Exclude Rubbish particles (DuSTER), a particle curation method that excludes low signal-to-noise ratio particles, we also resolved the 3D cryo-EM structures of nucleoplasmin NPM2 co-isolated with the linker histone H1.8 and revealed distinct open and closed structural variants. Our study demonstrates the utility of MagIC-cryo-EM for structural analysis of scarce macromolecules in heterogeneous samples and provides structural insights into the cell cycle-regulation of H1.8 association to nucleosomes.

[end paper 48]

[begin paper 49]

PMCID = 8950575

Title = Next-Generation Molecular Discovery: From Bottom-Up In Vivo and In Vitro Approaches to In Silico Top-Down Approaches for Therapeutics Neogenesis

Protein and drug engineering comprises a major part of the medical and research industries, and yet approaches to discovering and understanding therapeutic molecular interactions in biological systems rely on trial and error. The general approach to molecular discovery involves screening large libraries of compounds, proteins, or antibodies, or in vivo antibody generation, which could be considered “bottom-up” approaches to therapeutic discovery. In these bottom-up approaches, a minimal amount is known about the therapeutics at the start of the process, but through meticulous and exhaustive laboratory work, the molecule is characterised in detail. In contrast, the advent of “big data” and access to extensive online databases and machine learning technologies offers promising new avenues to understanding molecular interactions. Artificial intelligence (AI) now has the potential to predict protein structure at an unprecedented accuracy using only the genetic sequence. This predictive approach to characterising molecular structure—when accompanied by high-quality experimental data for model training—has the capacity to invert the process of molecular discovery and characterisation. The process has potential to be transformed into a top-down approach, where new molecules can be designed directly based on the structure of a target and the desired function, rather than performing screening of large libraries of molecular variants. This paper will provide a brief evaluation of bottom-up approaches to discovering and characterising biological molecules and will discuss recent advances towards developing top-down approaches and the prospects of this.

[end paper 49]

[begin paper 50]

PMCID = 11197468

Title = Accelerating Genetic Sensor Development, Scale-up, and Deployment Using Synthetic Biology

Living cells are exquisitely tuned to sense and respond to changes in their environment. Repurposing these systems to create engineered biosensors has seen growing interest in the field of synthetic biology and provides a foundation for many innovative applications spanning environmental monitoring to improved biobased production. In this review, we present a detailed overview of currently available biosensors and the methods that have supported their development, scale-up, and deployment. We focus on genetic sensors in living cells whose outputs affect gene expression. We find that emerging high-throughput experimental assays and evolutionary approaches combined with advanced bioinformatics and machine learning are establishing pipelines to produce genetic sensors for virtually any small molecule, protein, or nucleic acid. However, more complex sensing tasks based on classifying compositions of many stimuli and the reliable deployment of these systems into real-world settings remain challenges. We suggest that recent advances in our ability to precisely modify nonmodel organisms and the integration of proven control engineering principles (e.g., feedback) into the broader design of genetic sensing systems will be necessary to overcome these hurdles and realize the immense potential of the field.

[end paper 50]

[begin paper 51]

PMCID = 11245638

Title = ISEV2024 Abstract Book



[end paper 51]

[begin paper 52]

PMCID = 8687476

Title = Structural models of SARS-CoV-2 Omicron variant in complex with ACE2 receptor or antibodies suggest altered binding interfaces

There is enormous ongoing interest in characterizing the binding properties of the SARS-CoV-2 Omicron Variant of Concern (VOC) (B.1.1.529), which continues to spread towards potential dominance worldwide. To aid these studies, based on the wealth of available structural information about several SARS-CoV-2 variants in the Protein Data Bank (PDB) and a modeling pipeline we have previously developed for tracking the ongoing global evolution of SARS-CoV-2 proteins, we provide a set of computed structural models (henceforth models) of the Omicron VOC receptor-binding domain (omRBD) bound to its corresponding receptor Angiotensin-Converting Enzyme (ACE2) and a variety of therapeutic entities, including neutralizing and therapeutic antibodies targeting previously-detected viral strains. We generated bound omRBD models using both experimentally-determined structures in the PDB as well as machine learning-based structure predictions as starting points. Examination of ACE2-bound omRBD models reveals an interdigitated multi-residue interaction network formed by omRBD-specific substituted residues (R493, S496, Y501, R498) and ACE2 residues at the interface, which was not present in the original Wuhan-Hu-1 RBD-ACE2 complex. Emergence of this interaction network suggests optimization of a key region of the binding interface, and positive cooperativity among various sites of residue substitutions in omRBD mediating ACE2 binding. Examination of neutralizing antibody complexes for Barnes Class 1 and Class 2 antibodies modeled with omRBD highlights an overall loss of interfacial interactions (with gain of new interactions in rare cases) mediated by substituted residues. Many of these substitutions have previously been found to independently dampen or even ablate antibody binding, and perhaps mediate antibody-mediated neutralization escape (e.g., K417N). We observe little compensation of corresponding interaction loss at interfaces when potential escape substitutions occur in combination. A few selected antibodies (e.g., Barnes Class 3 S309), however, feature largely unaltered or modestly affected protein-protein interfaces. While we stress that only qualitative insights can be obtained directly from our models at this time, we anticipate that they can provide starting points for more detailed and quantitative computational characterization, and, if needed, redesign of monoclonal antibodies for targeting the Omicron VOC Spike protein. In the broader context, the computational pipeline we developed provides a framework for rapidly and efficiently generating retrospective and prospective models for other novel variants of SARS-CoV-2 bound to entities of virological and therapeutic interest, in the setting of a global pandemic.

[end paper 52]

[begin paper 53]

PMCID = 10468394

Title = De novo design of protein structure and function with RFdiffusion

There has been considerable recent progress in designing new proteins using deep-learning methods. Despite this progress, a general deep-learning framework for protein design that enables solution of a wide range of design challenges, including de novo binder design and design of higher-order symmetric architectures, has yet to be described. Diffusion models have had considerable success in image and language generative modelling but limited success when applied to protein modelling, probably due to the complexity of protein backbone geometry and sequence–structure relationships. Here we show that by fine-tuning the RoseTTAFold structure prediction network on protein structure denoising tasks, we obtain a generative model of protein backbones that achieves outstanding performance on unconditional and topology-constrained protein monomer design, protein binder design, symmetric oligomer design, enzyme active site scaffolding and symmetric motif scaffolding for therapeutic and metal-binding protein design. We demonstrate the power and generality of the method, called RoseTTAFold diffusion (RFdiffusion), by experimentally characterizing the structures and functions of hundreds of designed symmetric assemblies, metal-binding proteins and protein binders. The accuracy of RFdiffusion is confirmed by the cryogenic electron microscopy structure of a designed binder in complex with influenza haemagglutinin that is nearly identical to the design model. In a manner analogous to networks that produce images from user-specified inputs, RFdiffusion enables the design of diverse functional proteins from simple molecular specifications.

Fine-tuning the RoseTTAFold structure prediction network on protein structure denoising tasks yields a generative model for protein design that achieves outstanding performance on a wide range of protein structure and function design challenges.

[end paper 53]

[begin paper 54]

PMCID = 9754107

Title = Advances in the Computational Design of Small-Molecule-Controlled Protein-Based Circuits for Synthetic Biology

Synthetic biology approaches living systems with an engineering perspective and promises to deliver solutions to global challenges in healthcare and sustainability. A critical component is the design of biomolecular circuits with programmable input–output behaviors. Such circuits typically rely on a sensor module that recognizes molecular inputs, which is coupled to a functional output via protein-level circuits or regulating the expression of a target gene. While gene expression outputs can be customized relatively easily by exchanging the target genes, sensing new inputs is a major limitation. There is a limited repertoire of sensors found in nature, and there are often difficulties with interfacing them with engineered circuits. Computational protein design could be a key enabling technology to address these challenges, as it allows for the engineering of modular and tunable sensors that can be tailored to the circuit’s application. In this article, we review recent computational approaches to design protein-based sensors for small-molecule inputs with particular focus on those based on the widely used Rosetta software suite. Furthermore, we review mechanisms that have been harnessed to couple ligand inputs to functional outputs. Based on recent literature, we illustrate how the combination of protein design and synthetic biology enables new sensors for diverse applications ranging from biomedicine to metabolic engineering. We conclude with a perspective on how strategies to address frontiers in protein design and cellular circuit design may enable the next generation of sense-response networks, which may increasingly be assembled from de novo components to display diverse and engineerable input-output behaviors.

This article reviews the field of computational protein design, focusing on the advances in the engineering of synthetic small-molecule-binding protein sensors as well as sensor–actuator proteins.

[end paper 54]

[begin paper 55]

PMCID = 10361724

Title = Structural modeling of antibody variable regions using deep learning—progress and perspectives on drug discovery

AlphaFold2 has hallmarked a generational improvement in protein structure prediction. In particular, advances in antibody structure prediction have provided a highly translatable impact on drug discovery. Though AlphaFold2 laid the groundwork for all proteins, antibody-specific applications require adjustments tailored to these molecules, which has resulted in a handful of deep learning antibody structure predictors. Herein, we review the recent advances in antibody structure prediction and relate them to their role in advancing biologics discovery.

[end paper 55]

[begin paper 56]

PMCID = 9912273

Title = Advancing Targeted Protein Degradation via Multiomics Profiling and Artificial Intelligence

Only around 20% of the human proteome is considered to be druggable with small-molecule antagonists. This leaves some of the most compelling therapeutic targets outside the reach of ligand discovery. The concept of targeted protein degradation (TPD) promises to overcome some of these limitations. In brief, TPD is dependent on small molecules that induce the proximity between a protein of interest (POI) and an E3 ubiquitin ligase, causing ubiquitination and degradation of the POI. In this perspective, we want to reflect on current challenges in the field, and discuss how advances in multiomics profiling, artificial intelligence, and machine learning (AI/ML) will be vital in overcoming them. The presented roadmap is discussed in the context of small-molecule degraders but is equally applicable for other emerging proximity-inducing modalities.

[end paper 56]

[begin paper 57]

PMCID = 9989197

Title = Learned features of antibody-antigen binding affinity

Defining predictors of antigen-binding affinity of antibodies is valuable for engineering therapeutic antibodies with high binding affinity to their targets. However, this task is challenging owing to the huge diversity in the conformations of the complementarity determining regions of antibodies and the mode of engagement between antibody and antigen. In this study, we used the structural antibody database (SAbDab) to identify features that can discriminate high- and low-binding affinity across a 5-log scale. First, we abstracted features based on previously learned representations of protein-protein interactions to derive ‘complex’ feature sets, which include energetic, statistical, network-based, and machine-learned features. Second, we contrasted these complex feature sets with additional ‘simple’ feature sets based on counts of contacts between antibody and antigen. By investigating the predictive potential of 700 features contained in the eight complex and simple feature sets, we observed that simple feature sets perform comparably to complex feature sets in classification of binding affinity. Moreover, combining features from all eight feature-sets provided the best classification performance (median cross-validation AUROC and F1-score of 0.72). Of note, classification performance is substantially improved when several sources of data leakage (e.g., homologous antibodies) are not removed from the dataset, emphasizing a potential pitfall in this task. We additionally observe a classification performance plateau across diverse featurization approaches, highlighting the need for additional affinity-labeled antibody-antigen structural data. The findings from our present study set the stage for future studies aimed at multiple-log enhancement of antibody affinity through feature-guided engineering.

[end paper 57]

[begin paper 58]

PMCID = 10370091

Title = Contextual protein and antibody encodings from equivariant graph transformers

The optimal residue identity at each position in a protein is determined by its structural, evolutionary, and functional context. We seek to learn the representation space of the optimal amino-acid residue in different structural contexts in proteins. Inspired by masked language modeling (MLM), our training aims to transduce learning of amino-acid labels from non-masked residues to masked residues in their structural environments and from general (e.g., a residue in a protein) to specific contexts (e.g., a residue at the interface of a protein or antibody complex). Our results on native sequence recovery and forward folding with AlphaFold2 suggest that the amino acid label for a protein residue may be determined from its structural context alone (i.e., without knowledge of the sequence labels of surrounding residues). We further find that the sequence space sampled from our masked models recapitulate the evolutionary sequence neighborhood of the wildtype sequence. Remarkably, the sequences conditioned on highly plastic structures recapitulate the conformational flexibility encoded in the structures. Furthermore, maximum-likelihood interfaces designed with masked models recapitulate wildtype binding energies for a wide range of protein interfaces and binding strengths. We also propose and compare fine-tuning strategies to train models for designing CDR loops of antibodies in the structural context of the antibody-antigen interface by leveraging structural databases for proteins, antibodies (synthetic and experimental) and protein-protein complexes. We show that pretraining on more general contexts improves native sequence recovery for antibody CDR loops, especially for the hypervariable CDR H3, while fine-tuning helps to preserve patterns observed in special contexts.

[end paper 58]

[begin paper 59]

PMCID = 11206022

Title = The Millennia-Long Development of Drugs Associated with the 80-Year-Old Artificial Intelligence Story: The Therapeutic Big Bang?

The journey of drug discovery (DD) has evolved from ancient practices to modern technology-driven approaches, with Artificial Intelligence (AI) emerging as a pivotal force in streamlining and accelerating the process. Despite the vital importance of DD, it faces challenges such as high costs and lengthy timelines. This review examines the historical progression and current market of DD alongside the development and integration of AI technologies. We analyse the challenges encountered in applying AI to DD, focusing on drug design and protein–protein interactions. The discussion is enriched by presenting models that put forward the application of AI in DD. Three case studies are highlighted to demonstrate the successful application of AI in DD, including the discovery of a novel class of antibiotics and a small-molecule inhibitor that has progressed to phase II clinical trials. These cases underscore the potential of AI to identify new drug candidates and optimise the development process. The convergence of DD and AI embodies a transformative shift in the field, offering a path to overcome traditional obstacles. By leveraging AI, the future of DD promises enhanced efficiency and novel breakthroughs, heralding a new era of medical innovation even though there is still a long way to go.

[end paper 59]

[begin paper 60]

PMCID = 8714685

Title = Agonist antibody discovery: experimental, computational, and rational engineering approaches

Agonist antibodies that activate cellular signaling have emerged as promising therapeutics for treating myriad pathologies. Unfortunately, the discovery of rare antibodies with the desired agonist functions is a major bottleneck during drug development. Nevertheless, there has been important recent progress in discovering and optimizing agonist antibodies against a variety of therapeutic targets that are activated by diverse signaling mechanisms. Herein, we review emerging high-throughput experimental and computational methods for agonist antibody discovery as well as rational molecular engineering methods for optimizing their agonist activity.

[end paper 60]

[begin paper 61]

PMCID = 9684400

Title = Development of therapeutic antibodies for the treatment of diseases

Since the first monoclonal antibody drug, muromonab-CD3, was approved for marketing in 1986, 165 antibody drugs have been approved or are under regulatory review worldwide. With the approval of new drugs for treating a wide range of diseases, including cancer and autoimmune and metabolic disorders, the therapeutic antibody drug market has experienced explosive growth. Monoclonal antibodies have been sought after by many biopharmaceutical companies and scientific research institutes due to their high specificity, strong targeting abilities, low toxicity, side effects, and high development success rate. The related industries and markets are growing rapidly, and therapeutic antibodies are one of the most important research and development areas in the field of biology and medicine. In recent years, great progress has been made in the key technologies and theoretical innovations provided by therapeutic antibodies, including antibody–drug conjugates, antibody-conjugated nuclides, bispecific antibodies, nanobodies, and other antibody analogs. Additionally, therapeutic antibodies can be combined with technologies used in other fields to create new cross-fields, such as chimeric antigen receptor T cells (CAR-T), CAR-natural killer cells (CAR-NK), and other cell therapy. This review summarizes the latest approved or in regulatory review therapeutic antibodies that have been approved or that are under regulatory review worldwide, as well as clinical research on these approaches and their development, and outlines antibody discovery strategies that have emerged during the development of therapeutic antibodies, such as hybridoma technology, phage display, preparation of fully human antibody from transgenic mice, single B-cell antibody technology, and artificial intelligence-assisted antibody discovery.

The online version contains supplementary material available at 10.1186/s43556-022-00100-4.

[end paper 61]

[begin paper 62]

PMCID = 10761793

Title = Programmable synthetic receptors: the next-generation of cell and gene therapies

Cell and gene therapies hold tremendous promise for treating a range of difficult-to-treat diseases. However, concerns over the safety and efficacy require to be further addressed in order to realize their full potential. Synthetic receptors, a synthetic biology tool that can precisely control the function of therapeutic cells and genetic modules, have been rapidly developed and applied as a powerful solution. Delicately designed and engineered, they can be applied to finetune the therapeutic activities, i.e., to regulate production of dosed, bioactive payloads by sensing and processing user-defined signals or biomarkers. This review provides an overview of diverse synthetic receptor systems being used to reprogram therapeutic cells and their wide applications in biomedical research. With a special focus on four synthetic receptor systems at the forefront, including chimeric antigen receptors (CARs) and synthetic Notch (synNotch) receptors, we address the generalized strategies to design, construct and improve synthetic receptors. Meanwhile, we also highlight the expanding landscape of therapeutic applications of the synthetic receptor systems as well as current challenges in their clinical translation.

[end paper 62]

[begin paper 63]

PMCID = 11788754

Title = An outlook on structural biology after AlphaFold: tools, limits and perspectives

AlphaFold and similar groundbreaking, AI‐based tools, have revolutionized the field of structural bioinformatics, with their remarkable accuracy in ab‐initio protein structure prediction. This success has catalyzed the development of new software and pipelines aimed at incorporating AlphaFold's predictions, often focusing on addressing the algorithm's remaining challenges. Here, we present the current landscape of structural bioinformatics shaped by AlphaFold, and discuss how the field is dynamically responding to this revolution, with new software, methods, and pipelines. While the excitement around AI‐based tools led to their widespread application, it is essential to acknowledge that their practical success hinges on their integration into established protocols within structural bioinformatics, often neglected in the context of AI‐driven advancements. Indeed, user‐driven intervention is still as pivotal in the structure prediction process as in complementing state‐of‐the‐art algorithms with functional and biological knowledge.

Rendering of a GFP‐like fluorescent protein, starting from its AF‐generated PDB coordinates. Like AI algorithms for image generation focus on creating realistic and detailed content, AI‐based algorithms for protein structure generation aim to accurately generate/predict complex molecular arrangements. Figure generated using CGDream (https://cgdream.ai). 

[end paper 63]

[begin paper 64]

PMCID = 10356834

Title = GPCRome-wide analysis of G-protein-coupling diversity using a computational biology approach

GPCRs are master regulators of cell signaling by transducing extracellular stimuli into the cell via selective coupling to intracellular G-proteins. Here we present a computational analysis of the structural determinants of G-protein-coupling repertoire of experimental and predicted 3D GPCR-G-protein complexes. Interface contact analysis recapitulates structural hallmarks associated with G-protein-coupling specificity, including TM5, TM6 and ICLs. We employ interface contacts as fingerprints to cluster Gs vs Gi complexes in an unsupervised fashion, suggesting that interface residues contribute to selective coupling. We experimentally confirm on a promiscuous receptor (CCKAR) that mutations of some of these specificity-determining positions bias the coupling selectivity. Interestingly, Gs-GPCR complexes have more conserved interfaces, while Gi/o proteins adopt a wider number of alternative docking poses, as assessed via structural alignments of representative 3D complexes. Binding energy calculations demonstrate that distinct structural properties of the complexes are associated to higher stability of Gs than Gi/o complexes. AlphaFold2 predictions of experimental binary complexes confirm several of these structural features and allow us to augment the structural coverage of poorly characterized complexes such as G12/13.

Selective GPCR-G protein complexes formation is critical for signal transduction regulation. Here, the authors use a data-driven approach to show that the structures of experimental and predicted complex interfaces inform, at least partially, on G protein binding preferences.

[end paper 64]

[begin paper 65]

PMCID = 7589779

Title = Toward Drug-Like Multispecific Antibodies by Design

The success of antibody therapeutics is strongly influenced by their multifunctional nature that couples antigen recognition mediated by their variable regions with effector functions and half-life extension mediated by a subset of their constant regions. Nevertheless, the monospecific IgG format is not optimal for many therapeutic applications, and this has led to the design of a vast number of unique multispecific antibody formats that enable targeting of multiple antigens or multiple epitopes on the same antigen. Despite the diversity of these formats, a common challenge in generating multispecific antibodies is that they display suboptimal physical and chemical properties relative to conventional IgGs and are more difficult to develop into therapeutics. Here we review advances in the design and engineering of multispecific antibodies with drug-like properties, including favorable stability, solubility, viscosity, specificity and pharmacokinetic properties. We also highlight emerging experimental and computational methods for improving the next generation of multispecific antibodies, as well as their constituent antibody fragments, with natural IgG-like properties. Finally, we identify several outstanding challenges that need to be addressed to increase the success of multispecific antibodies in the clinic.

[end paper 65]

[begin paper 66]

PMCID = 11324344

Title = Locuaz: an in silico platform for protein binders optimization

Engineering high-affinity binders targeting specific antigenic determinants remains a challenging and often daunting task, requiring extensive experimental screening. Computational methods have the potential to accelerate this process, reducing costs and time, but only if they demonstrate broad applicability and efficiency in exploring mutations, evaluating affinity, and pruning unproductive mutation paths.

In response to these challenges, we introduce a new computational platform for optimizing protein binders towards their targets. The platform is organized as a series of modules, performing mutation selection and application, molecular dynamics simulations to sample conformations around interaction poses, and mutation prioritization using suitable scoring functions. Notably, the platform supports parallel exploration of different mutation streams, enabling in silico high-throughput screening on High Performance Computing (HPC) systems. Furthermore, the platform is highly customizable, allowing users to implement their own protocols.

The source code is available at https://github.com/pgbarletta/locuaz and documentation is at https://locuaz.readthedocs.io/. The data underlying this article are available at https://github.com/pgbarletta/suppl_info_locuaz

[end paper 66]

[begin paper 67]

PMCID = 10282643

Title = Solvated interaction energy: from small-molecule to antibody drug design

Scoring functions are ubiquitous in structure-based drug design as an aid to predicting binding modes and estimating binding affinities. Ideally, a scoring function should be broadly applicable, obviating the need to recalibrate and refit its parameters for every new target and class of ligands. Traditionally, drugs have been small molecules, but in recent years biologics, particularly antibodies, have become an increasingly important if not dominant class of therapeutics. This makes the goal of having a transferable scoring function, i.e., one that spans the range of small-molecule to protein ligands, even more challenging. One such broadly applicable scoring function is the Solvated Interaction Energy (SIE), which has been developed and applied in our lab for the last 15 years, leading to several important applications. This physics-based method arose from efforts to understand the physics governing binding events, with particular care given to the role played by solvation. SIE has been used by us and many independent labs worldwide for virtual screening and discovery of novel small-molecule binders or optimization of known drugs. Moreover, without any retraining, it is found to be transferrable to predictions of antibody-antigen relative binding affinities and as accurate as functions trained on protein-protein binding affinities. SIE has been incorporated in conjunction with other scoring functions into ADAPT (Assisted Design of Antibody and Protein Therapeutics), our platform for affinity modulation of antibodies. Application of ADAPT resulted in the optimization of several antibodies with 10-to-100-fold improvements in binding affinity. Further applications included broadening the specificity of a single-domain antibody to be cross-reactive with virus variants of both SARS-CoV-1 and SARS-CoV-2, and the design of safer antibodies by engineering of a pH switch to make them more selective towards acidic tumors while sparing normal tissues at physiological pH.

[end paper 67]

[begin paper 68]

PMCID = 11574076

Title = Rational strategies for improving the efficiency of design and discovery of nanomedicines

The rise of rational strategies in nanomedicine development, such as high-throughput methods and computer-aided techniques, has led to a shift in the design and discovery patterns of nanomedicines from a trial-and-error mode to a rational mode. This transition facilitates the enhancement of efficiency in the preclinical discovery pipeline of nanomaterials, particularly in improving the hit rate of nanomaterials and the optimization efficiency of promising candidates. Herein, we describe a directed evolution mode of nanomedicines driven by data to accelerate the discovery of nanomaterials with high delivery efficiency. Computer-aided design strategies are introduced in detail as one of the cutting-edge directions for the development of nanomedicines. Ultimately, we look forward to expanding the tools for the rational design and discovery of nanomaterials using multidisciplinary approaches. Rational design strategies may potentially boost the delivery efficiency of next-generation nanomedicines.

The rise of high-throughput methods and computer-aided techniques has led to a shift in the design and discovery patterns of nanomedicines to a data-driven and rational mode. In this perspective, the authors describe a directed evolution mode of nanomedicines driven by data to accelerate the discovery of nanomaterials with high delivery efficiency.

[end paper 68]

[begin paper 69]

PMCID = 10108624

Title = In vivo hypermutation and continuous evolution



[end paper 69]

[begin paper 70]

PMCID = 7319589

Title = mmCSM-AB: guiding rational antibody engineering through multiple point mutations

While antibodies are becoming an increasingly important therapeutic class, especially in personalized medicine, their development and optimization has been largely through experimental exploration. While there have been many efforts to develop computational tools to guide rational antibody engineering, most approaches are of limited accuracy when applied to antibody design, and have largely been limited to analysing a single point mutation at a time. To overcome this gap, we have curated a dataset of 242 experimentally determined changes in binding affinity upon multiple point mutations in antibody-target complexes (89 increasing and 153 decreasing binding affinity). Here, we have shown that by using our graph-based signatures and atomic interaction information, we can accurately analyse the consequence of multi-point mutations on antigen binding affinity. Our approach outperformed other available tools across cross-validation and two independent blind tests, achieving Pearson's correlations of up to 0.95. We have implemented our new approach, mmCSM-AB, as a web-server that can help guide the process of affinity maturation in antibody design. mmCSM-AB is freely available at http://biosig.unimelb.edu.au/mmcsm_ab/.

[end paper 70]

[begin paper 71]

PMCID = 5743843

Title = Award Winners and Abstracts of the 31st Annual Symposium of The Protein Society, Montreal, Canada, July 24–27, 2017



[end paper 71]

[begin paper 72]

PMCID = 11701522

Title = SYNBIP 2.0: epitopes mapping, sequence expansion and scaffolds discovery for synthetic binding protein innovation

Synthetic binding proteins (SBPs) represent a pivotal class of artificially engineered proteins, meticulously crafted to exhibit targeted binding properties and specific functions. Here, the SYNBIP database, a comprehensive resource for SBPs, has been significantly updated. These enhancements include (i) featuring 3D structures of 899 SBP–target complexes to illustrate the binding epitopes of SBPs, (ii) using the structures of SBPs in the monomer or complex forms with target proteins, their sequence space has been expanded five times to 12 025 by integrating a structure-based protein generation framework and a protein property prediction tool, (iii) offering detailed information on 78 473 newly identified SBP-like scaffolds from the RCSB Protein Data Bank, and an additional 16 401 555 ones from the AlphaFold Protein Structure Database, and (iv) the database is regularly updated, incorporating 153 new SBPs. Furthermore, the structural models of all SBPs have been enhanced through the application of the AlphaFold2, with their clinical statuses concurrently refreshed. Additionally, the design methods employed for each SBP are now prominently featured in the database. In sum, SYNBIP 2.0 is designed to provide researchers with essential SBP data, facilitating their innovation in research, diagnosis and therapy. SYNBIP 2.0 is now freely accessible at https://idrblab.org/synbip/.

[end paper 72]

[begin paper 73]

PMCID = 11783119

Title = Epitope mapping via in vitro deep mutational scanning methods and its applications

Epitope mapping is a technique employed to define the region of an antigen that elicits an immune response, providing crucial insight into the structural architecture of the antigen as well as epitope-paratope interactions. With this breadth of knowledge, immunotherapies, diagnostics, and vaccines are being developed with a rational and data-supported design. Traditional epitope mapping methods are laborious, time-intensive, and often lack the ability to screen proteins in a high-throughput manner or provide high resolution. Deep mutational scanning (DMS), however, is revolutionizing the field as it can screen all possible single amino acid mutations and provide an efficient and high-throughput way to infer the structures of both linear and three-dimensional epitopes with high resolution. Currently, more than 50 publications take this approach to efficiently identify enhancing or escaping mutations, with many then employing this information to rapidly develop broadly neutralizing antibodies, T-cell immunotherapies, vaccine platforms, or diagnostics. We provide a comprehensive review of the approaches to accomplish epitope mapping while also providing a summation of the development of DMS technology and its impactful applications.

[end paper 73]

[begin paper 74]

PMCID = 10187017

Title = ISEV2023 Abstract Book



[end paper 74]

[begin paper 75]

PMCID = 10507807

Title =  De novo design of a stapled peptide targeting SARS-CoV-2 spike protein receptor-binding domain†

Although effective vaccines have been developed against SARS-CoV-2, many regions in the world still have low rates of vaccination and new variants with mutations in the viral spike protein have reduced the effectiveness of most available vaccines and treatments. There is an urgent need for a drug to cure this disease and prevent infection. The SARS-CoV-2 virus enters the host cell through protein–protein interaction between the virus's spike protein and the host's angiotensin converting enzyme (ACE2). Using protein design software and molecular dynamics simulations, we have designed a 17-residue peptide (pep39), that binds to the spike protein receptor-binding domain (RBD) and blocks interaction of spike protein with ACE2. We have confirmed the binding activity of the designed peptide for the original spike protein and the delta variant spike protein using micro-cantilever and bio-layer interferometry (BLI) based methods. We also confirmed that pep39 strongly inhibits SARS-CoV-2 virus replication in Vero E6 cells. Taken together these data suggest that a newly designed spike protein RBD blocking peptide pep39 has a potential as a SARS-CoV-2 virus inhibitor.

Binding configuration of a de novo stapled peptide on SARS-CoV-2 spike protein, as predicted by molecular simulation. Stapled residues enhance peptide stability while interacting residues engage key amino acids on the protein receptor-binding domain.

[end paper 75]

[begin paper 76]

PMCID = 10594513

Title = Structure and Dynamics Guiding Design of Antibody Therapeutics and Vaccines

Antibodies and other new antibody-like formats have emerged as one of the most rapidly growing classes of biotherapeutic proteins. Understanding the structural features that drive antibody function and, consequently, their molecular recognition is critical for engineering antibodies. Here, we present the structural architecture of conventional IgG antibodies alongside other formats. We emphasize the importance of considering antibodies as conformational ensembles in solution instead of focusing on single-static structures because their functions and properties are strongly governed by their dynamic nature. Thus, in this review, we provide an overview of the unique structural and dynamic characteristics of antibodies with respect to their antigen recognition, biophysical properties, and effector functions. We highlight the numerous technical advances in antibody structure prediction and design, enabled by the vast number of experimentally determined high-quality structures recorded with cryo-EM, NMR, and X-ray crystallography. Lastly, we assess antibody and vaccine design strategies in the context of structure and dynamics.

[end paper 76]

[begin paper 77]

PMCID = 11236705

Title = Computational design of soluble and functional membrane protein analogues

De novo design of complex protein folds using solely computational means remains a substantial challenge. Here we use a robust deep learning pipeline to design complex folds and soluble analogues of integral membrane proteins. Unique membrane topologies, such as those from G-protein-coupled receptors, are not found in the soluble proteome, and we demonstrate that their structural features can be recapitulated in solution. Biophysical analyses demonstrate the high thermal stability of the designs, and experimental structures show remarkable design accuracy. The soluble analogues were functionalized with native structural motifs, as a proof of concept for bringing membrane protein functions to the soluble proteome, potentially enabling new approaches in drug discovery. In summary, we have designed complex protein topologies and enriched them with functionalities from membrane proteins, with high experimental success rates, leading to a de facto expansion of the functional soluble fold space.

A deep learning approach enables accurate computational design of soluble and functional analogues of membrane proteins, expanding the soluble protein fold space and facilitating new approaches to drug screening and design.

[end paper 77]

[begin paper 78]

PMCID = 11118692

Title = De novo designed proteins neutralize lethal snake venom toxins

Snakebite envenoming remains a devastating and neglected tropical disease, claiming over 100,000 lives annually and causing severe complications and long-lasting disabilities for many more. Three-finger toxins (3FTx) are highly toxic components of elapid snake venoms that can cause diverse pathologies, including severe tissue damage and inhibition of nicotinic acetylcholine receptors (nAChRs) resulting in life-threatening neurotoxicity. Currently, the only available treatments for snakebite consist of polyclonal antibodies derived from the plasma of immunized animals, which have high cost and limited efficacy against 3FTxs. Here, we use deep learning methods to de novo design proteins to bind short- and long-chain α-neurotoxins and cytotoxins from the 3FTx family. With limited experimental screening, we obtain protein designs with remarkable thermal stability, high binding affinity, and near-atomic level agreement with the computational models. The designed proteins effectively neutralize all three 3FTx sub-families in vitro and protect mice from a lethal neurotoxin challenge. Such potent, stable, and readily manufacturable toxin-neutralizing proteins could provide the basis for safer, cost-effective, and widely accessible next-generation antivenom therapeutics. Beyond snakebite, our computational design methodology should help democratize therapeutic discovery, particularly in resource-limited settings, by substantially reducing costs and resource requirements for development of therapies to neglected tropical diseases.

[end paper 78]

[begin paper 79]

PMCID = 10042144

Title = Computational Protein Design for COVID-19 Research and Emerging Therapeutics

As the world struggles with the ongoing COVID-19 pandemic, unprecedented obstacles have continuously been traversed as new SARS-CoV-2 variants continually emerge. Infectious disease outbreaks are unavoidable, but the knowledge gained from the successes and failures will help create a robust health management system to deal with such pandemics. Previously, scientists required years to develop diagnostics, therapeutics, or vaccines; however, we have seen that, with the rapid deployment of high-throughput technologies and unprecedented scientific collaboration worldwide, breakthrough discoveries can be accelerated and insights broadened. Computational protein design (CPD) is a game-changing new technology that has provided alternative therapeutic strategies for pandemic management. In addition to the development of peptide-based inhibitors, miniprotein binders, decoys, biosensors, nanobodies, and monoclonal antibodies, CPD has also been used to redesign native SARS-CoV-2 proteins and human ACE2 receptors. We discuss how novel CPD strategies have been exploited to develop rationally designed and robust COVID-19 treatment strategies.

This outlook summarizes CPD approaches utilized for the development of SARS-CoV-2 therapeutics and highlights the current challenges and future directions of CPD to tackle various infectious diseases.

[end paper 79]

[begin paper 80]

PMCID = 10371346

Title = Modeling of ACE2 and antibodies bound to SARS-CoV-2 provides insights into infectivity and immune evasion

Given the COVID-19 pandemic, there is interest in understanding ligand-receptor features and targeted antibody-binding attributes against emerging SARS-CoV-2 variants. Here, we developed a large-scale structure-based pipeline for analysis of protein-protein interactions regulating SARS-CoV-2 immune evasion. First, we generated computed structural models of the Spike protein of 3 SARS-CoV-2 variants (B.1.1.529, BA.2.12.1, and BA.5) bound either to a native receptor (ACE2) or to a large panel of targeted ligands (n = 282), which included neutralizing or therapeutic monoclonal antibodies. Moreover, by using the Barnes classification, we noted an overall loss of interfacial interactions (with gain of new interactions in certain cases) at the receptor-binding domain (RBD) mediated by substituted residues for neutralizing complexes in classes 1 and 2, whereas less destabilization was observed for classes 3 and 4. Finally, an experimental validation of predicted weakened therapeutic antibody binding was performed in a cell-based assay. Compared with the original Omicron variant (B.1.1.529), derivative variants featured progressive destabilization of antibody-RBD interfaces mediated by a larger set of substituted residues, thereby providing a molecular basis for immune evasion. This approach and findings provide a framework for rapidly and efficiently generating structural models for SARS-CoV-2 variants bound to ligands of mechanistic and therapeutic value.

[end paper 80]

[begin paper 81]

PMCID = 7423244

Title = Performance of Human and Server Prediction in CAPRI rounds 38–45

CAPRI challenges offer a variety of blind tests for protein-protein interaction prediction. In CAPRI Rounds 38–45, we generated a set of putative binding modes for each target with an FFT-based docking algorithm, and then scored and ranked these binding modes with a proprietary scoring function, ITScorePP. We have also developed a novel web server, Rebipp. The algorithm utilizes information retrieval to identify relevant biological information to significantly reduce the search space for a particular protein. In parallel, we have also constructed a GPU-based docking server, MDockPP, for protein-protein complex structure prediction. Here, the performance of our protocol in CAPRI rounds 38–45 is reported, which include 16 docking and scoring targets. Among them, three targets contain multiple interfaces: Targets 124, 125 and 136 have 2, 4 and 3 interfaces, respectively. In the predictor experiments, we predicted correct binding modes for nine targets, including one high-accuracy interface, six medium-accuracy binding modes, and six acceptable-accuracy binding modes. For the docking server prediction experiments, we predicted correct binding modes for eight targets, including one high-accuracy, three medium-accuracy, and five acceptable-accuracy binding modes.

[end paper 81]

[begin paper 82]

PMCID = 10179857

Title = PROTACs in the Management of Prostate Cancer

Cancer treatments with targeted therapy have gained immense interest due to their low levels of toxicity and high selectivity. Proteolysis-Targeting Chimeras (PROTACs) have drawn special attention in the development of cancer therapeutics owing to their unique mechanism of action, their ability to target undruggable proteins, and their focused target engagement. PROTACs selectively degrade the target protein through the ubiquitin–proteasome system, which describes a different mode of action compared to conventional small-molecule inhibitors or even antibodies. Among different cancer types, prostate cancer (PC) is the most prevalent non-cutaneous cancer in men. Genetic alterations and the overexpression of several genes, such as FOXA1, AR, PTEN, RB1, TP53, etc., suppress the immune response, resulting in drug resistance to conventional drugs in prostate cancer. Since the progression of ARV-110 (PROTAC for PC) into clinical phases, the focus of research has quickly shifted to protein degraders targeting prostate cancer. The present review highlights an overview of PROTACs in prostate cancer and their superiority over conventional inhibitors. We also delve into the underlying pathophysiology of the disease and explain the structural design and linkerology strategies for PROTAC molecules. Additionally, we touch on the various targets for PROTAC in prostate cancer, including the androgen receptor (AR) and other critical oncoproteins, and discuss the future prospects and challenges in this field.

[end paper 82]

[begin paper 83]

PMCID = 10402144

Title = Reliable protein-protein docking with AlphaFold, Rosetta, and replica-exchange

Despite the recent breakthrough of AlphaFold (AF) in the field of protein sequence-to-structure prediction, modeling protein interfaces and predicting protein complex structures remains challenging, especially when there is a significant conformational change in one or both binding partners. Prior studies have demonstrated that AF-multimer (AFm) can predict accurate protein complexes in only up to 43% of cases. In this work, we combine AlphaFold as a structural template generator with a physics-based replica exchange docking algorithm. Using a curated collection of 254 available protein targets with both unbound and bound structures, we first demonstrate that AlphaFold confidence measures (pLDDT) can be repurposed for estimating protein flexibility and docking accuracy for multimers. We incorporate these metrics within our ReplicaDock 2.0 protocol to complete a robust in-silico pipeline for accurate protein complex structure prediction. AlphaRED (AlphaFold-initiated Replica Exchange Docking) successfully docks failed AF predictions including 97 failure cases in Docking Benchmark Set 5.5. AlphaRED generates CAPRI acceptable-quality or better predictions for 66% of benchmark targets. Further, on a subset of antigen-antibody targets, which is challenging for AFm (19% success rate), AlphaRED demonstrates a success rate of 51%. This new strategy demonstrates the success possible by integrating deep-learning based architectures trained on evolutionary information with physics-based enhanced sampling. The pipeline is available at github.com/Graylab/AlphaRED.

[end paper 83]

[begin paper 84]

PMCID = 8218620

Title = Steering Molecular Activity with Optogenetics: Recent Advances and Perspectives

Optogenetics utilizes photosensitive proteins to manipulate the localization and interaction of molecules in living cells. Because light can be rapidly switched and conveniently confined to the sub-micrometer scale, optogenetics allows for controlling cellular events with an unprecedented resolution in time and space. The past decade has witnessed an enormous progress in the field of optogenetics within the biological sciences. The ever-increasing amount of optogenetic tools, however, can overwhelm the selection of appropriate optogenetic strategies. Considering that each optogenetic tool may have a distinct mode of action, a comparative analysis of the current optogenetic toolbox can promote the further use of optogenetics, especially by researchers new to this field. This review provides such a compilation that highlights the spatiotemporal accuracy of current optogenetic systems. Recent advances of optogenetics in live cells and animal models are summarized, the emerging work that interlinks optogenetics with other research fields is presented, and exciting clinical and industrial efforts to employ optogenetic strategy toward disease intervention are reported.

[end paper 84]

[begin paper 85]

PMCID = 6080095

Title =  In Silico Studies Targeting G-protein Coupled Receptors for Drug Research Against Parkinson’s Disease

Parkinson’s Disease (PD) is a long-term neurodegenerative brain disorder that mainly affects the motor system. The causes are still unknown, and even though currently there is no cure, several therapeutic options are available to manage its symptoms. The development of novel anti-parkinsonian agents and an understanding of their proper and optimal use are, indeed, highly demanding. For the last decades, L-3,4-DihydrOxyPhenylAlanine or levodopa (L-DOPA) has been the gold-standard therapy for the symptomatic treatment of motor dysfunctions associated to PD. However, the development of dyskinesias and motor fluctuations (wearing-off and on-off phenomena) associated with long-term L-DOPA replacement therapy have limited its antiparkinsonian efficacy. The investigation for non-dopaminergic therapies has been largely explored as an attempt to counteract the motor side effects associated with dopamine replacement therapy. Being one of the largest cell membrane protein families, G-Protein-Coupled Receptors (GPCRs) have become a relevant target for drug discovery focused on a wide range of therapeutic areas, including Central Nervous System (CNS) diseases. The modulation of specific GPCRs potentially implicated in PD, excluding dopamine receptors, may provide promising non-dopaminergic therapeutic alternatives for symptomatic treatment of PD. In this review, we focused on the impact of specific GPCR subclasses, including dopamine receptors, adenosine receptors, muscarinic acetylcholine receptors, metabotropic glutamate receptors, and 5-hydroxytryptamine receptors, on the pathophysiology of PD and the importance of structure- and ligand-based in silico approaches for the development of small molecules to target these receptors.

[end paper 85]

[begin paper 86]

PMCID = 6872852

Title = Discovery of novel helix binding sites at protein-protein interfaces

Protein-protein interactions (PPIs) play a key role in numerous biological processes. Many efforts have been undertaken to develop PPI modulators for therapeutic applications; however, to date, most of the peptide binders designed to target PPIs are derived from native binding helices or using the native helix binding site, which has limited the applications of protein-protein interface binding peptide design. Here, we developed a general computational algorithm, HPer (Helix Positioner), that locates single-helix binding sites at protein-protein interfaces based on the structure of protein targets. HPer performed well on known single-helix-mediated PPIs and recaptured the key interactions and hot-spot residues of native helical binders. We also screened non-helical-mediated PPIs in the PDBbind database and identified 17 PPIs that were suitable for helical peptide binding, and the helical binding sites in these PPIs were also predicted for designing novel peptide ligands. The L2 domain of EGFR, which was the top ranked, was selected as an example to show the protocol and results of designing novel helical peptide ligands on the searched binding site. The binding stability of the designed sequences were further investigated using molecular dynamics simulations.

[end paper 86]

[begin paper 87]

PMCID = 9720397

Title = Research progress on unique paratope structure, antigen binding modes, and systematic mutagenesis strategies of single-domain antibodies

Single-domain antibodies (sdAbs) showed the incredible advantages of small molecular weight, excellent affinity, specificity, and stability compared with traditional IgG antibodies, so their potential in binding hidden antigen epitopes and hazard detection in food, agricultural and veterinary fields were gradually explored. Moreover, its low immunogenicity, easy-to-carry target drugs, and penetration of the blood-brain barrier have made sdAbs remarkable achievements in medical treatment, toxin neutralization, and medical imaging. With the continuous development and maturity of modern molecular biology, protein analysis software and database with different algorithms, and next-generation sequencing technology, the unique paratope structure and different antigen binding modes of sdAbs compared with traditional IgG antibodies have aroused the broad interests of researchers with the increased related studies. However, the corresponding related summaries are lacking and needed. Different antigens, especially hapten antigens, show distinct binding modes with sdAbs. So, in this paper, the unique paratope structure of sdAbs, different antigen binding cases, and the current maturation strategy of sdAbs were classified and summarized. We hope this review lays a theoretical foundation to elucidate the antigen-binding mechanism of sdAbs and broaden the further application of sdAbs.

[end paper 87]

[begin paper 88]

PMCID = 8725378

Title = Directing Evolution of Novel Ligands by mRNA Display

mRNA display is a powerful biological display platform for the directed evolution of proteins and peptides. mRNA display libraries covalently link the displayed peptide or protein (phenotype) with the encoding genetic information (genotype) through the biochemical activity of the small molecule puromycin. Selection for peptide/protein function is followed by amplification of the linked genetic material and generation of a library enriched in functional sequences. Iterative selection cycles are then performed until the desired level of function is achieved, at which time the identity of candidate peptides can be obtained by sequencing the genetic material.

The purpose of this review is to discuss the development of mRNA display technology since its inception in 1997 and to comprehensively review its use in the selection of novel peptides and proteins. We begin with an overview of the biochemical mechanism of mRNA display and its variants with a particular focus on its advantages and disadvantages relative to other biological display technologies. We then discuss the importance of scaffold choice in mRNA display selections and review the results of selection experiments with biological (e.g., fibronectin) and linear peptide library architectures. We then explore recent progress in the development of “drug-like” peptides by mRNA display through the post-translational covalent macrocyclization and incorporation of non-proteogenic functionalities. We conclude with an examination of enabling technologies that increase the speed of selection experiments, enhance the information obtained in post-selection sequence analysis, and facilitate high-throughput characterization of lead compounds. We hope to provide the reader with a comprehensive view of current state and future trajectory of mRNA display and its broad utility as a peptide and protein design tool.

[end paper 88]

[begin paper 89]

PMCID = 3376864

Title = Current methods in structural proteomics and its applications in biological sciences

A broad working definition of structural proteomics (SP) is that it is the process of the high-throughput characterization of the three-dimensional structures of biological macromolecules. Recently, the process for protein structure determination has become highly automated and SP platforms have been established around the globe, utilizing X-ray crystallography as a tool. Although protein structures often provide clues about the biological function of a target, once the three-dimensional structures have been determined, bioinformatics and proteomics-driven strategies can be employed to derive their biological activities and physiological roles. This article reviews the current status of SP methods for the structure determination pipeline, including target selection, isolation, expression, purification, crystallization, diffraction data collection, structure solution, refinement and functional annotation.

[end paper 89]

[begin paper 90]

PMCID = 11288453

Title = A label-free G-quadruplex aptamer/gold nanoparticle-based colorimetric biosensor for rapid detection of bovine viral diarrhea virus genotype 1

Bovine viral diarrhea virus (BVDV) is the cause of bovine viral diarrhea disease, one of the most economically important livestock diseases worldwide. The majority of BVD disease control programs rely on the detection and then elimination of persistent infection (PI) cattle, as the continuing source of disease. The main purpose of this study was to design and develop an accurate G-quadruplex-based aptasensor for rapid and simple detection of BVDV-1. In this work, we utilized in silico techniques to design a G-quadruplex aptamer specific for the detection of BVDV-1. Also, the rationally designed aptamer was validated experimentally and was used for developing a colorimetric biosensor based on an aptamer-gold nanoparticle system. Firstly, a pool of G-quadruplex forming ssDNA sequences was constructed. Then, based on the stability score in secondary and tertiary structures and molecular docking score, an aptamer (Apt31) was selected. In the experimental part, gold nanoparticles (AuNPs) with an average particle size of 31.7 nm were synthesized and electrostatically linked with the Apt31. The colorimetric test showed that salt-induced color change of AuNPs from red to purple-blue occurs only in the presence of BVDV-Apt31 complex, after 20 min. These results approved the specificity of Apt31 for BVDV. Furthermore, our biosensor could detect the virus at as low as 0.27 copies/ml, which is an acceptable value in comparison to the qPCR method. The specificity of the aptasensor was confirmed through cross-reactivity testing, while its selectivity was confirmed through plasma testing. The sample analysis showed 90% precision and 94% accuracy. It was concluded that the biosensor was adequately sensitive and specific for the detection of BVDV in plasma samples and could be used as a simple and rapid method on the farm.

[end paper 90]

[begin paper 91]

PMCID = 10535987

Title = Therapeutic Antibodies in Medicine

Antibody engineering has developed into a wide-reaching field, impacting a multitude of industries, most notably healthcare and diagnostics. The seminal work on developing the first monoclonal antibody four decades ago has witnessed exponential growth in the last 10–15 years, where regulators have approved monoclonal antibodies as therapeutics and for several diagnostic applications, including the remarkable attention it garnered during the pandemic. In recent years, antibodies have become the fastest-growing class of biological drugs approved for the treatment of a wide range of diseases, from cancer to autoimmune conditions. This review discusses the field of therapeutic antibodies as it stands today. It summarizes and outlines the clinical relevance and application of therapeutic antibodies in treating a landscape of diseases in different disciplines of medicine. It discusses the nomenclature, various approaches to antibody therapies, and the evolution of antibody therapeutics. It also discusses the risk profile and adverse immune reactions associated with the antibodies and sheds light on future applications and perspectives in antibody drug discovery.

[end paper 91]

[begin paper 92]

PMCID = 4887520

Title = The Fifth International Meeting of ISEV, ISEV2016, Rotterdam, The Netherlands, 4 – 7 May, 2016



[end paper 92]

[begin paper 93]

PMCID = 11230293

Title = A Comparison of Antibody-Antigen Complex Sequence-to-Structure Prediction Methods and their Systematic Biases



[end paper 93]

[begin paper 94]

PMCID = 4001129

Title = Abstracts from the Third International Meeting of ISEV 2014 Rotterdam, The Netherlands, April 30th – May 3rd, 2014



[end paper 94]

[begin paper 95]

PMCID = 11423973

Title = Molecular mechanism and structure-guided humanization of a broadly neutralizing antibody against SFTSV

Severe fever with thrombocytopenia syndrome virus (SFTSV) is a novel tick-borne bunyavirus that causes severe fever with thrombocytopenia syndrome (SFTS), with a high mortality rate of up to 30%. The envelope glycoproteins of SFTSV, glycoprotein N (Gn) and glycoprotein C (Gc), facilitate the recognition of host receptors and the process of membrane fusion, allowing the virus to enter host cells. We previously reported a monoclonal antibody, mAb 40C10, capable of neutralizing different genotypes of SFTSV and SFTSV-related viruses. However, the specific neutralization mechanism is poorly understood. In this study, we elucidated the high-resolution structure of the SFTSV Gn head domain in complex with mAb 40C10, confirming that the binding epitope in the domain I region of SFTSV Gn, and it represented that a novel binding epitope of SFTSV Gn was identified. Through in-depth structural and sequence analyses, we found that the binding sites of mAb 40C10 are relatively conserved among different genotypes of SFTSV and SFTSV-related Heartland virus and Guertu virus, elucidating the molecular mechanism underlying the broad-spectrum neutralizing activity of mAb 40C10. Furthermore, we humanized of mAb 40C10, which is originally of murine origin, to reduce its immunogenicity. The resulting nine humanized antibodies maintained potent affinity and neutralizing activity. One of the humanized antibodies exhibited neutralizing activity at picomolar IC50 values and demonstrated effective therapeutic and protective effects in a mouse infection model. These findings provide a novel target for the future development of SFTSV vaccines or drugs and establish a foundation for the research and development of antibody therapeutics for clinical applications.

Severe fever with thrombocytopenia syndrome virus (SFTSV) infection has emerged as a global public health issue, and its incidence is increasing annually. Neutralizing antibodies offer rapid and efficient therapeutic potential against viral infections. In this report, we elucidated the crystal structure of a highly effective and broad-spectrum murine neutralizing antibody, mAb 40C10, in complex with the SFTSV glycoprotein N (Gn) head domain. Through structural and sequence analyses, we revealed the molecular mechanism underlying the neutralization activity of mAb 40C10 and unveiled a new, potent, and broad-spectrum neutralizing epitope. Notably, this epitope is conserved across different genotypes of SFTSV and SFTSV-related viruses. The newly identified epitope provides valuable insights for reverse vaccine or drug design. Furthermore, we humanized mAb 40C10 and demonstrated the sustained efficacy of the humanized antibody in animal experiments, potentially advancing the development of clinical antibody therapeutics targeting SFTSV.

[end paper 95]

[begin paper 96]

PMCID = 6022837

Title = Cross-Linking Mass Spectrometry (XL-MS): an Emerging Technology for Interactomics and Structural Biology



[end paper 96]

[begin paper 97]

PMCID = 10500258

Title = Cryo-EM structure determination of small therapeutic protein targets at 3 Å-resolution using a rigid imaging scaffold

Cryoelectron microscopy (cryo-EM) is emerging as a major method for elucidating the structures of proteins in atomic detail. A key limitation, however, is that cryo-EM is applicable only to sufficiently large macromolecular complexes. This places a great many important proteins of smaller size, especially those of interest for therapeutic drug development, outside the reach of cryo-EM. We describe a protein engineering effort that overcomes the lower mass limit through the development of a modular imaging scaffold able to rigidly bind and display practically any small protein of interest, greatly increasing its effective mass. We show this technology can be used to visualize molecules, such as a key cancer protein, with important implications for drug design and biomedical research.

Cryoelectron microscopy (Cryo-EM) has enabled structural determination of proteins larger than about 50 kDa, including many intractable by any other method, but it has largely failed for smaller proteins. Here, we obtain structures of small proteins by binding them to a rigid molecular scaffold based on a designed protein cage, revealing atomic details at resolutions reaching 2.9 Å. We apply this system to the key cancer signaling protein KRAS (19 kDa in size), obtaining four structures of oncogenic mutational variants by cryo-EM. Importantly, a structure for the key G12C mutant bound to an inhibitor drug (AMG510) reveals significant conformational differences compared to prior data in the crystalline state. The findings highlight the promise of cryo-EM scaffolds for advancing the design of drug molecules against small therapeutic protein targets in cancer and other human diseases.

[end paper 97]

[begin paper 98]

PMCID = 5683378

Title = A fragment based method for modeling of protein segments into cryo-EM density maps

Single-particle analysis of electron cryo-microscopy (cryo-EM) is a key technology for elucidation of macromolecular structures. Recent technical advances in hardware and software developments significantly enhanced the resolution of cryo-EM density maps and broadened the applicability and the circle of users. To facilitate modeling of macromolecules into cryo-EM density maps, fast and easy to use methods for modeling are now demanded.

Here we investigated and benchmarked the suitability of a classical and well established fragment-based approach for modeling of segments into cryo-EM density maps (termed FragFit). FragFit uses a hierarchical strategy to select fragments from a pre-calculated set of billions of fragments derived from structures deposited in the Protein Data Bank, based on sequence similarly, fit of stem atoms and fit to a cryo-EM density map. The user only has to specify the sequence of the segment and the number of the N- and C-terminal stem-residues in the protein. Using a representative data set of protein structures, we show that protein segments can be accurately modeled into cryo-EM density maps of different resolution by FragFit. Prediction quality depends on segment length, the type of secondary structure of the segment and local quality of the map.

Fast and automated calculation of FragFit renders it applicable for implementation of interactive web-applications e.g. to model missing segments, flexible protein parts or hinge-regions into cryo-EM density maps.

The online version of this article (10.1186/s12859-017-1904-5) contains supplementary material, which is available to authorized users.

[end paper 98]

[begin paper 99]

PMCID = 9586930

Title = Molecular insights into the distinct signaling duration for the peptide-induced PTH1R activation

The parathyroid hormone type 1 receptor (PTH1R), a class B1 G protein-coupled receptor, plays critical roles in bone turnover and Ca2+ homeostasis. Teriparatide (PTH) and Abaloparatide (ABL) are terms as long-acting and short-acting peptide, respectively, regarding their marked duration distinctions of the downstream signaling. However, the mechanistic details remain obscure. Here, we report the cryo-electron microscopy structures of PTH– and ABL–bound PTH1R-Gs complexes, adapting similar overall conformations yet with notable differences in the receptor ECD regions and the peptide C-terminal portions. 3D variability analysis and site-directed mutagenesis studies uncovered that PTH–bound PTH1R–Gs complexes display less motions and are more tolerant of mutations in affecting the receptor signaling than ABL–bound complexes. Furthermore, we combined the structural analysis and signaling assays to delineate the molecular basis of the differential signaling durations induced by these peptides. Our study deepens the mechanistic understanding of ligand-mediated prolonged or transient signaling.

Here the authors report two structures of human PTH1R-Gs complex bound to ligands PTH and ABL, providing insight into the molecular mechanism of ligand duration.

[end paper 99]

[begin paper 100]

PMCID = 11226077

Title = Protein loop structure prediction by community-based deep learning and its application to antibody CDR H3 loop modeling

As of now, more than 60 years have passed since the first determination of protein structures through crystallography, and a significant portion of protein structures can be predicted by computers. This is due to the groundbreaking enhancement in protein structure prediction achieved through neural network training utilizing extensive sequence and structure data. However, substantial challenges persist in structure prediction due to limited data availability, with antibody structure prediction standing as one such challenge. In this paper, we propose a novel neural network architecture that effectively enables structure prediction by reflecting the inherent combinatorial nature involved in protein structure formation. The core idea of this neural network architecture is not solely to track and generate a single structure but rather to form a community of multiple structures and pursue accurate structure prediction by exchanging information among community members. Applying this concept to antibody CDR H3 loop structure prediction resulted in improved structure sampling. Such an approach could be applied in the structural and functional studies of proteins, particularly in exploring various physiological processes mediated by loops. Moreover, it holds potential in addressing various other types of combinatorial structure prediction and design problems.

In this paper, we propose a new architecture that aims to improve upon protein structure prediction algorithms like AlphaFold or RoseTTAFold by considering the combinatorial nature of protein structure formation. Such an architecture, reflecting the physical principles of nature, is expected to yield beneficial results, particularly in scenarios with limited structure and sequence information. Named ComMat, this architecture does not focus on a single structure but rather on a set of multiple structures—a community—simultaneously. In this process, combinatorial exploration of protein structure is encouraged through information exchange among community members. ComMat is an instance that integrates this idea within the structure module of AlphaFold. Applying ComMat to antibody CDR H3 loop structure prediction yielded outstanding results in structure sampling and prediction when tested on the IgFold set and compared with IgFold and AlphaFold-Multimer. It confirmed that improved structure sampling stems from effective structural exploration. The proposed concept here could potentially be used in the development of various other combinatorial protein structure prediction and protein design methods.

[end paper 100]



